<?xml version="1.0" encoding="utf-8"?>
<!--
   Copyright (C) 2023 KylinSoft Co., Ltd.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, see &lt;http://www.gnu.org/licenses/&gt;.
-->
<!DOCTYPE TS>
<TS version="2.1" language="mn">
<context>
    <name>CustomAlbumViewer</name>
    <message>
        <source>No photos detected, please re-select them</source>
        <translation type="vanished">ᠭᠡᠷᠡᠯ ᠵᠢᠷᠤᠭ ᠢ ᠪᠠᠶᠢᠴᠠᠭᠠᠨ ᠰᠢᠯᠭᠠᠭᠰᠠᠨ ᠦᠭᠡᠢ ᠪᠣᠯ ᠳᠠᠬᠢᠨ ᠰᠣᠩᠭᠣᠭᠠᠷᠠᠢ ᠃</translation>
    </message>
</context>
<context>
    <name>MPRISSaverWidget</name>
    <message>
        <source>No music detected</source>
        <translation type="vanished">ᠳᠠᠭᠤᠤ ᠬᠥᠭ᠍ᠵᠢᠮ ᠢ ᠪᠠᠢ᠌ᠴᠠᠭᠠᠵᠤ ᠣᠯᠬᠤ ᠦᠭᠡᠢ ᠃</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="vanished">ᠦᠯᠦ ᠮᠡᠳᠡᠬᠦ</translation>
    </message>
</context>
<context>
    <name>PhotoCorver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="82"/>
        <source>Right open the file location</source>
        <translation>ᠪᠢᠴᠢᠭ᠌ ᠮᠠᠲ᠋ᠧᠷᠢᠶᠠᠯ ᠤᠨ ᠪᠠᠢ᠌ᠷᠢ ᠶᠢ ᠨᠡᠭᠡᠭᠡᠨ᠎ᠡ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="86"/>
        <source>Remove the file</source>
        <translation>ᠪᠢᠴᠢᠭ᠌ ᠮᠠᠲ᠋ᠧᠷᠢᠶᠠᠯ ᠢ ᠠᠷᠢᠯᠭᠠᠬᠤ</translation>
    </message>
</context>
<context>
    <name>Screenlock</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="54"/>
        <source>Screenlock</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠣᠨᠢᠰᠤᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <source>Show message on lock screen</source>
        <translation type="vanished">ᠳᠡᠯᠭᠡᠴᠡ ᠴᠣᠣᠵᠢᠯᠠᠬᠤ ᠦᠶᠡᠰ ᠵᠠᠩᠭᠢ ᠢᠯᠡᠷᠡᠭᠦᠯᠬᠦ</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="vanished">ᠦᠵᠡ ᠃</translation>
    </message>
    <message>
        <source>Online Picture</source>
        <translation type="vanished">ᠰᠦᠯᠵᠢᠶᠡᠨ ᠳᠡᠭᠡᠷᠡᠬᠢ ᠵᠢᠷᠤᠭ</translation>
    </message>
    <message>
        <source>Local Pictures</source>
        <translation type="vanished">ᠲᠤᠰ ᠭᠠᠵᠠᠷ᠎ᠤ᠋ᠨ ᠵᠢᠷᠤᠭ</translation>
    </message>
    <message>
        <source>Online Pictures</source>
        <translation type="vanished">ᠰᠦᠯᠵᠢᠶᠡᠨ ᠳᠡᠭᠡᠷᠡᠬᠢ ᠵᠢᠷᠤᠭ</translation>
    </message>
    <message>
        <source>Reset To Default</source>
        <translation type="vanished">ᠠᠶᠠᠳᠠᠯ ᠢ᠋ ᠰᠡᠷᠬᠦᠬᠡᠬᠦ</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="vanished">ᠬᠠᠮᠢᠶ᠎ᠠ ᠪᠦᠬᠦᠢ ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠭ᠎ᠠ</translation>
    </message>
    <message>
        <source>Screenlock Set</source>
        <translation type="vanished">锁屏设置</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">激活屏保时锁定屏幕</translation>
    </message>
    <message>
        <source>Lock screen delay</source>
        <translation type="vanished">ᠲᠤᠰ ᠴᠠᠭ᠎ᠤ᠋ᠨ ᠬᠡᠰᠡᠭ᠎ᠦ᠋ᠨ ᠠᠷᠤ ᠳᠡᠯᠭᠡᠴᠡ</translation>
    </message>
    <message>
        <source>Min</source>
        <translation type="vanished">分钟</translation>
    </message>
    <message>
        <source>Select screenlock background</source>
        <translation type="vanished">选择锁屏背景</translation>
    </message>
    <message>
        <source>Browser online wp</source>
        <translation type="vanished">浏览线上壁纸</translation>
    </message>
    <message>
        <source>Browser local wp</source>
        <translation type="vanished">浏览本地壁纸</translation>
    </message>
    <message>
        <source>Show picture of screenlock on screenlogin</source>
        <translation type="vanished">ᠣᠨᠢᠰᠤᠯᠠᠭᠰᠠᠨ ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠨᠠᠨ ᠵᠢᠷᠤᠭ ᠨᠡᠪᠳᠡᠷᠡᠬᠦ ᠵᠠᠭᠠᠭ ᠭᠠᠳᠠᠷᠭᠤ ᠳᠡᠭᠡᠷ᠎ᠡ ᠢᠯᠡᠷᠡᠬᠦ</translation>
    </message>
    <message>
        <source>Enabel screenlock</source>
        <translation type="vanished">开启锁屏</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="obsolete">浏览</translation>
    </message>
    <message>
        <source>screenlock</source>
        <translation type="vanished">锁屏</translation>
    </message>
    <message>
        <source>picture</source>
        <translation type="obsolete">图片</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">ᠶᠡᠷᠦ ᠡᠴᠡ ᠥᠬᠡᠢ</translation>
    </message>
    <message>
        <source>1m</source>
        <translation type="vanished">1m</translation>
    </message>
    <message>
        <source>5m</source>
        <translation type="vanished">5m</translation>
    </message>
    <message>
        <source>10m</source>
        <translation type="vanished">10m</translation>
    </message>
    <message>
        <source>30m</source>
        <translation type="vanished">30m</translation>
    </message>
    <message>
        <source>45m</source>
        <translation type="vanished">45m</translation>
    </message>
    <message>
        <source>1h</source>
        <translation type="vanished">1h</translation>
    </message>
    <message>
        <source>1.5h</source>
        <translation type="vanished">1.5h</translation>
    </message>
    <message>
        <source>3h</source>
        <translation type="vanished">3h</translation>
    </message>
    <message>
        <source>2h</source>
        <translation type="vanished">2h</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="322"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</source>
        <translation>ᠵᠢᠷᠤᠭ ᠤ᠋ᠨ ᠹᠠᠢᠯ (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</translation>
    </message>
    <message>
        <source>allFiles(*.*)</source>
        <translation type="vanished">所有文件(*.*)</translation>
    </message>
    <message>
        <source>1min</source>
        <translation type="vanished">1 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <source>5min</source>
        <translation type="vanished">5 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <source>10min</source>
        <translation type="vanished">10 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <source>30min</source>
        <translation type="vanished">30 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <source>45min</source>
        <translation type="vanished">45 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <source>1hour</source>
        <translation type="vanished">1 ᠴᠠᠭ</translation>
    </message>
    <message>
        <source>2hour</source>
        <translation type="vanished">2 ᠴᠠᠭ</translation>
    </message>
    <message>
        <source>3hour</source>
        <translation type="vanished">3 ᠴᠠᠭ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="291"/>
        <source>Your system does not have any browser application installed or the default browser application is not set up</source>
        <translation>ᠲᠠᠨ ᠤ᠋ ᠰᠢᠰᠲ᠋ᠧᠮ ᠳ᠋ᠤ᠌ ᠶᠠᠮᠠᠷ ᠴᠤ᠌ ᠦᠵᠡᠬᠦᠷ ᠬᠡᠷᠡᠭᠯᠡᠭᠡ ᠵᠢ ᠤᠭᠰᠠᠷᠠᠭᠰᠠᠨ ᠥᠬᠡᠢ ᠪᠤᠶᠤ ᠠᠶᠠᠳᠠᠯ ᠦᠵᠡᠬᠦᠷ ᠬᠡᠷᠡᠭᠯᠡᠭᠡ ᠵᠢ ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠤᠭᠰᠠᠨ ᠥᠬᠡᠢ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="292"/>
        <source>Unable to open browser application</source>
        <translation>ᠦᠵᠡᠬᠦᠷ ᠬᠡᠷᠡᠭᠯᠡᠭᠡ ᠵᠢ ᠨᠡᠬᠡᠬᠡᠬᠦ ᠵᠢᠨ ᠠᠷᠭ᠎ᠠ ᠥᠬᠡᠢ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="364"/>
        <source>select custom wallpaper file</source>
        <translation>ᠦᠪᠡᠷᠳᠡᠭᠡᠨ ᠳᠤᠭᠳᠠᠭᠠᠬᠤ ᠬᠠᠨᠠᠨ ᠵᠢᠷᠤᠭ ᠤ᠋ᠨ ᠹᠠᠢᠯ ᠢ᠋ ᠰᠣᠩᠭᠣᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="365"/>
        <source>Select</source>
        <translation>ᠰᠤᠩᠭᠤᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="366"/>
        <source>Position: </source>
        <translation>ᠪᠠᠢᠷᠢᠯᠠᠯ: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="367"/>
        <source>FileName: </source>
        <translation>ᠹᠠᠢᠯ᠎ᠤᠨ ᠨᠡᠷ᠎ᠡ ᠄ </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="368"/>
        <source>FileType: </source>
        <translation>ᠹᠠᠢᠯ ᠳᠦᠷᠦᠯ ᠵᠦᠢᠯ: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="369"/>
        <source>Cancel</source>
        <translation>ᠦᠬᠡᠢᠰᠬᠡᠬᠦ</translation>
    </message>
    <message>
        <source>Monitor Off</source>
        <translation type="vanished">ᠦᠵᠡᠬᠦᠷ ᠢ᠋ ᠬᠠᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <source>Screensaver</source>
        <translation type="vanished">ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="vanished">ᠣᠴᠢᠵᠤ ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠬᠤ</translation>
    </message>
    <message>
        <source>The date and time are displayed</source>
        <translation type="vanished">ᠴᠠᠭ ᠢ ᠢᠯᠡᠷᠡᠭᠦᠯᠦᠨ᠎ᠡ ᠃</translation>
        <extra-contents_path>/Screenlock/The date and time are displayed</extra-contents_path>
    </message>
</context>
<context>
    <name>ScreenlockUi</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="73"/>
        <source>Show picture of screenlock on screenlogin</source>
        <translation>ᠣᠨᠢᠰᠤᠯᠠᠭᠰᠠᠨ ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠨᠠᠨ ᠵᠢᠷᠤᠭ ᠨᠡᠪᠳᠡᠷᠡᠬᠦ ᠵᠠᠭᠠᠭ ᠭᠠᠳᠠᠷᠭᠤ ᠳᠡᠭᠡᠷ᠎ᠡ ᠢᠯᠡᠷᠡᠬᠦ</translation>
        <extra-contents_path>/Screenlock/Show picture of screenlock on screenlogin</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="99"/>
        <source>Leave lock (System will be locked when the paired phone gone)</source>
        <translation>ᠬᠦᠳᠡᠯᠦᠩᠬᠦᠢ ᠣᠨᠢᠰᠣ ( ᠰᠢᠰᠲ᠋ᠧᠮ ᠨᠢ ᠨᠢᠬᠡᠨᠳᠡ ᠠᠪᠴᠠᠯᠳᠤᠭᠰᠠᠨ ᠯᠠᠨᠶᠠ ᠭᠠᠷ ᠤᠳᠠᠰᠤᠨ ᠡᠴᠡ ᠰᠠᠯᠬᠤ ᠦᠶ᠎ᠡ ᠳ᠋ᠤ᠌ ᠠᠦ᠋ᠲ᠋ᠣ᠋ ᠪᠡᠷ ᠳᠡᠯᠭᠡᠴᠡ ᠵᠢ ᠣᠨᠢᠰᠤᠯᠠᠨ᠎ᠠ)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="110"/>
        <source>Specified device</source>
        <translation>ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢ ᠳᠤᠭᠳᠠᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="127"/>
        <source>No paired phone. Please turn to &apos;Bluetooth&apos; to pair.</source>
        <translation>ᠭᠠᠷ ᠤᠳᠠᠰᠤ ᠲᠠᠢ ᠠᠪᠴᠠᠯᠳᠤᠭᠰᠠᠨ ᠥᠬᠡᠢ᠂ &apos; ᠯᠠᠨᠶᠠ &apos; ᠪᠡᠷ ᠭᠠᠷ ᠤᠳᠠᠰᠤ ᠲᠠᠢ ᠬᠣᠯᠪᠣᠭᠠᠷᠠᠢ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="52"/>
        <source>Screenlock</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠣᠨᠢᠰᠤᠯᠠᠬᠤ</translation>
        <extra-contents_path>/Screenlock/Screenlock</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="85"/>
        <source>The date and time are displayed</source>
        <translation>ᠴᠠᠭ ᠢ ᠢᠯᠡᠷᠡᠭᠦᠯᠦᠨ᠎ᠡ ᠃</translation>
        <extra-contents_path>/Screenlock/The date and time are displayed</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="185"/>
        <source>Choose Picture</source>
        <translation>ᠵᠢᠷᠤᠭ ᠰᠣᠩᠭᠣᠬᠤ</translation>
        <extra-contents_path>/Wallpaper/Choose Picture</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="189"/>
        <source>Local Pictures</source>
        <translation>ᠲᠤᠰ ᠭᠠᠵᠠᠷ᠎ᠤ᠋ᠨ ᠵᠢᠷᠤᠭ</translation>
        <extra-contents_path>/Screenlock/Local Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="193"/>
        <source>Online Pictures</source>
        <translation>ᠰᠦᠯᠵᠢᠶᠡᠨ ᠳᠡᠭᠡᠷᠡᠬᠢ ᠵᠢᠷᠤᠭ</translation>
        <extra-contents_path>/Screenlock/Online Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="197"/>
        <source>Reset To Default</source>
        <translation>ᠠᠶᠠᠳᠠᠯ ᠰᠡᠷᠭᠦᠭᠡᠬᠦ</translation>
        <extra-contents_path>/Screenlock/Reset To Default</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="136"/>
        <source>Bluetooth</source>
        <translation>ᠯᠠᠨᠶᠠ ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠭ᠎ᠠ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="256"/>
        <source>No bluetooth adapter detected, can not use Leave Lock.</source>
        <translation>ᠯᠠᠨᠶᠠ ᠲᠠᠢ ᠠᠪᠴᠠᠯᠳᠤᠬᠤ ᠬᠡᠷᠡᠭᠰᠡᠯ ᠢ᠋ ᠬᠢᠨᠠᠨ ᠬᠡᠮᠵᠢᠵᠤ ᠤᠯᠤᠭᠰᠠᠨ ᠥᠬᠡᠢ᠂ ᠬᠦᠳᠡᠯᠦᠩᠬᠦᠢ ᠣᠨᠢᠰᠣ ᠵᠢᠨ ᠴᠢᠳᠠᠪᠬᠢ ᠵᠢ ᠬᠡᠷᠡᠭᠯᠡᠬᠦ ᠵᠢᠨ ᠠᠷᠭ᠎ᠠ ᠥᠬᠡᠢ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="220"/>
        <source>Monitor Off</source>
        <translation>ᠦᠵᠡᠬᠦᠷ ᠢ᠋ ᠬᠠᠭᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="222"/>
        <source>Screensaver</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠬᠡᠯᠪᠡᠷᠢ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="217"/>
        <source>Related Settings</source>
        <translation>ᠬᠠᠮᠢᠶ᠎ᠠ ᠪᠦᠬᠦᠢ ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠭ᠎ᠠ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="221"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="223"/>
        <source>Set</source>
        <translation>ᠳᠤᠬᠢᠷᠠᠭᠤᠯᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="288"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="737"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="771"/>
        <source>Please select device</source>
        <translation>ᠳᠤᠭᠳᠠᠭᠠᠭᠰᠠᠨ ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢ ᠰᠣᠩᠭᠣᠭᠠᠷᠠᠢ</translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="56"/>
        <source>Screensaver</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠬᠡᠯᠪᠡᠷᠢ</translation>
    </message>
    <message>
        <source>Idle time</source>
        <translation type="vanished">ᠲᠤᠰ ᠴᠠᠭ ᠤ᠋ᠨ ᠬᠡᠰᠡᠭ ᠤ᠋ᠨ ᠳᠠᠷᠠᠭ᠎ᠠ ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠮᠠᠭᠠᠯᠠᠯᠳᠠ ᠵᠢ ᠡᠬᠢᠯᠡᠬᠦᠯᠬᠦ</translation>
    </message>
    <message>
        <source>Lock screen when activating screensaver</source>
        <translation type="vanished">ᠳᠡᠯᠭᠡᠴᠡ᠎ᠶ᠋ᠢ ᠢᠳᠡᠪᠬᠢᠵᠢᠭᠦᠯᠬᠦ᠎ᠳ᠋ᠦ᠍ ᠳᠡᠯᠭᠡᠴᠡ᠎ᠶ᠋ᠢ ᠣᠨᠢᠰᠤᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <source>Enable screensaver</source>
        <translation type="vanished">开启屏保</translation>
    </message>
    <message>
        <source>Screensaver program</source>
        <translation type="vanished">ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠫᠷᠣᠭ᠌ᠷᠠᠮ</translation>
    </message>
    <message>
        <source>idle time</source>
        <translation type="vanished">等待时间</translation>
    </message>
    <message>
        <source>Min</source>
        <translation type="vanished">分钟</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠮᠠᠭᠠᠯᠠᠯᠳᠠ ᠵᠢ ᠡᠬᠢᠯᠡᠬᠦᠯᠬᠦ ᠦᠶ᠎ᠡ ᠳ᠋ᠤ᠌ ᠳᠡᠯᠭᠡᠴᠡ ᠵᠢ ᠣᠨᠢᠰᠤᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <source>screensaver</source>
        <translation type="vanished">屏保</translation>
    </message>
    <message>
        <source>Default_ukui</source>
        <translation type="vanished">默认屏保</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">ᠪᠠᠢᠴᠠᠭᠠᠵᠤ ᠦᠵᠡᠬᠦ</translation>
    </message>
    <message>
        <source>Text(up to 30 characters):</source>
        <translation type="vanished">ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠲᠸᠺᠰᠲ ( ᠬᠠᠮᠤᠭ ᠤ᠋ᠨ ᠣᠯᠠᠨ ᠳ᠋ᠤ᠌ ᠪᠡᠨ 30 ᠦᠰᠦᠭ):</translation>
    </message>
    <message>
        <source>Show rest time</source>
        <translation type="vanished">ᠠᠮᠠᠷᠠᠬᠤ ᠴᠠᠭ ᠢ᠋ ᠢᠯᠡᠷᠡᠬᠦᠯᠬᠦ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="222"/>
        <source>UKUI</source>
        <translation>UKUI</translation>
    </message>
    <message>
        <source>Blank_Only</source>
        <translation type="vanished">ᠬᠠᠷ᠎ᠠ ᠳᠡᠯᠭᠡᠴᠡ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="222"/>
        <source>Customize</source>
        <translation>ᠦᠪᠡᠷᠳᠡᠭᠡᠨ ᠳᠤᠳᠤᠷᠬᠠᠢᠯᠠᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>5min</source>
        <translation>5 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>10min</source>
        <translation>10 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <source>15min</source>
        <translation>15 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>30min</source>
        <translation>30 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <source>1hour</source>
        <translation>1 ᠴᠠᠭ</translation>
    </message>
    <message>
        <source>Screensaver source</source>
        <translation type="vanished">ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠢᠷᠡᠯᠳᠡ</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="vanished">ᠰᠤᠩᠭᠤᠬᠤ</translation>
    </message>
    <message>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation type="vanished">ᠬᠠᠨᠠᠨ ᠵᠢᠷᠤᠭ ᠤ᠋ᠨ ᠹᠠᠢᠯ (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</translation>
    </message>
    <message>
        <source>select custom screensaver dir</source>
        <translation type="vanished">ᠦᠪᠡᠷᠳᠡᠭᠡᠨ ᠳᠤᠭᠳᠠᠭᠠᠬᠤ ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠮᠠᠭᠠᠯᠠᠯᠳᠠ ᠵᠢᠨ ᠵᠢᠮ ᠢ᠋ ᠰᠣᠩᠭᠣᠬᠤ</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation type="vanished">ᠪᠠᠢᠷᠢ: </translation>
    </message>
    <message>
        <source>FileName: </source>
        <translation type="vanished">ᠹᠠᠢᠯ ᠤ᠋ᠨ ᠨᠡᠷ᠎ᠡ: </translation>
    </message>
    <message>
        <source>FileType: </source>
        <translation type="vanished">ᠹᠠᠢᠯ ᠤ᠋ᠨ ᠳᠦᠷᠦᠯ ᠵᠦᠢᠯ: </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">ᠦᠬᠡᠢᠰᠬᠡᠬᠦ</translation>
    </message>
    <message>
        <source>Switching time</source>
        <translation type="vanished">ᠳᠠᠪᠳᠠᠮᠵᠢ ᠵᠢ ᠰᠣᠯᠢᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="216"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>1min</source>
        <translation>1 ᠮᠢᠨᠦ᠋ᠲ</translation>
    </message>
    <message>
        <source>Ordinal</source>
        <translation type="vanished">ᠳᠠᠷᠠᠭᠠᠯᠠᠯ ᠵᠢᠡᠷ</translation>
    </message>
    <message>
        <source>Random switching</source>
        <translation type="vanished">ᠳᠠᠰᠢᠷᠠᠮ ᠵᠢᠡᠷ ᠰᠣᠯᠢᠬᠤ</translation>
    </message>
    <message>
        <source>Display text</source>
        <translation type="vanished">显示文本</translation>
    </message>
    <message>
        <source>Enter text, up to 30 characters</source>
        <translation type="vanished">输入文本，最多30个字符</translation>
    </message>
    <message>
        <source>Text position</source>
        <translation type="vanished">ᠲᠸᠺᠰᠲ ᠤ᠋ᠨ ᠪᠠᠢᠷᠢ</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation type="vanished">ᠳᠦᠪᠯᠡᠷᠡᠬᠦᠯᠬᠦ</translation>
    </message>
    <message>
        <source>Randow(Bubble text)</source>
        <translation type="vanished">ᠳᠠᠰᠢᠷᠠᠮ ( ᠬᠦᠬᠡᠰᠦ ᠲᠸᠺᠰᠲ)</translation>
    </message>
    <message>
        <source>1m</source>
        <translation type="vanished">1m</translation>
    </message>
    <message>
        <source>5m</source>
        <translation type="vanished">5m</translation>
    </message>
    <message>
        <source>10m</source>
        <translation type="vanished">10m</translation>
    </message>
    <message>
        <source>30m</source>
        <translation type="vanished">30m</translation>
    </message>
    <message>
        <source>45m</source>
        <translation type="vanished">45m</translation>
    </message>
    <message>
        <source>1h</source>
        <translation type="vanished">1h</translation>
    </message>
    <message>
        <source>1.5h</source>
        <translation type="vanished">1.5h</translation>
    </message>
    <message>
        <source>3h</source>
        <translation type="vanished">3h</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="vanished">ᠳᠠᠰᠢᠷᠠᠮ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <source>Never</source>
        <translation>ᠶᠡᠷᠦ ᠡᠴᠡ ᠥᠬᠡᠢ</translation>
    </message>
    <message>
        <source>Picture does not exist</source>
        <translation type="vanished">ᠵᠢᠷᠤᠭ ᠪᠠᠢᠬᠤ ᠥᠬᠡᠢ</translation>
    </message>
    <message>
        <source>Not connected to a network</source>
        <translation type="vanished">ᠲᠣᠣᠷ ᠰᠦᠯᠵᠢᠶ᠎ᠡ ᠶᠢ ᠬᠣᠯᠪᠣᠭᠰᠠᠨ ᠦᠭᠡᠢ ᠃</translation>
    </message>
    <message>
        <source>The weather update failed</source>
        <translation type="vanished">ᠠᠭᠤᠷ ᠠᠮᠢᠰᠭᠤᠯ ᠰᠢᠨᠡᠳᠭᠡᠬᠦ ᠳᠦ ᠢᠯᠠᠭᠳᠠᠪᠠ ᠃</translation>
    </message>
</context>
<context>
    <name>ScreensaverUi</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="70"/>
        <source>Screensaver</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠬᠡᠯᠪᠡᠷᠢ</translation>
        <extra-contents_path>/Screensaver/Screensaver</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="176"/>
        <source>Idle time</source>
        <translation>ᠲᠤᠰ ᠴᠠᠭ ᠤ᠋ᠨ ᠬᠡᠰᠡᠭ ᠤ᠋ᠨ ᠳᠠᠷᠠᠭ᠎ᠠ ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠮᠠᠭᠠᠯᠠᠯᠳᠠ ᠵᠢ ᠡᠬᠢᠯᠡᠬᠦᠯᠬᠦ</translation>
        <extra-contents_path>/Screensaver/Idle time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="347"/>
        <source>Screensaver program</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠫᠷᠣᠭ᠌ᠷᠠᠮ</translation>
        <extra-contents_path>/Screensaver/Screensaver program</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="376"/>
        <source>Screensaver source</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠢᠷᠡᠯᠳᠡ</translation>
        <extra-contents_path>/Screensaver/Screensaver source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="381"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="972"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1116"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1186"/>
        <source>Select</source>
        <translation>ᠰᠤᠩᠭᠤᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="402"/>
        <source>Ordinal</source>
        <translation>ᠳᠠᠷᠠᠭᠠᠯᠠᠯ ᠵᠢᠡᠷ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="305"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="403"/>
        <source>Random</source>
        <translation>ᠳᠠᠰᠢᠷᠠᠮ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="410"/>
        <source>Random switching</source>
        <translation>ᠳᠠᠰᠢᠷᠠᠮ ᠵᠢᠡᠷ ᠰᠣᠯᠢᠬᠤ</translation>
        <extra-contents_path>/Screensaver/Random switching</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="430"/>
        <source>Switching time</source>
        <translation>ᠳᠠᠪᠳᠠᠮᠵᠢ ᠵᠢ ᠰᠣᠯᠢᠬᠤ</translation>
        <extra-contents_path>/Screensaver/Switching time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="449"/>
        <source>Text(up to 30 characters):</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡ ᠬᠠᠮᠠᠭᠠᠯᠠᠬᠤ ᠲᠸᠺᠰᠲ ( ᠬᠠᠮᠤᠭ ᠤ᠋ᠨ ᠣᠯᠠᠨ ᠳ᠋ᠤ᠌ ᠪᠡᠨ 30 ᠦᠰᠦᠭ):</translation>
        <extra-contents_path>/Screensaver/Text(up to 30 characters):</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="472"/>
        <source>Text position</source>
        <translation>ᠲᠸᠺᠰᠲ ᠤ᠋ᠨ ᠪᠠᠢᠷᠢᠯᠠᠯ</translation>
        <extra-contents_path>/Screensaver/Text position</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="480"/>
        <source>Centered</source>
        <translation>ᠳᠦᠪᠯᠡᠷᠡᠬᠦᠯᠬᠦ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="481"/>
        <source>Randow(Bubble text)</source>
        <translation>ᠳᠠᠰᠢᠷᠠᠮ ( ᠬᠦᠬᠡᠰᠦ ᠲᠸᠺᠰᠲ)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="214"/>
        <source>Show rest time</source>
        <translation>ᠠᠮᠠᠷᠠᠬᠤ ᠴᠠᠭ ᠢ᠋ ᠢᠯᠡᠷᠡᠬᠦᠯᠬᠦ</translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="86"/>
        <source>Select Screensaver</source>
        <translation>ᠳᠡᠯᠬᠡᠴᠡ ᠶᠢᠨ ᠪᠠᠲᠤᠯᠠᠭ᠎ᠠ ᠶᠢ ᠰᠣᠩᠭᠣᠨ᠎ᠠ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="112"/>
        <source>Weather</source>
        <translation>ᠴᠠᠭ ᠠᠭᠤᠷ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="125"/>
        <source>Music</source>
        <translation>ᠳᠠᠭᠤᠤ ᠬᠥᠭᠵᠢᠮ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="138"/>
        <source>Albun</source>
        <translation>ᠵᠢᠷᠤᠭ ᠤ᠋ᠨ ᠳᠡᠪᠲᠡᠷ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="225"/>
        <source>Lock screen when screensaver boot</source>
        <translation>ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠮᠠᠭᠠᠯᠠᠯᠳᠠ ᠵᠢ ᠢᠳᠡᠪᠬᠢᠵᠢᠬᠦᠯᠬᠦ ᠦᠶ᠎ᠡ ᠳ᠋ᠤ᠌ ᠳᠡᠯᠭᠡᠴᠡ ᠵᠢ ᠣᠨᠢᠰᠤᠯᠠᠬᠤ</translation>
        <extra-contents_path>/Screensaver/Lock screen when screensaver boot</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="194"/>
        <source>The date and time are displayed</source>
        <translation>ᠴᠠᠭ ᠢ ᠢᠯᠡᠷᠡᠭᠦᠯᠦᠨ᠎ᠡ ᠃</translation>
        <extra-contents_path>/Screensaver/The date and time are displayed</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="246"/>
        <source>Go to App Settings</source>
        <translation>ᠬᠡᠷᠡᠭᠯᠡᠭᠡᠨ ᠦ ᠪᠠᠶᠢᠷᠢᠯᠠᠭᠤᠯᠤᠯᠲᠠ ᠳᠤ ᠬᠦᠷᠦᠨ᠎ᠡ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="257"/>
        <source>Current position</source>
        <translation>ᠣᠳᠣᠬᠠᠨ ᠤ ᠪᠠᠶᠢᠷᠢ ᠰᠠᠭᠤᠷᠢ ᠃</translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="270"/>
        <source>Prioritize the list of songs from the Music app</source>
        <translation>《 ᠳᠠᠭᠤᠤ ᠬᠥᠭ᠍ᠵᠢᠮ 》 ᠦᠨ ᠬᠡᠷᠡᠭᠯᠡᠯᠲᠡ ᠶᠢᠨ ᠳᠠᠭᠤᠤ ᠶᠢᠨ ᠵᠢᠭᠰᠠᠭᠠᠯᠲᠠ ᠶᠢᠨ ᠬᠦᠰᠦᠨᠦᠭᠲᠦ ᠶᠢ ᠡᠩ ᠲᠡᠷᠢᠭᠦᠨ ᠳᠦ ᠨᠡᠪᠲᠡᠷᠡᠭᠦᠯᠦᠨ᠎ᠡ ᠃</translation>
        <extra-contents_path>/Screensaver/Prioritize the list of songs from the Music app</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="277"/>
        <source>Priority playlists</source>
        <translation>ᠬᠦᠰᠦᠨᠦᠭᠲᠦ ᠶᠢ ᠡᠩ ᠲᠡᠷᠢᠭᠦᠨ ᠳᠦ ᠨᠡᠪᠲᠡᠷᠡᠭᠦᠯᠦᠨ᠎ᠡ ᠃</translation>
        <extra-contents_path>/Screensaver/Priority playlists</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="281"/>
        <source>Select the folder</source>
        <translation>ᠪᠢᠴᠢᠭ᠌ ᠮᠠᠲ᠋ᠧᠷᠢᠶᠠᠯ ᠤᠨ ᠬᠠᠪᠤᠳᠠᠷ ᠢ ᠰᠣᠩᠭᠣᠨ᠎ᠠ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="303"/>
        <source>Switch mode</source>
        <translation>ᠬᠡᠪ ᠵᠠᠭᠪᠤᠷ ᠢᠶᠠᠨ ᠰᠣᠯᠢᠨ᠎ᠠ ᠃</translation>
        <extra-contents_path>/Screensaver/Switch mode</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="304"/>
        <source>In order</source>
        <translation>ᠳᠡᠰ ᠳᠠᠷᠠᠭᠠᠯᠠᠯ ᠢᠶᠠᠷ ᠨᠢ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="310"/>
        <source>Switching frequency</source>
        <translation>ᠲᠠᠰᠢᠷᠠᠮ ᠢᠶᠠᠷ ᠃</translation>
        <extra-contents_path>/Screensaver/Switching frequency</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="327"/>
        <source>Image source</source>
        <translation>ᠵᠢᠷᠤᠭ ᠤ᠋ᠨ ᠢᠷᠡᠯᠳᠡ</translation>
        <extra-contents_path>/Screensaver/Image source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="328"/>
        <source>Add image folder</source>
        <translation>ᠵᠢᠷᠤᠭ ᠳᠦᠷᠰᠦᠲᠦ ᠪᠢᠴᠢᠭ᠌ ᠮᠠᠲ᠋ᠧᠷᠢᠶᠠᠯ ᠤᠨ ᠬᠠᠪᠤᠳᠠᠷ ᠨᠡᠮᠡ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="863"/>
        <source>System wallpaper gallery</source>
        <translation>ᠰᠢᠰᠲ᠋ᠧᠮᠲᠦ ᠵᠢᠷᠤᠭ ᠤᠨ ᠡᠬᠢ ᠪᠠᠶᠠᠯᠢᠭ ᠤᠨ ᠬᠥᠮᠥᠷᠭᠡ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="930"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1144"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation>ᠬᠠᠨᠠᠨ ᠵᠢᠷᠤᠭ ᠤ᠋ᠨ ᠹᠠᠢᠯ (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="971"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1185"/>
        <source>select custom screensaver dir</source>
        <translation>ᠦᠪᠡᠷᠳᠡᠭᠡᠨ ᠳᠤᠭᠳᠠᠭᠠᠬᠤ ᠳᠡᠯᠭᠡᠴᠡᠨ ᠤ᠋ ᠬᠠᠮᠠᠭᠠᠯᠠᠯᠳᠠ ᠵᠢᠨ ᠵᠢᠮ ᠢ᠋ ᠰᠣᠩᠭᠣᠬᠤ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="973"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1117"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1187"/>
        <source>Position: </source>
        <translation>ᠪᠠᠢᠷᠢᠯᠠᠯ᠄ </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="974"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1118"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1188"/>
        <source>FileName: </source>
        <translation>ᠹᠠᠢᠯ᠎ᠤᠨ ᠨᠡᠷ᠎ᠡ ᠄ </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="975"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1119"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1189"/>
        <source>FileType: </source>
        <translation>ᠹᠠᠢᠯ ᠳᠦᠷᠦᠯ ᠵᠦᠢᠯ: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="976"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1120"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1190"/>
        <source>Cancel</source>
        <translation>ᠦᠬᠡᠢᠰᠬᠡᠬᠦ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1074"/>
        <source>Music files(*.mp3 *.wav *.ogg *.flac *.aac *.m4a *.wma *.opus *.aiff .ape)</source>
        <translation>ᠳᠠᠭᠤᠨ ᠤ ᠳᠠᠪᠲᠠᠮᠵᠢ ᠶᠢᠨ ᠪᠢᠴᠢᠭ᠌ ᠮᠠᠲ᠋ᠧᠷᠢᠶᠠᠯ ᠃(*.mp3 *.wav *.ogg *.flac *.aac *.m4a *.wma *.opus *.aiff .ape)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1115"/>
        <source>select screensaver music dir</source>
        <translation>ᠳᠡᠯᠬᠡᠴᠡ ᠪᠠᠲᠤᠯᠠᠬᠤ ᠳᠠᠭᠤᠤ ᠬᠥᠭ᠍ᠵᠢᠮ ᠦᠨ ᠪᠢᠴᠢᠭ᠌ ᠮᠠᠲ᠋ᠧᠷᠢᠶᠠᠯ ᠤᠨ ᠬᠠᠪᠤᠳᠠᠷ ᠢ ᠰᠣᠩᠭᠣᠨ᠎ᠠ ᠃</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1140"/>
        <source>The maximum limit for the number of images in the folder has been reached; you can remove some before continuing to add more.</source>
        <translation>ᠵᠢᠷᠤᠭ ᠤ᠋ᠨ ᠹᠠᠢᠯ ᠤ᠋ᠨ ᠬᠠᠪᠳᠠᠰᠤ ᠵᠢ ᠨᠡᠮᠡᠭᠰᠡᠨ ᠲᠣᠭ᠎ᠠ ᠬᠢᠵᠠᠭᠠᠷ ᠲᠤ᠌ ᠳᠤᠯᠪᠠ᠂ ᠰᠢᠯᠵᠢᠬᠦᠯᠦᠭᠰᠡᠨ ᠤ᠋ ᠳᠠᠷᠠᠭ᠎ᠠ ᠳᠠᠬᠢᠨ ᠨᠡᠮᠡᠵᠤ ᠪᠤᠯᠤᠨ᠎ᠠ᠃</translation>
    </message>
</context>
</TS>
