<?xml version="1.0" encoding="utf-8"?>
<!--
   Copyright (C) 2023 KylinSoft Co., Ltd.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, see &lt;http://www.gnu.org/licenses/&gt;.
--><!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>AgreementWindow</name>
    <message>
        <location filename="../src/widgets/agreementwindow.cpp" line="47"/>
        <source>I know</source>
        <translation>Saya tahu</translation>
    </message>
</context>
<context>
    <name>AuthDialog</name>
    <message>
        <source>More Devices</source>
        <translation type="obsolete">选择其他设备</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="obsolete">使用生物识别认证</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">使用密码认证</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1554"/>
        <source>Retry</source>
        <translation>Cuba semula</translation>
    </message>
    <message>
        <source>UnLock</source>
        <translation type="obsolete">解锁</translation>
    </message>
    <message>
        <source>Slide to unlock</source>
        <translation type="vanished">向上滑动解锁</translation>
    </message>
    <message>
        <source>You have %1 unread message</source>
        <translation type="vanished">您有%1条未读消息</translation>
    </message>
    <message>
        <source>LoggedIn</source>
        <translation type="obsolete">已登录</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation type="vanished">密码：</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="948"/>
        <source>Password Prompt:%1</source>
        <translation>Gesaan Kata laluan: %1</translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="vanished">账户锁定%1分钟由于%2次错误尝试</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1623"/>
        <source>Please try again in %1 minutes.</source>
        <translation>Sila cuba lagi dalam %1 minit.</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1631"/>
        <source>Please try again in %1 seconds.</source>
        <translation>Sila cuba lagi dalam %1 minit.</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1639"/>
        <source>Account locked permanently.</source>
        <translation>Akaun dikunci selamanya.</translation>
    </message>
    <message>
        <source>Verify face recognition or enter password to unlock</source>
        <translation type="vanished">验证人脸识别或输入密码解锁</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="483"/>
        <source>Guest</source>
        <translation>Tetamu</translation>
    </message>
    <message>
        <source>Press fingerprint or enter password to unlock</source>
        <translation type="vanished">按压指纹或输入密码解锁</translation>
    </message>
    <message>
        <source>Verify voiceprint or enter password to unlock</source>
        <translation type="vanished">验证声纹或输入密码解锁</translation>
    </message>
    <message>
        <source>Verify finger vein or enter password to unlock</source>
        <translation type="vanished">验证指静脉或输入密码解锁</translation>
    </message>
    <message>
        <source>Verify iris or enter password to unlock</source>
        <translation type="vanished">验证虹膜或输入密码解锁</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="481"/>
        <source>Enter username</source>
        <translation>Masukkan nama pengguna</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="771"/>
        <location filename="../src/widgets/authdialog.cpp" line="803"/>
        <source>Facial recognition to unlock</source>
        <translation>Pengecaman wajah untuk membuka kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="774"/>
        <source>Fingerprint recognition to unlock</source>
        <translation>Pengecaman ibu jari untuk membuka kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="777"/>
        <source>Voiceprint recognition to unlock</source>
        <translation>Pengecaman suara untuk membuka kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="780"/>
        <source>Finger vein recognition to unlock</source>
        <translation>Pengecaman Vena jari untuk membuka kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="783"/>
        <source>Iris recognition to unlock</source>
        <translation>Pengenalan Iris untuk membuka kunci</translation>
    </message>
    <message>
        <source>Use the bound wechat scanning code to unlock</source>
        <translation type="vanished">微信扫码解锁</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="786"/>
        <source>wechat</source>
        <translation>WeChat</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="790"/>
        <source>Use the bound %1 scanning code to unlock</source>
        <translation>Gunakan kod pengimbasan %1 terikat untuk membuka kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1058"/>
        <location filename="../src/widgets/authdialog.cpp" line="1082"/>
        <source>The authentication has been cancelled!</source>
        <translation>Pengesahan telah dibatalkan!</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1278"/>
        <source>Password:</source>
        <translation>Kata laluan:</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1281"/>
        <source>Input Password</source>
        <translation>Masukkan Kata laluan</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1286"/>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1378"/>
        <source>User name input error!</source>
        <translation>Kesalahan Masukan Nama Pengguna!</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1468"/>
        <source>login</source>
        <translation>Log masuk</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1876"/>
        <location filename="../src/widgets/authdialog.cpp" line="2126"/>
        <location filename="../src/widgets/authdialog.cpp" line="2281"/>
        <location filename="../src/widgets/authdialog.cpp" line="2478"/>
        <source>Failed to verify %1, please enter password to unlock</source>
        <translation>Gagal mengesahkan %1, sila masukkan kata laluan untuk membuka kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1879"/>
        <location filename="../src/widgets/authdialog.cpp" line="2129"/>
        <location filename="../src/widgets/authdialog.cpp" line="2286"/>
        <location filename="../src/widgets/authdialog.cpp" line="2289"/>
        <location filename="../src/widgets/authdialog.cpp" line="2481"/>
        <source>Unable to verify %1, please enter password to unlock</source>
        <translation>Tidak dapat mengesahkan %1, sila masukkan kata laluan untuk membuka kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2322"/>
        <source>Abnormal network</source>
        <translation>Rangkaian Tidak Normal</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2326"/>
        <source>Acquisition failure</source>
        <translation>Pemerolehan gagal</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2338"/>
        <source>Face recognition waiting time out, please click refresh or enter the password to unlock.</source>
        <translation>Masa tunggu pengenalan wajah tamat, sila klik muat semula atau masukkan kata laluan untuk membuka kunci.</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2607"/>
        <source>FingerPrint</source>
        <translation>Cap Jari</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2609"/>
        <source>FingerVein</source>
        <translation>Vena Jari</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2611"/>
        <source>Iris</source>
        <translation>Iris</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2613"/>
        <source>Face</source>
        <translation>Muka</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2615"/>
        <source>VoicePrint</source>
        <translation>Cetakan Suara</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2617"/>
        <location filename="../src/widgets/authdialog.cpp" line="2639"/>
        <source>Ukey</source>
        <translation>Kunci USB</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2619"/>
        <location filename="../src/widgets/authdialog.cpp" line="2641"/>
        <source>QRCode</source>
        <translation>Kod QR</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2629"/>
        <source>fingerprint</source>
        <translation>Cap Jari</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2631"/>
        <source>fingervein</source>
        <translation>Vena Jari</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2633"/>
        <source>iris</source>
        <translation>Iris</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2635"/>
        <source>face</source>
        <translation>Muka</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2637"/>
        <source>voiceprint</source>
        <translation>Cetakan Suara</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2867"/>
        <source>Two-Factor OTP Dynamic Password Authentication</source>
        <translation>Pengesahan Kata laluan Dinamik OTP Dua Faktor</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2870"/>
        <source>Two-Factor Security Key Authentication</source>
        <translation>Pengesahan Kunci Keselamatan Dua Faktor</translation>
    </message>
    <message>
        <source>Use the bound wechat scanning code or enter the password to log in</source>
        <translation type="vanished">使用绑定的微信扫码或输入密码登录</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="930"/>
        <source>Password cannot be empty</source>
        <translation>Kata laluan tidak boleh kosong</translation>
    </message>
    <message>
        <source>Failed to verify %1, please enter password.</source>
        <translation type="vanished">验证%1失败，请输入密码.</translation>
    </message>
    <message>
        <source>Unable to verify %1, please enter password.</source>
        <translation type="vanished">无法验证%1，请输入密码.</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2306"/>
        <location filename="../src/widgets/authdialog.cpp" line="2310"/>
        <source>Failed to verify %1, you still have %2 verification opportunities</source>
        <translation>Gagal mengesahkan %1, anda masih mempunyai %2 peluang pengesahan</translation>
    </message>
    <message>
        <source>Biometric/code scan authentication failed too many times, please enter the password.</source>
        <translation type="vanished">生物/扫码验证失败达最大次数，请使用密码解锁</translation>
    </message>
    <message>
        <source>Bioauth/code scan authentication failed, you still have %1 verification opportunities</source>
        <translation type="vanished">生物/扫码验证失败，您还有%1次尝试机会</translation>
    </message>
    <message>
        <source>NET Exception</source>
        <translation type="vanished">网络异常</translation>
    </message>
    <message>
        <source>Password Incorrect, Please try again</source>
        <translation type="vanished">密码错误，请重试</translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="vanished">认证失败，还剩%1次尝试机会</translation>
    </message>
    <message>
        <source>Please enter your password or enroll your fingerprint </source>
        <translation type="vanished">请输入密码或者录入指纹</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1381"/>
        <location filename="../src/widgets/authdialog.cpp" line="1385"/>
        <source>Authentication failure, Please try again</source>
        <translation>Gagal pengesahan, sila cuba lagi</translation>
    </message>
    <message>
        <source>Use the bound wechat scanning code or enter the password to unlock</source>
        <translation type="vanished">使用绑定的微信扫码或输入密码解锁</translation>
    </message>
    <message>
        <source>Enter the ukey password</source>
        <translation type="vanished">输入安全密钥密码</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2833"/>
        <source>Insert the ukey into the USB port</source>
        <translation>Sisipkan ukey ke dalam port USB</translation>
    </message>
    <message>
        <source>Password </source>
        <translation type="vanished">密码 </translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1545"/>
        <source>Login</source>
        <translation>Log masuk</translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="vanished">生物识别认证</translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="vanished">密码认证</translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="vanished">其他设备</translation>
    </message>
    <message>
        <source>Too many unsuccessful attempts,please enter password.</source>
        <translation type="vanished">指纹验证失败达最大次数，请使用密码登录</translation>
    </message>
    <message>
        <source>Fingerprint authentication failed, you still have %1 verification opportunities</source>
        <translation type="vanished">指纹验证失败，您还有%1次尝试机会</translation>
    </message>
</context>
<context>
    <name>BatteryWidget</name>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="112"/>
        <location filename="../src/widgets/batterywidget.cpp" line="142"/>
        <source>Charging...</source>
        <translation>Mengecas...</translation>
    </message>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="114"/>
        <location filename="../src/widgets/batterywidget.cpp" line="144"/>
        <source>fully charged</source>
        <translation>Bateri penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="118"/>
        <location filename="../src/widgets/batterywidget.cpp" line="148"/>
        <source>PowerMode</source>
        <translation>Mod Kuasa</translation>
    </message>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="121"/>
        <location filename="../src/widgets/batterywidget.cpp" line="151"/>
        <source>BatteryMode</source>
        <translation>Mod Bateri</translation>
    </message>
</context>
<context>
    <name>BindDialog</name>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="91"/>
        <source>Close</source>
        <translation>Menutup</translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="103"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="107"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="119"/>
        <source>Mfa authentication is on, please bind OTP code</source>
        <translation>Autentikasi MFA telah dihidupkan, sila ikat kod OTP</translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="125"/>
        <source>Go to Bind</source>
        <translation>Pergi untuk Ikat</translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="150"/>
        <source>Bind</source>
        <translation>Ikat</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="obsolete">指纹</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="obsolete">指静脉</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="obsolete">虹膜</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="obsolete">人脸</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="obsolete">声纹</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Please select other biometric devices</source>
        <translation type="obsolete">请选择其他生物识别设备</translation>
    </message>
    <message>
        <source>Device Type:</source>
        <translation type="obsolete">设备类型：</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation type="obsolete">设备名称：</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="vanished">当前设备：</translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="vanished">识别失败，请重试</translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="vanished">请选择生物设备</translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="vanished">设备类型：</translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="vanished">设备型号：</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
</context>
<context>
    <name>BlockWidget</name>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="60"/>
        <location filename="../src/widgets/blockwidget.cpp" line="140"/>
        <location filename="../src/widgets/blockwidget.cpp" line="141"/>
        <location filename="../src/widgets/blockwidget.cpp" line="142"/>
        <location filename="../src/widgets/blockwidget.cpp" line="143"/>
        <location filename="../src/widgets/blockwidget.cpp" line="145"/>
        <location filename="../src/widgets/blockwidget.cpp" line="251"/>
        <location filename="../src/widgets/blockwidget.cpp" line="252"/>
        <location filename="../src/widgets/blockwidget.cpp" line="253"/>
        <location filename="../src/widgets/blockwidget.cpp" line="254"/>
        <location filename="../src/widgets/blockwidget.cpp" line="256"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="64"/>
        <location filename="../src/widgets/blockwidget.cpp" line="147"/>
        <location filename="../src/widgets/blockwidget.cpp" line="148"/>
        <location filename="../src/widgets/blockwidget.cpp" line="149"/>
        <location filename="../src/widgets/blockwidget.cpp" line="150"/>
        <location filename="../src/widgets/blockwidget.cpp" line="152"/>
        <location filename="../src/widgets/blockwidget.cpp" line="258"/>
        <location filename="../src/widgets/blockwidget.cpp" line="259"/>
        <location filename="../src/widgets/blockwidget.cpp" line="260"/>
        <location filename="../src/widgets/blockwidget.cpp" line="261"/>
        <location filename="../src/widgets/blockwidget.cpp" line="263"/>
        <source>Confrim</source>
        <translation>Sahkan</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="159"/>
        <location filename="../src/widgets/blockwidget.cpp" line="178"/>
        <source>If you do not perform any operation, the system will automatically %1 after %2 seconds.</source>
        <translation>Jika anda tidak melakukan sebarang operasi, sistem akan automatik %1 selepas %2 saat.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="193"/>
        <source>The following programs prevent restarting, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation>Program-program berikut menghalang muat semula, anda boleh klik &quot;Batal&quot; dan kemudian tutup program-program ini.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="197"/>
        <source>The following programs prevent the shutdown, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation>Program-program berikut menghalang penutupan, anda boleh klik &quot;Batal&quot; dan kemudian tutup program-program ini.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="202"/>
        <source>The following programs prevent suspend, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation>Program-program berikut menghalang penghentian sementara, anda boleh klik &quot;Batal&quot; dan kemudian tutup program-program ini.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="205"/>
        <source>The following programs prevent hibernation, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation>Program-program berikut menghalang mod tidur, anda boleh klik &quot;Batal&quot; dan kemudian tutup program-program ini.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="209"/>
        <source>The following programs prevent you from logging out, you can click &quot;Cancel&quot; and then close them.</source>
        <translation>Program berikut menghalang anda daripada log keluar, anda boleh klik &quot;Batal&quot; dan kemudian menutupnya.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="218"/>
        <source>The following programs prevent you restarting, you can click &quot;Cancel&quot; and then close them,                 or click &apos;OK&apos; to force close and proceed.</source>
        <translation>Program berikut menghalang anda memulakan semula, anda boleh mengklik &quot;Batal&quot; dan kemudian menutupnya, atau klik &apos;OK&apos; untuk menutup paksa dan meneruskan.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="223"/>
        <source>The following programs prevent you shutdown, you can click &quot;Cancel&quot; and then close them,                 or click &apos;OK&apos; to force close and proceed.</source>
        <translation>Program berikut menghalang anda memulakan semula, anda boleh klik &quot;Batal&quot; dan kemudian menutupnya, atau klik &apos;OK&apos; untuk menutup paksa dan meneruskan.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="228"/>
        <source>The following programs prevent you from logging out, you can click &quot;Cancel&quot; and then close them,                  or click &apos;OK&apos; to force close and proceed.</source>
        <translation>Program berikut menghalang anda memulakan semula, anda boleh klik &quot;Batal&quot; dan kemudian menutupnya, atau klik &apos;OK&apos; untuk menutup paksa dan meneruskan.</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="271"/>
        <source>shut down</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="274"/>
        <source>restart</source>
        <translation>Mulakan Semula</translation>
    </message>
</context>
<context>
    <name>CharsWidget</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/charswidget.cpp" line="115"/>
        <location filename="../src/VirtualKeyboard/src/charswidget.cpp" line="273"/>
        <source>More</source>
        <translation>Lebih banyak</translation>
    </message>
</context>
<context>
    <name>ConfForm</name>
    <message>
        <source>edit network</source>
        <translation type="vanished">网络属性</translation>
    </message>
    <message>
        <source>LAN name: </source>
        <translation type="vanished">网络名称：</translation>
    </message>
    <message>
        <source>Method: </source>
        <translation type="vanished">编辑IP设置: </translation>
    </message>
    <message>
        <source>Address: </source>
        <translation type="vanished">IP地址: </translation>
    </message>
    <message>
        <source>Netmask: </source>
        <translation type="vanished">子网掩码: </translation>
    </message>
    <message>
        <source>Gateway: </source>
        <translation type="vanished">默认网关: </translation>
    </message>
    <message>
        <source>DNS 1: </source>
        <translation type="vanished">首选DNS: </translation>
    </message>
    <message>
        <source>DNS 2: </source>
        <translation type="vanished">备选DNS: </translation>
    </message>
    <message>
        <source>Edit Conn</source>
        <translation type="vanished">网络设置</translation>
    </message>
    <message>
        <source>Auto(DHCP)</source>
        <translation type="vanished">自动(DHCP)</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="vanished">手动</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">返回</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="obsolete">确定</translation>
    </message>
    <message>
        <source>Can not create new wired network for without wired card</source>
        <translation type="obsolete">缺少有线网卡 无法新建网络</translation>
    </message>
    <message>
        <source>New network already created</source>
        <translation type="obsolete">已创建新的有线网络</translation>
    </message>
    <message>
        <source>New network settings already finished</source>
        <translation type="obsolete">新的网络配置已经完成</translation>
    </message>
    <message>
        <source>Edit Network</source>
        <translation type="obsolete">网络属性</translation>
    </message>
    <message>
        <source>Add Wired Network</source>
        <translation type="obsolete">新建有线网络</translation>
    </message>
    <message>
        <source>create wired network successfully</source>
        <translation type="obsolete">已创建新的有线网络</translation>
    </message>
    <message>
        <source>change configuration of wired network successfully</source>
        <translation type="obsolete">新的设置已经生效</translation>
    </message>
    <message>
        <source>New settings already effective</source>
        <translation type="vanished">新的设置已经生效</translation>
    </message>
    <message>
        <source>There is a same named LAN exsits.</source>
        <translation type="obsolete">已有同名连接存在</translation>
    </message>
</context>
<context>
    <name>CustomAlbumViewer</name>
    <message>
        <location filename="../src/screensaver/customalbumviewer.cpp" line="18"/>
        <source>No photos detected, please re-select them</source>
        <translation>Tiada foto dikesan, sila pilih semula</translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="vanished">指纹</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="vanished">指静脉</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="vanished">虹膜</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="vanished">人脸识别</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="vanished">声纹</translation>
    </message>
    <message>
        <source>Ukey</source>
        <translation type="vanished">安全密钥</translation>
    </message>
    <message>
        <source>QRCode</source>
        <translation type="vanished">二维码</translation>
    </message>
</context>
<context>
    <name>DigitalAuthDialog</name>
    <message>
        <source>LoginByUEdu</source>
        <translation type="vanished">请输入锁屏密码</translation>
    </message>
    <message>
        <source>now is authing, wait a moment</source>
        <translation type="vanished">认证中，请稍后</translation>
    </message>
    <message>
        <source>Password Incorrect, Please try again</source>
        <translation type="obsolete">密码错误，请重试</translation>
    </message>
    <message>
        <source>ResetPWD?</source>
        <translation type="vanished">忘记密码？</translation>
    </message>
    <message>
        <source>SetNewUEduPWD</source>
        <translation type="vanished">设置新锁屏密码</translation>
    </message>
    <message>
        <source>ConfirmNewUEduPWD</source>
        <translation type="vanished">确认新锁屏密码</translation>
    </message>
    <message>
        <source>The two password entries are inconsistent, please reset</source>
        <translation type="vanished">两次密码输入不一致，请重设</translation>
    </message>
    <message>
        <source>Password entered incorrectly, please try again</source>
        <translation type="vanished">密码输入错误，请重试</translation>
    </message>
    <message>
        <source>clear</source>
        <translation type="vanished">清空</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifi</name>
    <message>
        <source>Add Hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">连接设置:</translation>
    </message>
    <message>
        <source>Wi-Fi name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">确定</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiLeap</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="vanished">用户名:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecFast</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">认证:</translation>
    </message>
    <message>
        <source>Anonymous identity</source>
        <translation type="vanished">匿名身份:</translation>
    </message>
    <message>
        <source>Allow automatic PAC pro_visioning</source>
        <translation type="vanished">自动PAC配置:</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation type="vanished">PAC文件:</translation>
    </message>
    <message>
        <source>Inner authentication</source>
        <translation type="vanished">内部认证:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">用户名:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="vanished">隧道 TLS</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="vanished">受保护的 EAP</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation type="vanished">匿名</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation type="vanished">已认证</translation>
    </message>
    <message>
        <source>Both</source>
        <translation type="vanished">两者兼用</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecLeap</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="obsolete">认证:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">用户名:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="obsolete">隧道 TLS</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="obsolete">受保护的 EAP</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecPeap</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="obsolete">认证:</translation>
    </message>
    <message>
        <source>Anonymous identity</source>
        <translation type="obsolete">匿名身份:</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="vanished">域名:</translation>
    </message>
    <message>
        <source>CA certificate</source>
        <translation type="vanished">CA 证书:</translation>
    </message>
    <message>
        <source>CA certificate password</source>
        <translation type="vanished">CA 证书密码:</translation>
    </message>
    <message>
        <source>No CA certificate is required</source>
        <translation type="vanished">不需要CA证书</translation>
    </message>
    <message>
        <source>PEAP version</source>
        <translation type="vanished">PEAP版本:</translation>
    </message>
    <message>
        <source>Inner authentication</source>
        <translation type="obsolete">内部认证:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">用户名:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="obsolete">隧道 TLS</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="obsolete">受保护的 EAP</translation>
    </message>
    <message>
        <source>Choose from file</source>
        <translation type="vanished">从文件选择...</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="vanished">自动</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation type="vanished">版本 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation type="vanished">版本 1</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecPwd</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="obsolete">认证:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">用户名:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="obsolete">隧道 TLS</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="obsolete">受保护的 EAP</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecTls</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="obsolete">认证:</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation type="vanished">身份:</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="obsolete">域名:</translation>
    </message>
    <message>
        <source>CA certificate</source>
        <translation type="obsolete">CA 证书:</translation>
    </message>
    <message>
        <source>CA certificate password</source>
        <translation type="obsolete">CA 证书密码:</translation>
    </message>
    <message>
        <source>No CA certificate is required</source>
        <translation type="vanished">不需要CA证书</translation>
    </message>
    <message>
        <source>User certificate</source>
        <translation type="vanished">用户证书:</translation>
    </message>
    <message>
        <source>User certificate password</source>
        <translation type="vanished">用户证书密码:</translation>
    </message>
    <message>
        <source>User private key</source>
        <translation type="vanished">用户私钥:</translation>
    </message>
    <message>
        <source>User key password</source>
        <translation type="vanished">用户密钥密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="obsolete">隧道 TLS</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="obsolete">受保护的 EAP</translation>
    </message>
    <message>
        <source>Choose from file</source>
        <translation type="obsolete">从文件选择...</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecTunnelTLS</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="obsolete">认证:</translation>
    </message>
    <message>
        <source>Anonymous identity</source>
        <translation type="obsolete">匿名身份:</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="obsolete">域名:</translation>
    </message>
    <message>
        <source>CA certificate</source>
        <translation type="obsolete">CA 证书:</translation>
    </message>
    <message>
        <source>CA certificate password</source>
        <translation type="obsolete">CA 证书密码:</translation>
    </message>
    <message>
        <source>No CA certificate is required</source>
        <translation type="vanished">不需要CA证书</translation>
    </message>
    <message>
        <source>Inner authentication</source>
        <translation type="obsolete">内部认证:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">用户名:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="obsolete">隧道 TLS</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="obsolete">受保护的 EAP</translation>
    </message>
    <message>
        <source>Choose from file</source>
        <translation type="obsolete">从文件选择...</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiWep</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Key</source>
        <translation type="vanished">密钥</translation>
    </message>
    <message>
        <source>WEP index</source>
        <translation type="vanished">WEP 检索</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="obsolete">认证:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>1(default)</source>
        <translation type="vanished">1(默认)</translation>
    </message>
    <message>
        <source>Open System</source>
        <translation type="vanished">开放式系统</translation>
    </message>
    <message>
        <source>Shared Key</source>
        <translation type="vanished">共享密钥</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiWpa</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Add Hidden Wi-Fi</source>
        <translation type="obsolete">加入无线网络</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="obsolete">连接设置:</translation>
    </message>
    <message>
        <source>Wi-Fi name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">连接</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="obsolete">新建...</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
</context>
<context>
    <name>DlgHotspotCreate</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="obsolete">创建个人热点</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="obsolete">网络名称:</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="obsolete">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">密码:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">返回</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="obsolete">确定</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="obsolete">WPA 及 WPA2 个人</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <location filename="../src/widgets/iconedit.cpp" line="120"/>
        <location filename="../src/widgets/iconedit.cpp" line="231"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>InputInfos</name>
    <message>
        <source>Service exception...</source>
        <translation type="vanished">服务异常，重试中...</translation>
    </message>
    <message>
        <source>Invaild parameters...</source>
        <translation type="vanished">参数异常，重试中...</translation>
    </message>
    <message>
        <source>Unknown fault:%1</source>
        <translation type="vanished">未知错误:%1</translation>
    </message>
    <message>
        <source>Recapture(60s)</source>
        <translation type="vanished">重新获取(60s)</translation>
    </message>
    <message>
        <source>Recapture(%1s)</source>
        <translation type="vanished">重新获取(%1s)</translation>
    </message>
    <message>
        <source>Get code</source>
        <translation type="vanished">获取验证码</translation>
    </message>
</context>
<context>
    <name>KBTitle</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="46"/>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="83"/>
        <source>Suspended state</source>
        <translation>Status Terhenti Sementara</translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="57"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="86"/>
        <source>Welt status</source>
        <translation>Status Wel</translation>
    </message>
</context>
<context>
    <name>KylinDBus</name>
    <message>
        <source>kylin network applet desktop message</source>
        <translation type="obsolete">麒麟网络工具信息提示</translation>
    </message>
</context>
<context>
    <name>KylinNM</name>
    <message>
        <source>kylin-nm</source>
        <translation type="vanished">网络工具</translation>
    </message>
    <message>
        <source>LAN</source>
        <translation type="vanished">有线网络</translation>
    </message>
    <message>
        <source>Enabel LAN List</source>
        <translation type="obsolete">其他有线网络</translation>
    </message>
    <message>
        <source>WiFi</source>
        <translation type="obsolete">无线网络</translation>
    </message>
    <message>
        <source>Enabel WiFi List</source>
        <translation type="obsolete">其他无线网络</translation>
    </message>
    <message>
        <source>New WiFi</source>
        <translation type="obsolete">加入其他网络</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="vanished">设置网络</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation type="vanished">有线网络</translation>
    </message>
    <message>
        <source>Connect Hide Network</source>
        <translation type="vanished">加入网络</translation>
    </message>
    <message>
        <source>Wifi</source>
        <translation type="vanished">无线网络</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation type="vanished">已开启</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="vanished">已关闭</translation>
    </message>
    <message>
        <source>HotSpot</source>
        <translation type="vanished">个人热点</translation>
    </message>
    <message>
        <source>FlyMode</source>
        <translation type="vanished">飞行模式</translation>
    </message>
    <message>
        <source>Show MainWindow</source>
        <translation type="vanished">显示网络连接界面</translation>
    </message>
    <message>
        <source>Inactivated LAN</source>
        <translation type="vanished">未激活</translation>
    </message>
    <message>
        <source>Inactivated WLAN</source>
        <translation type="vanished">未激活</translation>
    </message>
    <message>
        <source>Other WLAN</source>
        <translation type="vanished">其他</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation type="vanished">无线局域网</translation>
    </message>
    <message>
        <source>No wireless card detected</source>
        <translation type="obsolete">未检测到无线网卡</translation>
    </message>
    <message>
        <source>Activated LAN</source>
        <translation type="vanished">已激活</translation>
    </message>
    <message>
        <source>Activated WLAN</source>
        <translation type="vanished">已激活</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation type="vanished">未连接任何网络</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="vanished">未连接</translation>
    </message>
    <message>
        <source>No Other Wired Network Scheme</source>
        <translation type="obsolete">列表中无其他有线网络</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="obsolete">编辑</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="obsolete">完成</translation>
    </message>
    <message>
        <source>No wifi connected.</source>
        <translation type="obsolete">未连接任何网络</translation>
    </message>
    <message>
        <source>No Other Wireless Network Scheme</source>
        <translation type="obsolete">未检测到其他无线网络</translation>
    </message>
    <message>
        <source>Wired net is disconnected</source>
        <translation type="obsolete">断开有线网络</translation>
    </message>
    <message>
        <source>Wi-Fi is disconnected</source>
        <translation type="obsolete">断开无线网络</translation>
    </message>
    <message>
        <source>Confirm your Wi-Fi password or usable of wireless card</source>
        <translation type="obsolete">请确认Wi-Fi密码或无线设备</translation>
    </message>
    <message>
        <source>Ethernet Networks</source>
        <translation type="vanished">其他有线网络</translation>
    </message>
    <message>
        <source>New LAN</source>
        <translation type="obsolete">新建有线网络</translation>
    </message>
    <message>
        <source>Hide WiFi</source>
        <translation type="vanished">加入网络</translation>
    </message>
    <message>
        <source>No usable network in the list</source>
        <translation type="obsolete">列表暂无可连接网络</translation>
    </message>
    <message>
        <source>NetOn,</source>
        <translation type="vanished">已连接，</translation>
    </message>
    <message>
        <source>Wifi Networks</source>
        <translation type="vanished">其他无线网络</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">无</translation>
    </message>
    <message>
        <source>keep wired network switch is on before turning on wireless switch</source>
        <translation type="vanished">打开无线网开关前保持有线网开关打开</translation>
    </message>
    <message>
        <source>please insert the wireless network adapter</source>
        <translation type="vanished">请先插入无线网卡</translation>
    </message>
    <message>
        <source>Abnormal connection exist, program will delete it</source>
        <translation type="vanished">正在断开异常连接的网络</translation>
    </message>
    <message>
        <source>update Wi-Fi list now, click again</source>
        <translation type="vanished">正在更新 Wi-Fi列表 请再次点击</translation>
    </message>
    <message>
        <source>update Wi-Fi list now</source>
        <translation type="vanished">正在更新 Wi-Fi列表</translation>
    </message>
    <message>
        <source>Conn Ethernet Success</source>
        <translation type="vanished">连接有线网络成功</translation>
    </message>
    <message>
        <source>Conn Ethernet Fail</source>
        <translation type="vanished">连接有线网络失败</translation>
    </message>
    <message>
        <source>Conn Wifi Success</source>
        <translation type="vanished">连接无线网络成功</translation>
    </message>
</context>
<context>
    <name>LightDMHelper</name>
    <message>
        <location filename="../src/lock-backend/lightdmhelper.cpp" line="138"/>
        <source>failed to start session.</source>
        <translation>gagal memulakan sesi.</translation>
    </message>
    <message>
        <location filename="../src/lock-backend/lightdmhelper.cpp" line="232"/>
        <source>Login</source>
        <translation>Log masuk</translation>
    </message>
    <message>
        <location filename="../src/lock-backend/lightdmhelper.cpp" line="241"/>
        <source>Guest</source>
        <translation>Tetamu</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>Date</source>
        <translation type="vanished">日期</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">时间</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="vanished">游客</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="648"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1957"/>
        <source>SwitchUser</source>
        <translation>Tukar Pengguna</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="584"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1946"/>
        <source>Power</source>
        <translation>Kuasa</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="597"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1949"/>
        <source>VirtualKeyboard</source>
        <translation>Papan Kekunci Maya</translation>
    </message>
    <message>
        <source>Multiple users are logged in at the same time.Are you sure you want to reboot this system?</source>
        <translation type="vanished">同时有多个用户登录系统，您确定要退出系统吗？</translation>
    </message>
    <message>
        <source>LAN</source>
        <translation type="vanished">有线网络</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation type="vanished">无线局域网</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="705"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1963"/>
        <source>SwitchSession</source>
        <translation>Tukar Sesi</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="669"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1960"/>
        <source>Power Information</source>
        <translation>Maklumat Kuasa</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1953"/>
        <location filename="../src/widgets/lockwidget.cpp" line="2224"/>
        <source>Network</source>
        <translation>Rangkaian</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="743"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1966"/>
        <location filename="../src/widgets/lockwidget.cpp" line="2174"/>
        <source>system-monitor</source>
        <translation>pemantau-sistem</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1227"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1969"/>
        <source>Reset Pwd</source>
        <translation>Set Semula Kata Laluan</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1611"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1617"/>
        <source>%1 may cause users who have logged in to this computer to lose content that has not yet been stored,To still perform please click &quot;Confirm&quot;.</source>
        <translation>%1 boleh menyebabkan pengguna yang telah log masuk ke komputer ini kehilangan kandungan yang belum disimpan,Untuk terus melakukan sila klik &quot;Sahkan&quot;.</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1613"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1650"/>
        <source>Restart</source>
        <translation>Mulakan semula</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1649"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1654"/>
        <source>Multiple users are logged in at the same time.Are you sure you want to %1 this system?</source>
        <translation>Berbilang pengguna log masuk pada masa yang sama. Adakah anda pasti anda mahu %1 sistem ini?</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="vanished">重启</translation>
    </message>
    <message>
        <source>PowerOff</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1619"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1655"/>
        <source>Shut Down</source>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="81"/>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="104"/>
        <source>Login Options</source>
        <translation>Pilihan Log Masuk</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="266"/>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="292"/>
        <source>Other</source>
        <translation>Lain</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1064"/>
        <source>FingerPrint</source>
        <translation>Cap Jari</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1066"/>
        <source>FingerVein</source>
        <translation>Vena Jari</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1068"/>
        <source>Iris</source>
        <translation>Iris</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1070"/>
        <source>Face</source>
        <translation>Muka</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1072"/>
        <source>VoicePrint</source>
        <translation>Cetakan Suara</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1074"/>
        <source>Ukey</source>
        <translation>Kunci USB</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1076"/>
        <source>QRCode</source>
        <translation>Kod QR</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">微信</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="685"/>
        <source>Identify device removed!</source>
        <translation>Peranti yang dikenal pasti telah dikeluarkan!</translation>
    </message>
</context>
<context>
    <name>MPRISSaverWidget</name>
    <message>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="230"/>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="419"/>
        <source>No music detected</source>
        <translation>Tiada muzik dikesan</translation>
    </message>
    <message>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="444"/>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="453"/>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
</context>
<context>
    <name>MPRISWidget</name>
    <message>
        <source>Unknown</source>
        <translation type="vanished">未知</translation>
    </message>
</context>
<context>
    <name>MusicFileInformation</name>
    <message>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="199"/>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="235"/>
        <source>Unknown singer</source>
        <translation>Penyanyi Tidak Dikenal</translation>
    </message>
    <message>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="200"/>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="238"/>
        <source>Unknown album</source>
        <translation>Album Tidak Dikenal</translation>
    </message>
</context>
<context>
    <name>MyLineEdit</name>
    <message>
        <source>Verification code</source>
        <translation type="vanished">短信验证码</translation>
    </message>
</context>
<context>
    <name>MyNetworkWidget</name>
    <message>
        <location filename="../src/widgets/mynetworkwidget.cpp" line="52"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/widgets/mynetworkwidget.cpp" line="54"/>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
</context>
<context>
    <name>NumbersWidget</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/numberswidget.cpp" line="175"/>
        <location filename="../src/VirtualKeyboard/src/numberswidget.cpp" line="310"/>
        <source>Return</source>
        <translation>Kembali</translation>
    </message>
</context>
<context>
    <name>OneConnForm</name>
    <message>
        <source>Form</source>
        <translation type="vanished">--</translation>
    </message>
    <message>
        <source>Automatically join the network</source>
        <translation type="vanished">自动加入该网络</translation>
    </message>
    <message>
        <source>Input password</source>
        <translation type="vanished">输入密码</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">连接</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation type="vanished">断开连接</translation>
    </message>
    <message>
        <source>Input Password...</source>
        <translation type="obsolete">输入密码...</translation>
    </message>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <source>Signal：</source>
        <translation type="obsolete">信号强度：</translation>
    </message>
    <message>
        <source>Public</source>
        <translation type="vanished">开放</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="vanished">安全</translation>
    </message>
    <message>
        <source>Rate</source>
        <translation type="vanished">速率</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">无</translation>
    </message>
    <message>
        <source>WiFi Security：</source>
        <translation type="obsolete">WiFi安全性：</translation>
    </message>
    <message>
        <source>MAC：</source>
        <translation type="obsolete">物理地址：</translation>
    </message>
    <message>
        <source>Conn Wifi Failed</source>
        <translation type="vanished">连接无线网络失败</translation>
    </message>
</context>
<context>
    <name>OneLancForm</name>
    <message>
        <source>Form</source>
        <translation type="vanished">--</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">连接</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation type="vanished">断开连接</translation>
    </message>
    <message>
        <source>No Configuration</source>
        <translation type="obsolete">未配置</translation>
    </message>
    <message>
        <source>IPv4：</source>
        <translation type="obsolete">IPv4地址：</translation>
    </message>
    <message>
        <source>IPv6：</source>
        <translation type="obsolete">IPv6地址：</translation>
    </message>
    <message>
        <source>BandWidth：</source>
        <translation type="obsolete">带宽：</translation>
    </message>
    <message>
        <source>MAC：</source>
        <translation type="obsolete">物理地址：</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="obsolete">自动</translation>
    </message>
</context>
<context>
    <name>PasswdCheckUtil</name>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="159"/>
        <source>The password is shorter than %1 characters</source>
        <translation>Kata laluan lebih pendek daripada %1 aksara</translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="162"/>
        <source>The password contains less than %1 character classes</source>
        <translation>Kata laluan mengandungi kurang daripada %1 kategori aksara</translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="165"/>
        <source>The password is the same as the old one</source>
        <translation>Kata laluan sama dengan kata laluan lama</translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="168"/>
        <source>The password contains the user name in some form</source>
        <translation>Kata laluan mengandungi nama pengguna dalam beberapa bentuk</translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="171"/>
        <source>The password differs with case changes only</source>
        <translation>Kata laluan berbeza dengan perubahan kes sahaja</translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="174"/>
        <source>The password is too similar to the old one</source>
        <translation>Kata laluan terlalu serupa dengan kata laluan lama</translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="177"/>
        <source>The password is a palindrome</source>
        <translation>Kata laluan adalah palindrom</translation>
    </message>
</context>
<context>
    <name>PhoneAuthWidget</name>
    <message>
        <source>Verification by phoneNum</source>
        <translation type="vanished">手机号验证</translation>
    </message>
    <message>
        <source>「 Use SMS to verification 」</source>
        <translation type="vanished">「 请使用绑定该账户手机号验证 」</translation>
    </message>
    <message>
        <source>commit</source>
        <translation type="vanished">提交</translation>
    </message>
    <message>
        <source>Network not connected~</source>
        <translation type="vanished">系统未联网，请检查网络连接~</translation>
    </message>
    <message>
        <source>Network unavailable~</source>
        <translation type="vanished">网络状态差，请检查网络连接~</translation>
    </message>
    <message>
        <source>Verification Code invalid!</source>
        <translation type="vanished">验证码失效</translation>
    </message>
    <message>
        <source>Verification Code incorrect.Please retry!</source>
        <translation type="vanished">验证码错误！请填写正确的验证码!</translation>
    </message>
    <message>
        <source>Failed time over limit!Retry after 1 hour!</source>
        <translation type="vanished">验证码错误次数超过10次,1小时后再试</translation>
    </message>
    <message>
        <source>verifaction failed!</source>
        <translation type="vanished">手机验证失败</translation>
    </message>
</context>
<context>
    <name>PowerListWidget</name>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="302"/>
        <location filename="../src/widgets/powerlistwidget.h" line="109"/>
        <source>Hibernate</source>
        <translation>Hibernasi</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="303"/>
        <location filename="../src/widgets/powerlistwidget.h" line="110"/>
        <source>Turn off your computer, but the app stays open, When the computer is turned on, it can be restored to the state you left</source>
        <translation>Langkaukan penutupan penuh komputer, dengan mengekalkan aplikasi dalam keadaan aktif di latar belakang. Semasa komputer dihidupkan semula, keadaan operasi sebelumnya boleh dipulihkan automatik</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="306"/>
        <location filename="../src/widgets/powerlistwidget.h" line="122"/>
        <source>Suspend</source>
        <translation>Tangguh</translation>
    </message>
    <message>
        <source>The computer stays on, but consumes less power. The app stays open and can quickly wake up and revert to where you left off</source>
        <translation type="vanished">电脑保持开机状态，但耗电较少。应用会一直保持打开状态，可快速唤醒电脑并恢复到你离开的状态。</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="310"/>
        <location filename="../src/widgets/powerlistwidget.h" line="172"/>
        <source>Restart</source>
        <translation>Mulakan semula</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="311"/>
        <source>Close all apps, and then restart your computer</source>
        <translation>Sila tutup semua aplikasi, selepas itu hidupkan semula komputer anda</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="313"/>
        <location filename="../src/widgets/powerlistwidget.h" line="196"/>
        <source>Shut Down</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="318"/>
        <location filename="../src/widgets/powerlistwidget.h" line="149"/>
        <source>The current user logs out of the system, terminates the session, and returns to the login page</source>
        <translation>&lt;p&gt;Pengguna semasa log keluar daripada sistem, menamatkan sesi mereka dan kembali ke skrin log masuk &lt;/p&gt;</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="314"/>
        <location filename="../src/widgets/powerlistwidget.h" line="197"/>
        <source>Close all apps, and then shut down your computer</source>
        <translation>Sila tutup semua aplikasi yang sedang berjalan, selepas itu hidupkan semula komputer anda</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="320"/>
        <location filename="../src/widgets/powerlistwidget.h" line="97"/>
        <source>SwitchUser</source>
        <translation>Tukar Pengguna</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="322"/>
        <location filename="../src/widgets/powerlistwidget.h" line="135"/>
        <source>LockScreen</source>
        <translation>Skrin Kunci</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="316"/>
        <location filename="../src/widgets/powerlistwidget.h" line="147"/>
        <source>Log Out</source>
        <translation>Log Keluar</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="307"/>
        <location filename="../src/widgets/powerlistwidget.h" line="123"/>
        <source>The computer stays on, but consumes less power, The app stays open and can quickly wake up and revert to where you left off</source>
        <translation>Komputer kekal hidup tetapi menggunakan tenaga yang lebih sedikit. Aplikasi kekal beroperasi di latar belakang, boleh hidupkan cepat dan kembali ke keadaan sebelumnya anda tinggalkan</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="324"/>
        <location filename="../src/widgets/powerlistwidget.h" line="160"/>
        <source>UpgradeThenRestart</source>
        <translation>Naik Taraf Kemudian Muat Semula</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.h" line="173"/>
        <source>Close all apps, turn off your computer, and then turn your computer back on</source>
        <translation>Tutup semua aplikasi, matikan komputer anda, kemudian hidupkan semula komputer anda</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="326"/>
        <location filename="../src/widgets/powerlistwidget.h" line="184"/>
        <source>UpgradeThenShutdown</source>
        <translation>Naik Taraf Kemudian Matikan</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>lock</source>
        <translation type="vanished">锁定</translation>
    </message>
    <message>
        <source>SwitchUser</source>
        <translation type="vanished">切换用户</translation>
    </message>
    <message>
        <source>logout</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <source>reboot</source>
        <translation type="vanished">重启</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation type="vanished">锁屏</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="vanished">切换用户</translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="vanished">重启</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <source>Close all apps, turn off your computer, and then turn your computer back on</source>
        <translation type="vanished">关闭所有应用，关闭电脑，然后重新打开电脑。</translation>
    </message>
    <message>
        <source>Close all apps, and then shut down your computer</source>
        <translation type="vanished">关闭所有应用，然后关闭电脑。</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <source>Turn off your computer, but the app stays open, When the computer is turned on, it can be restored to the state you left</source>
        <translation type="vanished">关闭电脑，但是应用会一直保持打开状态。当打开电脑时，可以恢复到你离开的状态。</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation type="vanished">休眠</translation>
    </message>
    <message>
        <source>The computer stays on, but consumes less power. The app stays open and can quickly wake up and revert to where you left off</source>
        <translation type="vanished">电脑保持开机状态，但耗电较少。应用会一直保持打开状态，可快速唤醒电脑并恢复到你离开的状态。</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="vanished">睡眠</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation type="vanished">休眠</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/lock-command/main.cpp" line="108"/>
        <source>The screensaver is active.</source>
        <translation>Penjaga skrin telah diaktifkan.</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="110"/>
        <source>The screensaver is inactive.</source>
        <translation>Penjaga skrin belum diaktifkan.</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="28"/>
        <source>FingerPrint</source>
        <translation>Cap Jari</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="30"/>
        <source>FingerVein</source>
        <translation>Vena Jari</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="32"/>
        <source>Iris</source>
        <translation>Iris</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="34"/>
        <source>Face</source>
        <translation>Muka</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="36"/>
        <source>VoicePrint</source>
        <translation>Cetakan Suara</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="38"/>
        <source>Ukey</source>
        <translation>Kunci USB</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="40"/>
        <source>QRCode</source>
        <translation>Kod QR</translation>
    </message>
</context>
<context>
    <name>ResetPwdWidget</name>
    <message>
        <source>Reset your password</source>
        <translation type="vanished">重置密码</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="80"/>
        <source>Security Question</source>
        <translation>Soalan keselamatan</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="81"/>
        <source>Kylin ID</source>
        <translation>ID Kylin</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="160"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="359"/>
        <source>Enter new password</source>
        <translation>Masukkan kata laluan baru</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="184"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="360"/>
        <source>Confirm your password</source>
        <translation>Sahkan kata laluan anda</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="187"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="322"/>
        <source>Inconsistency with pwd</source>
        <translation>Kesalahan padanan kata laluan</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="215"/>
        <source>Confirm</source>
        <translation>Sahkan</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="291"/>
        <source>Contains illegal characters!</source>
        <translation>Mengandungi aksara haram!</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="385"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="456"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="480"/>
        <source>The service is abnormal</source>
        <translation>Perkhidmatan tidak normal</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="393"/>
        <source>The SMS verification code has been sent to the mobile phone with the tail number %1 (Valid for 5 minutes)</source>
        <translation>Kod pengesahan SMS telah dihantar ke telefon bimbit dengan nombor ekor %1 (Sah selama 5 minit)</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="401"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="406"/>
        <source>Failed to get the verification code</source>
        <translation>Gagal mendapatkan kod pengesahan</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="414"/>
        <source>The account does not exist, please re-enter it</source>
        <translation>Akaun tidak wujud, sila masukkan semula</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="462"/>
        <source>The account does not exist, please complete the registration first</source>
        <translation>Akaun tidak wujud, sila mendaftarkan terlebih dahulu</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="465"/>
        <source>The user is already locked, contact the administrator to unlock it</source>
        <translation>Pengguna telah terkunci, hubungi pentadbir untuk membuka kuncinya</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="468"/>
        <source>If there are too many login errors, please try again in 5 minutes</source>
        <translation>Jika terdapat terlalu banyak kali gagal log masuk, sila cuba lagi dalam masa 5 minit</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="471"/>
        <source>The SMS verification code is incorrect or has expired</source>
        <translation>Kod pengesahan SMS tidak betul atau telah tamat tempoh</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="474"/>
        <source>Wrong username or password</source>
        <translation>Nama pengguna atau kata laluan salah</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="477"/>
        <source>Password decryption error</source>
        <translation>Kesalahan penyahkodan kata laluan</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="547"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="575"/>
        <source>Verify Kylin ID Reset Password</source>
        <translation>Sahkan Tetapkan Semula Kata Laluan Kylin ID</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="550"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="569"/>
        <source>Answer the security questions and reset your password</source>
        <translation>Jawab soalan keselamatan dan tetapkan semula kata laluan anda</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="604"/>
        <source>One or more wrong answers</source>
        <translation>Satu atau lebih jawapan yang salah</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="308"/>
        <source></source>
        <comment>tablet device</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <source>exit(Esc)</source>
        <translation type="vanished">退出(Esc)</translation>
    </message>
    <message>
        <source>exit</source>
        <translation type="vanished">退出</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="155"/>
        <source>Picture does not exist</source>
        <translation>Gambar tidak wujud</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1794"/>
        <location filename="../src/screensaver/screensaver.cpp" line="1796"/>
        <source>Not connected to a network</source>
        <translation>Tidak disambungkan ke rangkaian</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1800"/>
        <location filename="../src/screensaver/screensaver.cpp" line="1802"/>
        <source>The weather update failed</source>
        <translation>Kemas kini cuaca gagal</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1887"/>
        <source>Smart Saver</source>
        <translation>Pelindung Pintar</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1961"/>
        <source>Weather</source>
        <translation>Cuaca</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1989"/>
        <source>Music</source>
        <translation>Muzik</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="2020"/>
        <source>Photo Albun</source>
        <translation>Album Foto</translation>
    </message>
    <message>
        <source>Set as desktop wallpaper</source>
        <translation type="vanished">设置为桌面壁纸</translation>
    </message>
    <message>
        <source>Automatic switching</source>
        <translation type="vanished">自动切换</translation>
    </message>
    <message>
        <source>You have %1 unread message</source>
        <translation type="obsolete">您有%1条未读消息</translation>
    </message>
    <message>
        <source>You have new notification</source>
        <translation type="vanished">您有新的消息</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="158"/>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
</context>
<context>
    <name>SleepTime</name>
    <message>
        <source>You have rested:</source>
        <translation type="vanished">您已休息:</translation>
    </message>
    <message>
        <location filename="../src/screensaver/sleeptime.cpp" line="75"/>
        <source>You have rested</source>
        <translation>Anda telah berehat</translation>
    </message>
</context>
<context>
    <name>SureWindow</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">--</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="vanished">确认</translation>
    </message>
    <message>
        <source>Multiple users are logged in at the same time.Are you sure you want to reboot this system?</source>
        <translation type="vanished">同时有多个用户登录系统，您确定要退出系统吗？</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from suspend!</source>
        <translation type="vanished">以下程序正在运行，阻止系统进入睡眠！</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from hibernate!</source>
        <translation type="vanished">以下程序正在运行，阻止系统进入休眠！</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from shutting down!</source>
        <translation type="vanished">以下程序正在运行，阻止系统关机！</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from reboot!</source>
        <translation type="vanished">以下程序正在运行，阻止系统重启！</translation>
    </message>
</context>
<context>
    <name>SwitchButton</name>
    <message>
        <source>login by password</source>
        <translation type="vanished">密码登录</translation>
    </message>
    <message>
        <source>login by qr code</source>
        <translation type="vanished">微信登录</translation>
    </message>
</context>
<context>
    <name>SwitchButtonGroup</name>
    <message>
        <source>uEduPWD</source>
        <translation type="vanished">密码登录</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">微信登录</translation>
    </message>
</context>
<context>
    <name>TabletLockWidget</name>
    <message>
        <source>You have %1 unread message</source>
        <translation type="vanished">您有%1条未读消息</translation>
    </message>
    <message>
        <source>Slide to unlock</source>
        <translation type="vanished">向上滑动解锁</translation>
    </message>
    <message>
        <source>New password is the same as old</source>
        <translation type="vanished">新密码与原密码相同</translation>
    </message>
    <message>
        <source>Reset password error:%1</source>
        <translation type="vanished">重置密码失败:%1</translation>
    </message>
    <message>
        <source>Please scan by correct WeChat</source>
        <translation type="vanished">请使用正确的微信扫码</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">返回</translation>
    </message>
    <message>
        <source>Skip</source>
        <translation type="vanished">跳过</translation>
    </message>
</context>
<context>
    <name>TalksWidget</name>
    <message>
        <location filename="../src/widgets/talkswidget.cpp" line="58"/>
        <source>Enter your answer</source>
        <translation>Masukkan jawapan anda</translation>
    </message>
</context>
<context>
    <name>UserListWidget</name>
    <message>
        <location filename="../src/widgets/userlistwidget.cpp" line="67"/>
        <location filename="../src/widgets/userlistwidget.cpp" line="121"/>
        <source>Login</source>
        <translation>Log masuk</translation>
    </message>
    <message>
        <location filename="../src/widgets/userlistwidget.cpp" line="69"/>
        <location filename="../src/widgets/userlistwidget.cpp" line="123"/>
        <source>Guest</source>
        <translation>Tetamu</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>kylin network applet desktop message</source>
        <translation type="obsolete">麒麟网络工具信息提示</translation>
    </message>
</context>
<context>
    <name>VerificationWidget</name>
    <message>
        <source>Please scan by bound WeChat</source>
        <translation type="vanished">请使用已绑定的微信扫码</translation>
    </message>
</context>
<context>
    <name>VerifyKyidWidget</name>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="45"/>
        <source>Enter your Kylin ID account</source>
        <translation>Masukkan akaun Kylin ID anda</translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="64"/>
        <source>Input password</source>
        <translation>Masukkan Kata laluan</translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="77"/>
        <source>Enter the verification code</source>
        <translation>Masukkan kod pengesahan</translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="84"/>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="109"/>
        <source>Get verification code</source>
        <translation>Dapatkan kod pengesahan</translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="112"/>
        <source>Reacquire(%1)</source>
        <translation>Perolehi semula(%1)</translation>
    </message>
</context>
<context>
    <name>VerticalVerificationWidget</name>
    <message>
        <source>Please scan by bound WeChat</source>
        <translation type="obsolete">请使用已绑定的微信扫码</translation>
    </message>
</context>
<context>
    <name>WeChatAuthDialog</name>
    <message>
        <source>Login by wechat</source>
        <translation type="vanished">微信登录</translation>
    </message>
    <message>
        <source>Verification by wechat</source>
        <translation type="vanished">微信验证</translation>
    </message>
    <message>
        <source>「 Use registered WeChat account to login 」</source>
        <translation type="vanished">「 使用已注册的微信号登录 」</translation>
    </message>
    <message>
        <source>「 Use bound WeChat account to verification 」</source>
        <translation type="vanished">「 请使用绑定该账号的微信验证 」</translation>
    </message>
    <message>
        <source>Network not connected~</source>
        <translation type="vanished">系统未联网，请检查网络连接~</translation>
    </message>
    <message>
        <source>Scan code successfully</source>
        <translation type="vanished">扫码成功</translation>
    </message>
    <message>
        <source>Timeout!Try again!</source>
        <translation type="vanished">超时!请重新扫码!</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation type="vanished">登录失败</translation>
    </message>
</context>
<context>
    <name>WeatherWidget</name>
    <message>
        <source>Not connected to a network</source>
        <translation type="vanished">网络未连接</translation>
    </message>
</context>
<context>
    <name>delay</name>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="62"/>
        <source>how long to show lock</source>
        <translation>Berapa lama untuk menunjukkan kunci</translation>
    </message>
</context>
<context>
    <name>has-lock</name>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="67"/>
        <source>if show lock</source>
        <translation>Adakah tunjukkan kunci</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/lock-command/main.cpp" line="44"/>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation>Mulakan arahan untuk Pelindung Skrin ukui.</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="49"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="46"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="48"/>
        <source>lock the screen immediately</source>
        <translation>Segera Kunci Skrin</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="52"/>
        <source>query the status of the screen saver</source>
        <translation>Tanya status pelindung skrin</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="55"/>
        <source>unlock the screen saver</source>
        <translation>Buka kunci pelindung skrin</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="57"/>
        <source>show the screensaver</source>
        <translation>tunjukkan pelindung skrin</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="63"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="70"/>
        <source>show the session tools</source>
        <translation>Tunjukkan alatan sesi</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="68"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="80"/>
        <source>show the app block window</source>
        <translation>Tunjukkan tetingkap blok aplikasi</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="73"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="85"/>
        <source>show the multiUsers block window</source>
        <translation>tunjukkan tetingkap blok berbilang pengguna</translation>
    </message>
    <message>
        <location filename="../src/lock-backend/main.cpp" line="63"/>
        <source>Backend for the ukui ScreenSaver.</source>
        <translation>Bahagian belakang untuk Pelindung Skrin ukui.</translation>
    </message>
</context>
</TS>
