<?xml version="1.0" encoding="utf-8"?>
<!--
   Copyright (C) 2023 KylinSoft Co., Ltd.
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, see &lt;http://www.gnu.org/licenses/&gt;.
 -->
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Screenlock</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="39"/>
        <source>Screenlock</source>
        <translation>Bildschirmsperre</translation>
    </message>
    <message>
        <source>Screenlock Interface</source>
        <translation type="vanished">锁屏界面</translation>
    </message>
    <message>
        <source>Show message on lock screen</source>
        <translation type="vanished">Nachricht auf dem Sperrbildschirm anzeigen</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="vanished">浏览</translation>
    </message>
    <message>
        <source>Online Picture</source>
        <translation type="vanished">线上图片</translation>
    </message>
    <message>
        <source>Local Pictures</source>
        <translation type="vanished">Lokale Bilder</translation>
    </message>
    <message>
        <source>Online Pictures</source>
        <translation type="vanished">Online-Bilder</translation>
    </message>
    <message>
        <source>Reset To Default</source>
        <translation type="vanished">Auf Standard zurücksetzen</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="vanished">Verwandte Einstellungen</translation>
    </message>
    <message>
        <source>Screenlock Set</source>
        <translation type="vanished">锁屏设置</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">激活屏保时锁定屏幕</translation>
    </message>
    <message>
        <source>Lock screen delay</source>
        <translation type="vanished">Verzögerung des Sperrbildschirms</translation>
    </message>
    <message>
        <source>Min</source>
        <translation type="vanished">分钟</translation>
    </message>
    <message>
        <source>Select screenlock background</source>
        <translation type="vanished">选择锁屏背景</translation>
    </message>
    <message>
        <source>Browser online wp</source>
        <translation type="vanished">浏览线上壁纸</translation>
    </message>
    <message>
        <source>Browser local wp</source>
        <translation type="vanished">浏览本地壁纸</translation>
    </message>
    <message>
        <source>Show picture of screenlock on screenlogin</source>
        <translation type="vanished">Bild der Bildschirmsperre beim Screenlogin anzeigen</translation>
    </message>
    <message>
        <source>Enabel screenlock</source>
        <translation type="vanished">开启锁屏</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="obsolete">浏览</translation>
    </message>
    <message>
        <source>screenlock</source>
        <translation type="vanished">锁屏</translation>
    </message>
    <message>
        <source>picture</source>
        <translation type="obsolete">图片</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">Nie</translation>
    </message>
    <message>
        <source>1m</source>
        <translation type="vanished">1m</translation>
    </message>
    <message>
        <source>5m</source>
        <translation type="vanished">5m</translation>
    </message>
    <message>
        <source>10m</source>
        <translation type="vanished">10m</translation>
    </message>
    <message>
        <source>30m</source>
        <translation type="vanished">30m</translation>
    </message>
    <message>
        <source>45m</source>
        <translation type="vanished">45m</translation>
    </message>
    <message>
        <source>1h</source>
        <translation type="vanished">1h</translation>
    </message>
    <message>
        <source>1.5h</source>
        <translation type="vanished">1.5h</translation>
    </message>
    <message>
        <source>3h</source>
        <translation type="vanished">3h</translation>
    </message>
    <message>
        <source>2h</source>
        <translation type="vanished">2h</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="187"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</source>
        <translation>Hintergrunddateien (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</translation>
    </message>
    <message>
        <source>allFiles(*.*)</source>
        <translation type="vanished">所有文件(*.*)</translation>
    </message>
    <message>
        <source>1min</source>
        <translation type="vanished">1min</translation>
    </message>
    <message>
        <source>5min</source>
        <translation type="vanished">5min</translation>
    </message>
    <message>
        <source>10min</source>
        <translation type="vanished">10min</translation>
    </message>
    <message>
        <source>30min</source>
        <translation type="vanished">30 Minuten</translation>
    </message>
    <message>
        <source>45min</source>
        <translation type="vanished">45 Minuten</translation>
    </message>
    <message>
        <source>1hour</source>
        <translation type="vanished">1 Stunde</translation>
    </message>
    <message>
        <source>2hour</source>
        <translation type="vanished">2 Stunden</translation>
    </message>
    <message>
        <source>3hour</source>
        <translation type="vanished">3 Stunden</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="275"/>
        <source>Your system does not have any browser application installed or the default browser application is not set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="276"/>
        <source>Unable to open browser application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="348"/>
        <source>select custom wallpaper file</source>
        <translation>Wählen Sie eine benutzerdefinierte Hintergrundbilddatei aus</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="230"/>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="231"/>
        <source>Position: </source>
        <translation>Position: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="232"/>
        <source>FileName: </source>
        <translation>Dateiname: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="233"/>
        <source>FileType: </source>
        <translation>Dateityp: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="234"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Monitor Off</source>
        <translation type="vanished">Monitor aus</translation>
    </message>
    <message>
        <source>Screensaver</source>
        <translation type="vanished">Bildschirmschoner</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="vanished">Garnitur</translation>
    </message>
</context>
<context>
    <name>ScreenlockUi</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="74"/>
        <source>Show picture of screenlock on screenlogin</source>
        <translation type="unfinished">Bild der Bildschirmsperre beim Screenlogin anzeigen</translation>
        <extra-contents_path>/Screenlock/Show picture of screenlock on screenlogin</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="87"/>
        <source>Leave lock (System will be locked when the paired phone gone)</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screenlock/Leave lock (System will be locked when the paired phone gone)</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="97"/>
        <source>Specified device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="114"/>
        <source>No paired phone. Please turn to &apos;Bluetooth&apos; to pair.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="53"/>
        <source>Screenlock</source>
        <translation type="unfinished">Bildschirmsperre</translation>
        <extra-contents_path>/Screenlock/Screenlock</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="168"/>
        <source>Choose Picture</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Wallpaper/Choose Picture</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="172"/>
        <source>Local Pictures</source>
        <translation type="unfinished">Lokale Bilder</translation>
        <extra-contents_path>/Screenlock/Local Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="176"/>
        <source>Online Pictures</source>
        <translation type="unfinished">Online-Bilder</translation>
        <extra-contents_path>/Screenlock/Online Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="180"/>
        <source>Reset To Default</source>
        <translation type="unfinished">Auf Standard zurücksetzen</translation>
        <extra-contents_path>/Screenlock/Reset To Default</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="122"/>
        <source>Bluetooth</source>
        <translation type="unfinished">蓝牙</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="239"/>
        <source>No bluetooth adapter detected, can not use Leave Lock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="203"/>
        <source>Monitor Off</source>
        <translation type="unfinished">Monitor aus</translation>
        <extra-contents_path>/Screenlock/Monitor Off</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="205"/>
        <source>Screensaver</source>
        <translation type="unfinished">Bildschirmschoner</translation>
        <extra-contents_path>/Screenlock/Screensaver</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="200"/>
        <source>Related Settings</source>
        <translation type="unfinished">Verwandte Einstellungen</translation>
        <extra-contents_path>/Screenlock/Related Settings</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="204"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="206"/>
        <source>Set</source>
        <translation type="unfinished">Garnitur</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="266"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="647"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="681"/>
        <source>Please select device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="44"/>
        <source>Screensaver</source>
        <translation>Bildschirmschoner</translation>
    </message>
    <message>
        <source>Idle time</source>
        <translation type="vanished">Stillstandszeit</translation>
    </message>
    <message>
        <source>Lock screen when activating screensaver</source>
        <translation type="vanished">Sperrbildschirm beim Aktivieren des Bildschirmschoners</translation>
    </message>
    <message>
        <source>Enable screensaver</source>
        <translation type="vanished">开启屏保</translation>
    </message>
    <message>
        <source>Screensaver program</source>
        <translation type="vanished">Bildschirmschoner-Programm</translation>
    </message>
    <message>
        <source>idle time</source>
        <translation type="vanished">等待时间</translation>
    </message>
    <message>
        <source>Min</source>
        <translation type="vanished">分钟</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">Sperrbildschirm beim Starten des Bildschirmschoners</translation>
    </message>
    <message>
        <source>screensaver</source>
        <translation type="vanished">屏保</translation>
    </message>
    <message>
        <source>Default_ukui</source>
        <translation type="vanished">默认屏保</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Ansehen</translation>
    </message>
    <message>
        <source>Text(up to 30 characters):</source>
        <translation type="vanished">Text (bis zu 30 Zeichen):</translation>
    </message>
    <message>
        <source>Show rest time</source>
        <translation type="vanished">Ruhezeit anzeigen</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="182"/>
        <source>UKUI</source>
        <translation>UKUI</translation>
    </message>
    <message>
        <source>Blank_Only</source>
        <translation type="vanished">Blank_Only</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="182"/>
        <source>Customize</source>
        <translation>Anpassen</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="170"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="189"/>
        <source>5min</source>
        <translation>5min</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="170"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="189"/>
        <source>10min</source>
        <translation>10min</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="170"/>
        <source>15min</source>
        <translation>15 Minuten</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="170"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="189"/>
        <source>30min</source>
        <translation>30 Minuten</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="170"/>
        <source>1hour</source>
        <translation>1 Stunde</translation>
    </message>
    <message>
        <source>Screensaver source</source>
        <translation type="vanished">Quelle des Bildschirmschoners</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="vanished">Auswählen</translation>
    </message>
    <message>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation type="vanished">Hintergrundbilder (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</translation>
    </message>
    <message>
        <source>select custom screensaver dir</source>
        <translation type="vanished">Benutzerdefiniertes Bildschirmschoner-Verzeichnis auswählen</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation type="vanished">Position: </translation>
    </message>
    <message>
        <source>FileName: </source>
        <translation type="vanished">Dateiname: </translation>
    </message>
    <message>
        <source>FileType: </source>
        <translation type="vanished">Dateityp: </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Abbrechen</translation>
    </message>
    <message>
        <source>Switching time</source>
        <translation type="vanished">Schaltzeit</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="176"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="189"/>
        <source>1min</source>
        <translation>1min</translation>
    </message>
    <message>
        <source>Ordinal</source>
        <translation type="vanished">Ordinale</translation>
    </message>
    <message>
        <source>Random switching</source>
        <translation type="vanished">Zufällige Umschaltung</translation>
    </message>
    <message>
        <source>Display text</source>
        <translation type="vanished">显示文本</translation>
    </message>
    <message>
        <source>Enter text, up to 30 characters</source>
        <translation type="vanished">输入文本，最多30个字符</translation>
    </message>
    <message>
        <source>Text position</source>
        <translation type="vanished">Position des Textes</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation type="vanished">Zentriert</translation>
    </message>
    <message>
        <source>Randow(Bubble text)</source>
        <translation type="vanished">Randow(Sprechblasentext)</translation>
    </message>
    <message>
        <source>1m</source>
        <translation type="vanished">1m</translation>
    </message>
    <message>
        <source>5m</source>
        <translation type="vanished">5m</translation>
    </message>
    <message>
        <source>10m</source>
        <translation type="vanished">10m</translation>
    </message>
    <message>
        <source>30m</source>
        <translation type="vanished">30m</translation>
    </message>
    <message>
        <source>45m</source>
        <translation type="vanished">45m</translation>
    </message>
    <message>
        <source>1h</source>
        <translation type="vanished">1h</translation>
    </message>
    <message>
        <source>1.5h</source>
        <translation type="vanished">1.5h</translation>
    </message>
    <message>
        <source>3h</source>
        <translation type="vanished">3h</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="vanished">Zufällig</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="170"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>ScreensaverUi</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="41"/>
        <source>Screensaver</source>
        <translation type="unfinished">Bildschirmschoner</translation>
        <extra-contents_path>/Screensaver/Screensaver</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="54"/>
        <source>Idle time</source>
        <translation type="unfinished">Stillstandszeit</translation>
        <extra-contents_path>/Screensaver/Idle time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="56"/>
        <source>Screensaver program</source>
        <translation type="unfinished">Bildschirmschoner-Programm</translation>
        <extra-contents_path>/Screensaver/Screensaver program</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="88"/>
        <source>Screensaver source</source>
        <translation type="unfinished">Quelle des Bildschirmschoners</translation>
        <extra-contents_path>/Screensaver/Screensaver source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="93"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="457"/>
        <source>Select</source>
        <translation type="unfinished">Auswählen</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="114"/>
        <source>Ordinal</source>
        <translation type="unfinished">Ordinale</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="115"/>
        <source>Random</source>
        <translation type="unfinished">Zufällig</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="122"/>
        <source>Random switching</source>
        <translation type="unfinished">Zufällige Umschaltung</translation>
        <extra-contents_path>/Screensaver/Random switching</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="142"/>
        <source>Switching time</source>
        <translation type="unfinished">Schaltzeit</translation>
        <extra-contents_path>/Screensaver/Switching time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="161"/>
        <source>Text(up to 30 characters):</source>
        <translation type="unfinished">Text (bis zu 30 Zeichen):</translation>
        <extra-contents_path>/Screensaver/Text(up to 30 characters):</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="184"/>
        <source>Text position</source>
        <translation type="unfinished">Position des Textes</translation>
        <extra-contents_path>/Screensaver/Text position</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="192"/>
        <source>Centered</source>
        <translation type="unfinished">Zentriert</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="193"/>
        <source>Randow(Bubble text)</source>
        <translation type="unfinished">Randow(Sprechblasentext)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="215"/>
        <source>Show rest time</source>
        <translation type="unfinished">Ruhezeit anzeigen</translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="226"/>
        <source>Lock screen when screensaver boot</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Lock screen when screensaver boot</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="415"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation type="unfinished">Hintergrundbilder (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="456"/>
        <source>select custom screensaver dir</source>
        <translation type="unfinished">Benutzerdefiniertes Bildschirmschoner-Verzeichnis auswählen</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="458"/>
        <source>Position: </source>
        <translation type="unfinished">Position: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="459"/>
        <source>FileName: </source>
        <translation type="unfinished">Dateiname: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="460"/>
        <source>FileType: </source>
        <translation type="unfinished">Dateityp: </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="461"/>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
</TS>
