<?xml version="1.0" encoding="utf-8"?>
<!--
   Copyright (C) 2023 KylinSoft Co., Ltd.
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, see &lt;http://www.gnu.org/licenses/&gt;.
 --><!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>PhotoCorver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="60"/>
        <source>Right open the file location</source>
        <translation>ngay tại vị trí mở tệp</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="64"/>
        <source>Remove the file</source>
        <translation>loại bỏ tệp</translation>
    </message>
</context>
<context>
    <name>Screenlock</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="39"/>
        <source>Screenlock</source>
        <translation>Khóa màn hình</translation>
    </message>
    <message>
        <source>Screenlock Interface</source>
        <translation type="vanished">锁屏界面</translation>
    </message>
    <message>
        <source>Show message on lock screen</source>
        <translation type="vanished">锁屏时显示消息</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="vanished">相关设置</translation>
    </message>
    <message>
        <source>Screenlock Set</source>
        <translation type="vanished">锁屏设置</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">激活屏保时锁定屏幕</translation>
    </message>
    <message>
        <source>Lock screen delay</source>
        <translation type="vanished">此时间段后锁屏</translation>
    </message>
    <message>
        <source>Min</source>
        <translation type="vanished">分钟</translation>
    </message>
    <message>
        <source>Select screenlock background</source>
        <translation type="vanished">选择锁屏背景</translation>
    </message>
    <message>
        <source>Browser online wp</source>
        <translation type="vanished">浏览线上壁纸</translation>
    </message>
    <message>
        <source>Browser local wp</source>
        <translation type="vanished">浏览本地壁纸</translation>
    </message>
    <message>
        <source>Show picture of screenlock on screenlogin</source>
        <translation type="vanished">显示锁屏壁纸在登录界面</translation>
    </message>
    <message>
        <source>Enabel screenlock</source>
        <translation type="vanished">开启锁屏</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="obsolete">浏览</translation>
    </message>
    <message>
        <source>screenlock</source>
        <translation type="vanished">锁屏</translation>
    </message>
    <message>
        <source>picture</source>
        <translation type="obsolete">图片</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">从不</translation>
    </message>
    <message>
        <source>1m</source>
        <translation type="vanished">1m</translation>
    </message>
    <message>
        <source>5m</source>
        <translation type="vanished">5m</translation>
    </message>
    <message>
        <source>10m</source>
        <translation type="vanished">10m</translation>
    </message>
    <message>
        <source>30m</source>
        <translation type="vanished">30m</translation>
    </message>
    <message>
        <source>45m</source>
        <translation type="vanished">45m</translation>
    </message>
    <message>
        <source>1h</source>
        <translation type="vanished">1h</translation>
    </message>
    <message>
        <source>1.5h</source>
        <translation type="vanished">1.5h</translation>
    </message>
    <message>
        <source>3h</source>
        <translation type="vanished">3h</translation>
    </message>
    <message>
        <source>2h</source>
        <translation type="vanished">2h</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="187"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</source>
        <translation>Tệp ảnh (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</translation>
    </message>
    <message>
        <source>allFiles(*.*)</source>
        <translation type="vanished">所有文件(*.*)</translation>
    </message>
    <message>
        <source>1min</source>
        <translation type="vanished">1分钟</translation>
    </message>
    <message>
        <source>5min</source>
        <translation type="vanished">5分钟</translation>
    </message>
    <message>
        <source>10min</source>
        <translation type="vanished">10分钟</translation>
    </message>
    <message>
        <source>30min</source>
        <translation type="vanished">30分钟</translation>
    </message>
    <message>
        <source>45min</source>
        <translation type="vanished">45分钟</translation>
    </message>
    <message>
        <source>1hour</source>
        <translation type="vanished">1小时</translation>
    </message>
    <message>
        <source>2hour</source>
        <translation type="vanished">2小时</translation>
    </message>
    <message>
        <source>3hour</source>
        <translation type="vanished">3小时</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="275"/>
        <source>Your system does not have any browser application installed or the default browser application is not set up</source>
        <translation>Hệ thống của bạn không có bất kỳ ứng dụng trình duyệt nào được cài đặt hoặc ứng dụng trình duyệt mặc định không được thiết lập</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="276"/>
        <source>Unable to open browser application</source>
        <translation>không thể mở ứng dụng</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="348"/>
        <source>select custom wallpaper file</source>
        <translation>Chọn tệp hình nền tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="230"/>
        <source>Select</source>
        <translation>Chọn</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="231"/>
        <source>Position: </source>
        <translation>Vị trí </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="232"/>
        <source>FileName: </source>
        <translation>Tên tệp </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="233"/>
        <source>FileType: </source>
        <translation>Loại </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="234"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Monitor Off</source>
        <translation type="vanished">关闭显示器</translation>
    </message>
    <message>
        <source>Screensaver</source>
        <translation type="vanished">屏幕保护</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="vanished">去设置</translation>
    </message>
</context>
<context>
    <name>ScreenlockUi</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="74"/>
        <source>Show picture of screenlock on screenlogin</source>
        <translation>Hiển thị hình nền màn hình khóa ở giao diện đăng nhập</translation>
        <extra-contents_path>/Screenlock/Show picture of screenlock on screenlogin</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="87"/>
        <source>Leave lock (System will be locked when the paired phone gone)</source>
        <translation>khóa động thái (Hệ thống sẽ bị khóa khi điện thoại được kết nối bị ngắt)</translation>
        <extra-contents_path>/Screenlock/Leave lock (System will be locked when the paired phone gone)</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="97"/>
        <source>Specified device</source>
        <translation>thiết bị chỉ định</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="114"/>
        <source>No paired phone. Please turn to &apos;Bluetooth&apos; to pair.</source>
        <translation>không có điện thoại được kết nối. vui lòng bật kết nối Bluetooth để kết nối.</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="53"/>
        <source>Screenlock</source>
        <translation>Khóa màn hình</translation>
        <extra-contents_path>/Screenlock/Screenlock</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="168"/>
        <source>Choose Picture</source>
        <translation>Chọn hình ảnh</translation>
        <extra-contents_path>/Wallpaper/Choose Picture</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="172"/>
        <source>Local Pictures</source>
        <translation>Ảnh cục bộ</translation>
        <extra-contents_path>/Screenlock/Local Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="176"/>
        <source>Online Pictures</source>
        <translation>Ảnh trực tuyến</translation>
        <extra-contents_path>/Screenlock/Online Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="180"/>
        <source>Reset To Default</source>
        <translation>Khôi phục về mặc định</translation>
        <extra-contents_path>/Screenlock/Reset To Default</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="122"/>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="239"/>
        <source>No bluetooth adapter detected, can not use Leave Lock.</source>
        <translation>không phát hiện bộ điều hợp Bluetooth, không thể dùng Khóa động thái.</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="203"/>
        <source>Monitor Off</source>
        <translation>Tắt màn hình</translation>
        <extra-contents_path>/Screenlock/Monitor Off</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="205"/>
        <source>Screensaver</source>
        <translation>bảo vệ màn hình</translation>
        <extra-contents_path>/Screenlock/Screensaver</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="200"/>
        <source>Related Settings</source>
        <translation>Cài đặt liên quan</translation>
        <extra-contents_path>/Screenlock/Related Settings</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="204"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="206"/>
        <source>Set</source>
        <translation>Cài đặt</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="266"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="647"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="681"/>
        <source>Please select device</source>
        <translation>vui lòng chọn thiết bị</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="84"/>
        <source>The date and time are displayed</source>
        <translation>hiển thị thời gian ngày tháng</translation>
        <extra-contents_path>/Screenlock/The date and time are displayed</extra-contents_path>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="51"/>
        <source>Screensaver</source>
        <translation>bảo vệ màn hình</translation>
    </message>
    <message>
        <source>Idle time</source>
        <translation type="vanished">此时间段后开启屏保</translation>
    </message>
    <message>
        <source>Lock screen when activating screensaver</source>
        <translation type="vanished">激活屏保时锁住屏幕</translation>
    </message>
    <message>
        <source>Enable screensaver</source>
        <translation type="vanished">开启屏保</translation>
    </message>
    <message>
        <source>Screensaver program</source>
        <translation type="vanished">屏幕保护程序</translation>
    </message>
    <message>
        <source>idle time</source>
        <translation type="vanished">等待时间</translation>
    </message>
    <message>
        <source>Min</source>
        <translation type="vanished">分钟</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">激活屏保时锁定屏幕</translation>
    </message>
    <message>
        <source>screensaver</source>
        <translation type="vanished">屏保</translation>
    </message>
    <message>
        <source>Default_ukui</source>
        <translation type="vanished">默认屏保</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">预览</translation>
    </message>
    <message>
        <source>Text(up to 30 characters):</source>
        <translation type="vanished">屏保文本(最多30个字):</translation>
    </message>
    <message>
        <source>Show rest time</source>
        <translation type="vanished">显示休息时间</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="189"/>
        <source>UKUI</source>
        <translation>UKUI</translation>
    </message>
    <message>
        <source>Blank_Only</source>
        <translation type="vanished">黑屏</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="189"/>
        <source>Customize</source>
        <translation>Tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="177"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="202"/>
        <source>5min</source>
        <translation>5 phút</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="177"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="202"/>
        <source>10min</source>
        <translation>10 phút</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="177"/>
        <source>15min</source>
        <translation>15 phút</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="177"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="202"/>
        <source>30min</source>
        <translation>30 phút</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="177"/>
        <source>1hour</source>
        <translation>1 giờ</translation>
    </message>
    <message>
        <source>Screensaver source</source>
        <translation type="vanished">屏保来源</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="vanished">选择</translation>
    </message>
    <message>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation type="vanished">壁纸文件(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</translation>
    </message>
    <message>
        <source>select custom screensaver dir</source>
        <translation type="vanished">选择自定义屏保路径</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation type="vanished">位置:</translation>
    </message>
    <message>
        <source>FileName: </source>
        <translation type="vanished">文件名:</translation>
    </message>
    <message>
        <source>FileType: </source>
        <translation type="vanished">文件类型:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Switching time</source>
        <translation type="vanished">切换频率</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="183"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="202"/>
        <source>1min</source>
        <translation>1 phút</translation>
    </message>
    <message>
        <source>Ordinal</source>
        <translation type="vanished">按顺序</translation>
    </message>
    <message>
        <source>Random switching</source>
        <translation type="vanished">随机切换</translation>
    </message>
    <message>
        <source>Display text</source>
        <translation type="vanished">显示文本</translation>
    </message>
    <message>
        <source>Enter text, up to 30 characters</source>
        <translation type="vanished">输入文本，最多30个字符</translation>
    </message>
    <message>
        <source>Text position</source>
        <translation type="vanished">文本位置</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation type="vanished">居中</translation>
    </message>
    <message>
        <source>Randow(Bubble text)</source>
        <translation type="vanished">随机(气泡文本)</translation>
    </message>
    <message>
        <source>1m</source>
        <translation type="vanished">1m</translation>
    </message>
    <message>
        <source>5m</source>
        <translation type="vanished">5m</translation>
    </message>
    <message>
        <source>10m</source>
        <translation type="vanished">10m</translation>
    </message>
    <message>
        <source>30m</source>
        <translation type="vanished">30m</translation>
    </message>
    <message>
        <source>45m</source>
        <translation type="vanished">45m</translation>
    </message>
    <message>
        <source>1h</source>
        <translation type="vanished">1h</translation>
    </message>
    <message>
        <source>1.5h</source>
        <translation type="vanished">1.5h</translation>
    </message>
    <message>
        <source>3h</source>
        <translation type="vanished">3h</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="vanished">随机</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="177"/>
        <source>Never</source>
        <translation>Không bao giờ</translation>
    </message>
</context>
<context>
    <name>ScreensaverUi</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="46"/>
        <source>Screensaver</source>
        <translation>bảo vệ màn hình</translation>
        <extra-contents_path>/Screensaver/Screensaver</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="136"/>
        <source>Idle time</source>
        <translation>Bật trình bảo vệ màn hình sau thời gian này</translation>
        <extra-contents_path>/Screensaver/Idle time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="253"/>
        <source>Screensaver program</source>
        <translation>Trình bảo vệ màn hình</translation>
        <extra-contents_path>/Screensaver/Screensaver program</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="282"/>
        <source>Screensaver source</source>
        <translation>Nguồn trình bảo vệ màn hình</translation>
        <extra-contents_path>/Screensaver/Screensaver source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="287"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="814"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="947"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1009"/>
        <source>Select</source>
        <translation>Chọn</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="308"/>
        <source>Ordinal</source>
        <translation>Theo thứ tự</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="213"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="309"/>
        <source>Random</source>
        <translation>Phát ngẫu nhiên</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="61"/>
        <source>Select Screensaver</source>
        <translation>chọn bảo vệ màn hình</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="91"/>
        <source>Weather</source>
        <translation>Thời tiết</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="104"/>
        <source>Music</source>
        <translation>Bài hát</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="118"/>
        <source>Albun</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="154"/>
        <source>Go to App Settings</source>
        <translation>đi tới cài đặt ứng dụng</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="165"/>
        <source>Current position</source>
        <translation>vị trí hiện tại</translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="246"/>
        <source>Prioritize the list of songs from the Music app</source>
        <translation>ưu tiên danh sách nhạc từ ứng dụng Music</translation>
        <extra-contents_path>/Screensaver/Prioritize the list of songs from the Music app</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="253"/>
        <source>Priority playlists</source>
        <translation>ưu tiên danh sách phát</translation>
        <extra-contents_path>/Screensaver/Priority playlists</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="189"/>
        <source>Select the folder</source>
        <translation>chọn tệp</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="211"/>
        <source>Switch mode</source>
        <translation>Chuyển đổi chế độ mạng</translation>
        <extra-contents_path>/Screensaver/Switch mode</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="212"/>
        <source>In order</source>
        <translation>theo thứ tự</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="218"/>
        <source>Switching frequency</source>
        <translation>Tần số chuyển đổi</translation>
        <extra-contents_path>/Screensaver/Switching frequency</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="234"/>
        <source>Image source</source>
        <translation>Nguồn hình ảnh</translation>
        <extra-contents_path>/Screensaver/Image source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="235"/>
        <source>Add image folder</source>
        <translation>thêm tệp ảnh</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="316"/>
        <source>Random switching</source>
        <translation>Chuyển đổi ngẫu nhiên</translation>
        <extra-contents_path>/Screensaver/Random switching</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="336"/>
        <source>Switching time</source>
        <translation>Tần số chuyển đổi</translation>
        <extra-contents_path>/Screensaver/Switching time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="355"/>
        <source>Text(up to 30 characters):</source>
        <translation>Văn bản bảo vệ màn hình (tối đa 30 ký tự):</translation>
        <extra-contents_path>/Screensaver/Text(up to 30 characters):</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="378"/>
        <source>Text position</source>
        <translation>vị trí văn bản</translation>
        <extra-contents_path>/Screensaver/Text position</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="386"/>
        <source>Centered</source>
        <translation>Trung tâm</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="387"/>
        <source>Randow(Bubble text)</source>
        <translation>Ngẫu nhiên (văn bản bong bóng)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="409"/>
        <source>Show rest time</source>
        <translation>Hiển thị thời gian nghỉ trên trình bảo vệ màn hình</translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="420"/>
        <source>Lock screen when screensaver boot</source>
        <translation>Khóa màn hình khi kích hoạt trình bảo vệ màn hình</translation>
        <extra-contents_path>/Screensaver/Lock screen when screensaver boot</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="817"/>
        <source>The date and time are displayed</source>
        <translation>hiển thị thời gian ngày tháng</translation>
        <extra-contents_path>/Screensaver/The date and time are displayed</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="817"/>
        <source>System wallpaper gallery</source>
        <translation>Thư viện hình nền hệ thống</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="878"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1073"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation>Tệp hình nền (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="813"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1008"/>
        <source>select custom screensaver dir</source>
        <translation>Chọn đường dẫn bảo vệ màn hình tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="815"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="948"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1010"/>
        <source>Position: </source>
        <translation>Vị trí </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="816"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="949"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1011"/>
        <source>FileName: </source>
        <translation>Tên tệp </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="817"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="950"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1012"/>
        <source>FileType: </source>
        <translation>Loại </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="818"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="951"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1013"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1011"/>
        <source>Music files(*.mp3 *.wav *.ogg *.flac *.aac *.m4a *.wma *.opus *.aiff .ape)</source>
        <translation>Tệp nhạc (* .mp3 * .wav * .ogg * .flac * .aac * .m4a * .wma * .opus * .aiff .ape)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="946"/>
        <source>select screensaver music dir</source>
        <translation>Chọn bảo vệ màn hình thư mục âm nhạc</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1075"/>
        <source>The maximum limit for the number of images in the folder has been reached; you can remove some before continuing to add more.</source>
        <translation>Đã đạt đến giới hạn tối đa về số lượng hình ảnh trong thư mục; Bạn có thể xóa một số trước khi tiếp tục thêm nhiều hơn.</translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="154"/>
        <source>Picture does not exist</source>
        <translation>Hình ảnh không tồn tại</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1722"/>
        <location filename="../src/screensaver/screensaver.cpp" line="1723"/>
        <source>Not connected to a network</source>
        <translation>Không được kết nối mạng</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1726"/>
        <location filename="../src/screensaver/screensaver.cpp" line="1727"/>
        <source>The weather update failed</source>
        <translation>cập nhật thời tiết thất bại</translation>
    </message>
</context>
<context>
    <name>MPRISSaverWidget</name>
    <message>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="216"/>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="378"/>
        <source>No music detected</source>
        <translation>không phát hiện ra nhạc</translation>
    </message>
    <message>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="400"/>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="409"/>
        <source>Unknown</source>
        <translation>Chưa xác định</translation>
    </message>
</context>
<context>
    <name>CustomAlbumViewer</name>
    <message>
        <location filename="../src/screensaver/customalbumviewer.cpp" line="20"/>
        <source>No photos detected, please re-select them</source>
        <translation>Không phát hiện thấy ảnh, vui lòng chọn lại</translation>
    </message>
</context>
</TS>
