<?xml version="1.0" encoding="utf-8"?>
<!--
   Copyright (C) 2023 KylinSoft Co., Ltd.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, see &lt;http://www.gnu.org/licenses/&gt;.
-->
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>CustomAlbumViewer</name>
    <message>
        <source>No photos detected, please re-select them</source>
        <translation type="vanished">པར་བཤེར་འཇལ་བྱེད་མ་ཐུབ།ཡང་བསྐྱར་འདེམ་རོགས།</translation>
    </message>
</context>
<context>
    <name>MPRISSaverWidget</name>
    <message>
        <source>No music detected</source>
        <translation type="vanished">གླུ་དབྱངས་བཤེར་འཇལ་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="vanished">ཤེས་མེད་པ།</translation>
    </message>
</context>
<context>
    <name>PhotoCorver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="82"/>
        <source>Right open the file location</source>
        <translation>ཡིག་ཆའི་གནས་ཡུལ་གྱི་ཁ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="86"/>
        <source>Remove the file</source>
        <translation>སྤོ་བ།</translation>
    </message>
</context>
<context>
    <name>Screenlock</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="54"/>
        <source>Screenlock</source>
        <translation>བརྙན་ཤེལ་གྱི་སྒོ་བརྒྱབ་པ</translation>
    </message>
    <message>
        <source>Screenlock Interface</source>
        <translation type="vanished">བརྙན་ཤེལ་གྱི་འབྲེལ་མཐུད།</translation>
    </message>
    <message>
        <source>Show message on lock screen</source>
        <translation type="vanished">ཟྭ་ངོས་སུ་ཆ་འཕྲིན་མངོན་པར་བྱས་ཡོད།</translation>
    </message>
    <message>
        <source>Show picture of screenlock on screenlogin</source>
        <translation type="vanished">བརྙན་ཤེལ་སྟེང་གི་བརྙན་ཤེལ་གྱི་པར་རིས་འགྲེམས་སྟོན་བྱས།</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="vanished">འབྲེལ་ལྡན་སྒྲིག་འགོད་</translation>
    </message>
    <message>
        <source>Monitor Off</source>
        <translation type="vanished">སྒོ་རྒྱག་འཆར་ཆས་</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="vanished">ཉི་ནུབ</translation>
    </message>
    <message>
        <source>Screensaver</source>
        <translation type="vanished">བརྙན་ཡོལ་སྲུང་སྐྱོབ་</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">བརྙན་ཤེལ་གྱི་ལྷམ་ཡུ་རིང་གི་དུས་སུ་བརྙན་ཤེལ་ལ་ཟྭ་རྒྱག</translation>
    </message>
    <message>
        <source>Lock screen delay</source>
        <translation type="vanished">བརྙན་ཤེལ་གྱི་དུས་ཚོད་འགོར་འགྱངས</translation>
    </message>
    <message>
        <source>Online Picture</source>
        <translation type="vanished">དྲ་ཐོག་པར་རིས།</translation>
    </message>
    <message>
        <source>1min</source>
        <translation type="vanished">1min</translation>
    </message>
    <message>
        <source>5min</source>
        <translation type="vanished">5min</translation>
    </message>
    <message>
        <source>10min</source>
        <translation type="vanished">10min</translation>
    </message>
    <message>
        <source>30min</source>
        <translation type="vanished">30min</translation>
    </message>
    <message>
        <source>45min</source>
        <translation type="vanished">45min</translation>
    </message>
    <message>
        <source>1hour</source>
        <translation type="vanished">1hour</translation>
    </message>
    <message>
        <source>2hour</source>
        <translation type="vanished">2hour</translation>
    </message>
    <message>
        <source>3hour</source>
        <translation type="vanished">3hour</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">གཏན་ནས་བྱེད་མི་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="291"/>
        <source>Your system does not have any browser application installed or the default browser application is not set up</source>
        <translation>ཁྱེད་ཀྱི་རྒྱུད་ཁོངས་ལ་གང་རུང་གི་མིག་བཤར་ཆས་བེད་སྤྱོད་དང་སོར་བཞག་མིག་བཤར་ཆས་བེད་སྤྱོད་སྒྲིག་འགོད་བྱས་མེད།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="292"/>
        <source>Unable to open browser application</source>
        <translation>མིག་བཤར་ཆས་བེད་སྤྱོད་ཁ་འབྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="322"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</source>
        <translation>པར་རིས་ཡིག་ཆWallpaper files (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *jpe *.gif *.tif *.tiff *wdp)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="364"/>
        <source>select custom wallpaper file</source>
        <translation>མཚན་ཉིད་རང་འཇོག་གི་གྱང་ཤོག་ཡིག་ཆ་བདམས་པ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="365"/>
        <source>Select</source>
        <translation>བདམ་གསེས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="366"/>
        <source>Position: </source>
        <translation>ས་གནས་ནི། </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="367"/>
        <source>FileName: </source>
        <translation>ཡིག་ཆའི་མིང་ནི། </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="368"/>
        <source>FileType: </source>
        <translation>ཡིག་ཆའི་རིགས་ནི། </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="369"/>
        <source>Cancel</source>
        <translation>མེད་པར་བཟོ་དགོས</translation>
    </message>
    <message>
        <source>The date and time are displayed</source>
        <translation type="vanished">དུས་ཚོད་ཀྱི་ཚེས་གྲངས་གསལ་པོར་མངོན་པ།</translation>
        <extra-contents_path>/Screenlock/The date and time are displayed</extra-contents_path>
    </message>
</context>
<context>
    <name>ScreenlockUi</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="73"/>
        <source>Show picture of screenlock on screenlogin</source>
        <translation>བརྙན་ཤེལ་སྟེང་གི་བརྙན་ཤེལ་གྱི་པར་རིས་འགྲེམས་སྟོན་བྱས།</translation>
        <extra-contents_path>/Screenlock/Show picture of screenlock on screenlogin</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="99"/>
        <source>Leave lock (System will be locked when the paired phone gone)</source>
        <translation>ཟྭ་དང་བྲལ་ནས་(ལག་ཁྱེར་ཁ་པར་མེད་པར་གྱུར་རྗེས་མ་ལག་ལ་སྒོ་བརྒྱབ་ནས་གཏན་ཁེལ་བྱེད་ངེས་ )</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="110"/>
        <source>Specified device</source>
        <translation>སྒྲིག་ཆས་དམིགས་འཛུགས་བྱ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="127"/>
        <source>No paired phone. Please turn to &apos;Bluetooth&apos; to pair.</source>
        <translation>ལག་ཁྱེར་ཁ་པར་ཆ་འགྲིག་མེད&apos;སོ་སྔོན་པོ་&apos;རུ་བསྒྱུར་ནས་སྡེབ་སྒྲིག་བྱེད་རོགས།。</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="52"/>
        <source>Screenlock</source>
        <translation>བརྙན་ཤེལ་གྱི་སྒོ་བརྒྱབ་པ</translation>
        <extra-contents_path>/Screenlock/Screenlock</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="85"/>
        <source>The date and time are displayed</source>
        <translation>དུས་ཚོད་ཀྱི་ཚེས་གྲངས་གསལ་པོར་མངོན་པ།</translation>
        <extra-contents_path>/Screenlock/The date and time are displayed</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="185"/>
        <source>Choose Picture</source>
        <translation>པར་རིས་འདེམ་པ།</translation>
        <extra-contents_path>/Wallpaper/Choose Picture</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="189"/>
        <source>Local Pictures</source>
        <translation>རང་སའི་རི་མོ།</translation>
        <extra-contents_path>/Screenlock/Local Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="193"/>
        <source>Online Pictures</source>
        <translation>དྲ་ཐོག་པར་རིས།</translation>
        <extra-contents_path>/Screenlock/Online Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="197"/>
        <source>Reset To Default</source>
        <translation>བསྐྱར་དུ་ཁ་ཆད་དང་འགལ་བའི་གནས་</translation>
        <extra-contents_path>/Screenlock/Reset To Default</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="136"/>
        <source>Bluetooth</source>
        <translation>སོ་སྔོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="256"/>
        <source>No bluetooth adapter detected, can not use Leave Lock.</source>
        <translation>སོ་སྔོན་པོའི་སྡེབ་སྦྱོར་ཡོ་བྱད་ལ་ཞིབ་དཔྱད་ཚད་ལེན་མ་བྱས་ན། བཀོད་སྤྱོད་བྱེད་ཐབས་མེད།。</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="220"/>
        <source>Monitor Off</source>
        <translation>འཆར་ཆས་ཁ་རྒྱོབ</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="222"/>
        <source>Screensaver</source>
        <translation>བརྙན་ཡོལ་སྲུང་སྐྱོབ་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="217"/>
        <source>Related Settings</source>
        <translation>འབྲེལ་ཡོད་སྒྲིག་འགོད་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="221"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="223"/>
        <source>Set</source>
        <translation>སྒྲིག་འགོད་བྱེད་ཏུ་སོང་།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="288"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="737"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="771"/>
        <source>Please select device</source>
        <translation>དམིགས་འཛིན་གྱི་སྒྲིག་ཆས་གདམ་རོགས།</translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="56"/>
        <source>Screensaver</source>
        <translation>བརྙན་ཡོལ་སྲུང་སྐྱོབ་</translation>
    </message>
    <message>
        <source>Idle time</source>
        <translation type="vanished">སྒྱིད་ལུག་གི་དུས་ཚོད།</translation>
    </message>
    <message>
        <source>Lock screen when activating screensaver</source>
        <translation type="vanished">བརྙན་ཤེལ་ལ་སྐུལ་སློང་བྱེད་སྐབས་བརྙན་ཤེལ་ལ་ཟྭ་རྒྱག་པ།</translation>
    </message>
    <message>
        <source>Screensaver program</source>
        <translation type="vanished">བརྙན་ཤེལ་གྱི་འཆར་གཞི།</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">ལྟ་ཚུལ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="222"/>
        <source>UKUI</source>
        <translation>UKUI</translation>
    </message>
    <message>
        <source>Blank_Only</source>
        <translation type="vanished">Blank_Only</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="222"/>
        <source>Customize</source>
        <translation>རང་མཚན་འཇོག་པ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>5min</source>
        <translation>5སྐར་མ་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>10min</source>
        <translation>10སྐར་མ་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <source>15min</source>
        <translation>15སྐར་མ་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>30min</source>
        <translation>30སྐར་མ་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <source>1hour</source>
        <translation>1ཆུ་ཚོད།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="210"/>
        <source>Never</source>
        <translation>གཏན་ནས་མི་བྱེད</translation>
    </message>
    <message>
        <source>Screensaver source</source>
        <translation type="vanished">བརྙན་ཤེལ་གྱི་འབྱུང་ཁུངས།</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="vanished">བདམས་ཐོན་བྱུང་བ།</translation>
    </message>
    <message>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation type="vanished">Wallpaper files (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *jpe *.gif *.tif *.tiff *.svg)</translation>
    </message>
    <message>
        <source>select custom screensaver dir</source>
        <translation type="vanished">ཡུལ་སྲོལ་གོམས་གཤིས་ཀྱི་བརྙན་ཤེལ་གྲོན་ཆུང་བྱེད་མཁན་བདམས་པ་</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation type="vanished">གོ་གནས་ནི། </translation>
    </message>
    <message>
        <source>FileName: </source>
        <translation type="vanished">ཡིག་ཆའི་མིང་ནི། </translation>
    </message>
    <message>
        <source>FileType: </source>
        <translation type="vanished">ཡིག་ཆའི་རིགས་དབྱིབས་ནི། </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <source>Switching time</source>
        <translation type="vanished">བརྗེ་རེས་བྱེད་པའི་དུས་ཚོད།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="216"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="229"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="235"/>
        <source>1min</source>
        <translation>1སྐར་མ་</translation>
    </message>
    <message>
        <source>Ordinal</source>
        <translation type="vanished">སྲོལ་ཡིག</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="vanished">སྐབས་བསྟུན་རང་བཞིན།</translation>
    </message>
    <message>
        <source>Random switching</source>
        <translation type="vanished">སྐབས་བསྟུན་གྱིས་བརྗེ་རེས་བྱེད་པ</translation>
    </message>
    <message>
        <source>Text(up to 30 characters):</source>
        <translation type="vanished">ཡི་གེ(ཆེས་མང་ན་ཡི་གེ་30ཡོད་པ་གཤམ་གསལ། )</translation>
    </message>
    <message>
        <source>Show rest time</source>
        <translation type="vanished">ངལ་གསོའི་དུས་ཚོད་མངོན་པ།</translation>
    </message>
    <message>
        <source>Lock screen when screensaver boot</source>
        <translation type="vanished">བརྙན་ཤེལ་གྱི་ལྷམ་ཡུ་རིང་གི་དུས་སུ་བརྙན་ཤེལ་ལ་ཟྭ་རྒྱག</translation>
    </message>
    <message>
        <source>Text position</source>
        <translation type="vanished">ཡི་གེའི་གོ་གནས།</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation type="vanished">ལྟེ་བར་འཛིན་པ།</translation>
    </message>
    <message>
        <source>Randow(Bubble text)</source>
        <translation type="vanished">ལན་ཏུའོ་(ལྦུ་བ་ཅན་གྱི་ཡི་གེ)</translation>
    </message>
    <message>
        <source>Picture does not exist</source>
        <translation type="vanished">འདྲ་པར་མེད།</translation>
    </message>
    <message>
        <source>Not connected to a network</source>
        <translation type="vanished">དྲ་རྒྱ་སྦྲལ་མཐུད་མ་བྱུང་།</translation>
    </message>
    <message>
        <source>The weather update failed</source>
        <translation type="vanished">གནམ་གཤིས་གསར་སྒྱར་ལ་ཕམ་ཁ་བྱུང་།</translation>
    </message>
</context>
<context>
    <name>ScreensaverUi</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="70"/>
        <source>Screensaver</source>
        <translation>བརྙན་ཡོལ་སྲུང་སྐྱོབ་</translation>
        <extra-contents_path>/Screensaver/Screensaver</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="176"/>
        <source>Idle time</source>
        <translation>དུས་ཚོད་འདི་འགོར་རྗེས་བརྙན་ཤེལ་སྲུང་བྱད་ཀྱི་ཁ་འབྱེད།</translation>
        <extra-contents_path>/Screensaver/Idle time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="347"/>
        <source>Screensaver program</source>
        <translation>བརྙན་ཤེལ་གྱི་སྲུང་སྐྱོབ་བ་རིམ</translation>
        <extra-contents_path>/Screensaver/Screensaver program</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="376"/>
        <source>Screensaver source</source>
        <translation>བརྙན་ཤེལ་གྱི་འབྱུང་ཁུངས།</translation>
        <extra-contents_path>/Screensaver/Screensaver source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="381"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="972"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1116"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1186"/>
        <source>Select</source>
        <translation>བདམ་གསེས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="402"/>
        <source>Ordinal</source>
        <translation>གོ་རིམ་ལྟར</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="305"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="403"/>
        <source>Random</source>
        <translation>སྐབས་བསྟུན་རང་བཞིན།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="410"/>
        <source>Random switching</source>
        <translation>སྐབས་བསྟུན་གྱིས་བརྗེ་རེས་བྱེད་པ</translation>
        <extra-contents_path>/Screensaver/Random switching</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="430"/>
        <source>Switching time</source>
        <translation>བརྗེ་རེས་བྱེད་པའི་ཟློས་ཕྱོད</translation>
        <extra-contents_path>/Screensaver/Switching time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="449"/>
        <source>Text(up to 30 characters):</source>
        <translation>ཡི་གེ(ཆེས་མང་ན་ཡི་གེ་30ཡོད་པ་གཤམ་གསལ། )：</translation>
        <extra-contents_path>/Screensaver/Text(up to 30 characters):</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="472"/>
        <source>Text position</source>
        <translation>ཡི་གེའི་གནས།</translation>
        <extra-contents_path>/Screensaver/Text position</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="480"/>
        <source>Centered</source>
        <translation>ལྟེ་བར་འཛིན་པ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="481"/>
        <source>Randow(Bubble text)</source>
        <translation>སྐབས་བསྟུན(ལྦུ་བ་ཅན་གྱི་ཡི་གེ)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="214"/>
        <source>Show rest time</source>
        <translation>ངལ་གསོའི་དུས་ཚོད་མངོན་པ།</translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="86"/>
        <source>Select Screensaver</source>
        <translation>སྲུང་ཡོལ་གདམ་གསེས་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="112"/>
        <source>Weather</source>
        <translation>གནམ་གཤིས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="125"/>
        <source>Music</source>
        <translation>གླུ་དབྱངས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="138"/>
        <source>Albun</source>
        <translation>འདྲ་པར།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="225"/>
        <source>Lock screen when screensaver boot</source>
        <translation>བརྙན་ཤེལ་གྱི་གྲུང་སློང་བྱེད་དུས་བརྙན་ཡོལ་ཟྭ་རྒྱག</translation>
        <extra-contents_path>/Screensaver/Lock screen when screensaver boot</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="194"/>
        <source>The date and time are displayed</source>
        <translation>དུས་ཚོད་ཀྱི་ཚེས་གྲངས་གསལ་པོར་མངོན་པ།</translation>
        <extra-contents_path>/Screensaver/The date and time are displayed</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="246"/>
        <source>Go to App Settings</source>
        <translation>སྔོན་ལ་བེད་སྤྱོད་གཏོང་བའི་སྒྲིག་གཞི་འཛུགས་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="257"/>
        <source>Current position</source>
        <translation>དེང་སྐབས་ཀྱི་གནས་བབ།</translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="270"/>
        <source>Prioritize the list of songs from the Music app</source>
        <translation>&quot;རོལ་མོ་&quot;ཉེར་སྤྱོད་ཀྱི་གླུ་གཞས་རེའུ་མིག་སྔོན་ལ་གཏོང་།</translation>
        <extra-contents_path>/Screensaver/Prioritize the list of songs from the Music app</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="277"/>
        <source>Priority playlists</source>
        <translation>དམིགས་སུ་བཀར་ནས་སྔོན་ལ་རེའུ་མིག་གཏོང་།</translation>
        <extra-contents_path>/Screensaver/Priority playlists</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="281"/>
        <source>Select the folder</source>
        <translation>ཡིག་ཆ་བཙུར་བ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="303"/>
        <source>Switch mode</source>
        <translation>བྱེད་སྟངས་བརྗེ་རེས་བྱེད་པ།</translation>
        <extra-contents_path>/Screensaver/Switch mode</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="304"/>
        <source>In order</source>
        <translation>གོ་རིམ་ལྟར་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="310"/>
        <source>Switching frequency</source>
        <translation>སྐབས་བསྟུན་བྱེད་པ།</translation>
        <extra-contents_path>/Screensaver/Switching frequency</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="327"/>
        <source>Image source</source>
        <translation>པར་རིས་འབྱུང་ཁུངས།</translation>
        <extra-contents_path>/Screensaver/Image source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="328"/>
        <source>Add image folder</source>
        <translation>པར་རིས་ཡིག་ཆའི་བཙུར་མ་བསྣན་པ།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="863"/>
        <source>System wallpaper gallery</source>
        <translation>མ་ལག་པར་རིས་ཐོན་ཁུངས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="930"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1144"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation>Wallpaper files (*.jpg *.jpeg *.bmp *.dib *.png *.jfif *jpe *.gif *.tif *.tiff *.svg)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="971"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1185"/>
        <source>select custom screensaver dir</source>
        <translation>ཡུལ་སྲོལ་གོམས་གཤིས་ཀྱི་བརྙན་ཤེལ་གྲོན་ཆུང་བྱེད་མཁན་བདམས་པ་</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="973"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1117"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1187"/>
        <source>Position: </source>
        <translation>ས་གནས་ནི། </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="974"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1118"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1188"/>
        <source>FileName: </source>
        <translation>ཡིག་ཆའི་མིང་ནི། </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="975"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1119"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1189"/>
        <source>FileType: </source>
        <translation>ཡིག་ཆའི་རིགས་ནི། </translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="976"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1120"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1190"/>
        <source>Cancel</source>
        <translation>མེད་པར་བཟོ་དགོས</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1074"/>
        <source>Music files(*.mp3 *.wav *.ogg *.flac *.aac *.m4a *.wma *.opus *.aiff .ape)</source>
        <translation>Music files(*.mp3 *.wav *.ogg *.flac *.aac *.m4a *.wma *.opus *.aiff .ape)</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1115"/>
        <source>select screensaver music dir</source>
        <translation>རོལ་དབྱངས་ཀྱི་ཐབས་ལམ་གདམ་ག་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1140"/>
        <source>The maximum limit for the number of images in the folder has been reached; you can remove some before continuing to add more.</source>
        <translation>ཡིག་ཆལ་ཚོད་འཛིན་ཆེ་ཤོས་བྱས་ཟིན་པས།ཁྱེད་ཀྱིས་མུ་མཐུད་དུ་ཁ་སྣོན་བྱས་ཆོག</translation>
    </message>
</context>
</TS>
