<?xml version="1.0" encoding="utf-8"?>
<!--
   Copyright (C) 2023 KylinSoft Co., Ltd.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, see &lt;http://www.gnu.org/licenses/&gt;.
-->
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AgreementWindow</name>
    <message>
        <location filename="../src/widgets/agreementwindow.cpp" line="47"/>
        <source>I know</source>
        <translation>Lo sé</translation>
    </message>
</context>
<context>
    <name>AuthDialog</name>
    <message>
        <source>More Devices</source>
        <translation type="obsolete">选择其他设备</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="obsolete">使用生物识别认证</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">使用密码认证</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1554"/>
        <source>Retry</source>
        <translation>Reintentar</translation>
    </message>
    <message>
        <source>UnLock</source>
        <translation type="obsolete">解锁</translation>
    </message>
    <message>
        <source>Slide to unlock</source>
        <translation type="vanished">向上滑动解锁</translation>
    </message>
    <message>
        <source>You have %1 unread message</source>
        <translation type="vanished">您有%1条未读消息</translation>
    </message>
    <message>
        <source>LoggedIn</source>
        <translation type="obsolete">已登录</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation type="vanished">密码：</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="948"/>
        <source>Password Prompt:%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="vanished">账户锁定%1分钟由于%2次错误尝试</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1623"/>
        <source>Please try again in %1 minutes.</source>
        <translation>Inténtelo de nuevo en %1 minutos.</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1631"/>
        <source>Please try again in %1 seconds.</source>
        <translation>Inténtelo de nuevo en %1 segundos.</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1639"/>
        <source>Account locked permanently.</source>
        <translation>Cuenta bloqueada permanentemente.</translation>
    </message>
    <message>
        <source>Verify face recognition or enter password to unlock</source>
        <translation type="vanished">Verifique el reconocimiento facial o ingrese la contraseña para desbloquear</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="483"/>
        <source>Guest</source>
        <translation type="unfinished">游客</translation>
    </message>
    <message>
        <source>Press fingerprint or enter password to unlock</source>
        <translation type="vanished">Presione la huella dactilar o ingrese la contraseña para desbloquear</translation>
    </message>
    <message>
        <source>Verify voiceprint or enter password to unlock</source>
        <translation type="vanished">Verifica la huella de voz o ingresa la contraseña para desbloquear</translation>
    </message>
    <message>
        <source>Verify finger vein or enter password to unlock</source>
        <translation type="vanished">Verifique la vena del dedo o ingrese la contraseña para desbloquear</translation>
    </message>
    <message>
        <source>Verify iris or enter password to unlock</source>
        <translation type="vanished">Verifique el iris o ingrese la contraseña para desbloquear</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="481"/>
        <source>Enter username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="771"/>
        <location filename="../src/widgets/authdialog.cpp" line="803"/>
        <source>Facial recognition to unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="774"/>
        <source>Fingerprint recognition to unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="777"/>
        <source>Voiceprint recognition to unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="780"/>
        <source>Finger vein recognition to unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="783"/>
        <source>Iris recognition to unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="786"/>
        <source>wechat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="790"/>
        <source>Use the bound %1 scanning code to unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1058"/>
        <location filename="../src/widgets/authdialog.cpp" line="1082"/>
        <source>The authentication has been cancelled!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1278"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1281"/>
        <source>Input Password</source>
        <translation>Contraseña de entrada</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1286"/>
        <source>Username</source>
        <translation type="unfinished">Nombre de usuario</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1378"/>
        <source>User name input error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1468"/>
        <source>login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1876"/>
        <location filename="../src/widgets/authdialog.cpp" line="2126"/>
        <location filename="../src/widgets/authdialog.cpp" line="2281"/>
        <location filename="../src/widgets/authdialog.cpp" line="2478"/>
        <source>Failed to verify %1, please enter password to unlock</source>
        <translation>No se pudo verificar %1, ingrese la contraseña para desbloquear</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1879"/>
        <location filename="../src/widgets/authdialog.cpp" line="2129"/>
        <location filename="../src/widgets/authdialog.cpp" line="2286"/>
        <location filename="../src/widgets/authdialog.cpp" line="2289"/>
        <location filename="../src/widgets/authdialog.cpp" line="2481"/>
        <source>Unable to verify %1, please enter password to unlock</source>
        <translation>No se puede verificar %1, ingrese la contraseña para desbloquear</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2322"/>
        <source>Abnormal network</source>
        <translation>Red anormal</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2326"/>
        <source>Acquisition failure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2338"/>
        <source>Face recognition waiting time out, please click refresh or enter the password to unlock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2607"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2609"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2611"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2613"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2615"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2617"/>
        <location filename="../src/widgets/authdialog.cpp" line="2639"/>
        <source>Ukey</source>
        <translation type="unfinished">Ukey</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2619"/>
        <location filename="../src/widgets/authdialog.cpp" line="2641"/>
        <source>QRCode</source>
        <translation type="unfinished">QRCode</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2629"/>
        <source>fingerprint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2631"/>
        <source>fingervein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2633"/>
        <source>iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2635"/>
        <source>face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2637"/>
        <source>voiceprint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2867"/>
        <source>Two-Factor OTP Dynamic Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2870"/>
        <source>Two-Factor Security Key Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the bound wechat scanning code or enter the password to log in</source>
        <translation type="vanished">使用绑定的微信扫码或输入密码登录</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="930"/>
        <source>Password cannot be empty</source>
        <translation>La contraseña no puede estar vacía</translation>
    </message>
    <message>
        <source>Failed to verify %1, please enter password.</source>
        <translation type="vanished">验证%1失败，请输入密码.</translation>
    </message>
    <message>
        <source>Unable to verify %1, please enter password.</source>
        <translation type="vanished">无法验证%1，请输入密码.</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2306"/>
        <location filename="../src/widgets/authdialog.cpp" line="2310"/>
        <source>Failed to verify %1, you still have %2 verification opportunities</source>
        <translation>No se pudo verificar %1, todavía tiene %2 oportunidades de verificación</translation>
    </message>
    <message>
        <source>Biometric/code scan authentication failed too many times, please enter the password.</source>
        <translation type="vanished">生物/扫码验证失败达最大次数，请使用密码解锁</translation>
    </message>
    <message>
        <source>Bioauth/code scan authentication failed, you still have %1 verification opportunities</source>
        <translation type="vanished">生物/扫码验证失败，您还有%1次尝试机会</translation>
    </message>
    <message>
        <source>NET Exception</source>
        <translation type="vanished">网络异常</translation>
    </message>
    <message>
        <source>Password Incorrect, Please try again</source>
        <translation type="vanished">密码错误，请重试</translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="vanished">认证失败，还剩%1次尝试机会</translation>
    </message>
    <message>
        <source>Please enter your password or enroll your fingerprint </source>
        <translation type="vanished">请输入密码或者录入指纹</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1381"/>
        <location filename="../src/widgets/authdialog.cpp" line="1385"/>
        <source>Authentication failure, Please try again</source>
        <translation>Error de autenticación, inténtelo de nuevo</translation>
    </message>
    <message>
        <source>Use the bound wechat scanning code or enter the password to unlock</source>
        <translation type="vanished">Use el código de escaneo de wechat vinculado o ingrese la contraseña para desbloquear</translation>
    </message>
    <message>
        <source>Enter the ukey password</source>
        <translation type="vanished">Introduzca la contraseña de ukey</translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="2833"/>
        <source>Insert the ukey into the USB port</source>
        <translation>Inserte la ukey en el puerto USB</translation>
    </message>
    <message>
        <source>Password </source>
        <translation type="vanished">Contraseña </translation>
    </message>
    <message>
        <location filename="../src/widgets/authdialog.cpp" line="1545"/>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="vanished">生物识别认证</translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="vanished">密码认证</translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="vanished">其他设备</translation>
    </message>
    <message>
        <source>Too many unsuccessful attempts,please enter password.</source>
        <translation type="vanished">指纹验证失败达最大次数，请使用密码登录</translation>
    </message>
    <message>
        <source>Fingerprint authentication failed, you still have %1 verification opportunities</source>
        <translation type="vanished">指纹验证失败，您还有%1次尝试机会</translation>
    </message>
</context>
<context>
    <name>BatteryWidget</name>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="112"/>
        <location filename="../src/widgets/batterywidget.cpp" line="142"/>
        <source>Charging...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="114"/>
        <location filename="../src/widgets/batterywidget.cpp" line="144"/>
        <source>fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="118"/>
        <location filename="../src/widgets/batterywidget.cpp" line="148"/>
        <source>PowerMode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/batterywidget.cpp" line="121"/>
        <location filename="../src/widgets/batterywidget.cpp" line="151"/>
        <source>BatteryMode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BindDialog</name>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="91"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="103"/>
        <source>Ok</source>
        <translation type="unfinished">De acuerdo</translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="107"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="119"/>
        <source>Mfa authentication is on, please bind OTP code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="125"/>
        <source>Go to Bind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/binddialog.cpp" line="150"/>
        <source>Bind</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="obsolete">指纹</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="obsolete">指静脉</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="obsolete">虹膜</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="obsolete">人脸</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="obsolete">声纹</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Please select other biometric devices</source>
        <translation type="obsolete">请选择其他生物识别设备</translation>
    </message>
    <message>
        <source>Device Type:</source>
        <translation type="obsolete">设备类型：</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation type="obsolete">设备名称：</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="vanished">Dispositivo actual: </translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="vanished">Identifique el error, vuelva a intentarlo.</translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="vanished">Seleccione el dispositivo biométrico</translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="vanished">Tipo de dispositivo:</translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="vanished">Nombre del dispositivo:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">De acuerdo</translation>
    </message>
</context>
<context>
    <name>BlockWidget</name>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="60"/>
        <location filename="../src/widgets/blockwidget.cpp" line="140"/>
        <location filename="../src/widgets/blockwidget.cpp" line="141"/>
        <location filename="../src/widgets/blockwidget.cpp" line="142"/>
        <location filename="../src/widgets/blockwidget.cpp" line="143"/>
        <location filename="../src/widgets/blockwidget.cpp" line="145"/>
        <location filename="../src/widgets/blockwidget.cpp" line="251"/>
        <location filename="../src/widgets/blockwidget.cpp" line="252"/>
        <location filename="../src/widgets/blockwidget.cpp" line="253"/>
        <location filename="../src/widgets/blockwidget.cpp" line="254"/>
        <location filename="../src/widgets/blockwidget.cpp" line="256"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="64"/>
        <location filename="../src/widgets/blockwidget.cpp" line="147"/>
        <location filename="../src/widgets/blockwidget.cpp" line="148"/>
        <location filename="../src/widgets/blockwidget.cpp" line="149"/>
        <location filename="../src/widgets/blockwidget.cpp" line="150"/>
        <location filename="../src/widgets/blockwidget.cpp" line="152"/>
        <location filename="../src/widgets/blockwidget.cpp" line="258"/>
        <location filename="../src/widgets/blockwidget.cpp" line="259"/>
        <location filename="../src/widgets/blockwidget.cpp" line="260"/>
        <location filename="../src/widgets/blockwidget.cpp" line="261"/>
        <location filename="../src/widgets/blockwidget.cpp" line="263"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="159"/>
        <location filename="../src/widgets/blockwidget.cpp" line="178"/>
        <source>If you do not perform any operation, the system will automatically %1 after %2 seconds.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="193"/>
        <source>The following programs prevent restarting, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="197"/>
        <source>The following programs prevent the shutdown, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="202"/>
        <source>The following programs prevent suspend, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="205"/>
        <source>The following programs prevent hibernation, you can click &quot;Cancel&quot; and then close these programs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="209"/>
        <source>The following programs prevent you from logging out, you can click &quot;Cancel&quot; and then close them.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="271"/>
        <source>shut down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/blockwidget.cpp" line="274"/>
        <source>restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from reboot!</source>
        <translation type="obsolete">¡El siguiente programa se está ejecutando para evitar que el sistema se reinicie!</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from shutting down!</source>
        <translation type="obsolete">¡El siguiente programa se está ejecutando para evitar que el sistema se apague!</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from suspend!</source>
        <translation type="obsolete">¡El siguiente programa se está ejecutando para evitar que el sistema se suspenda!</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from hibernate!</source>
        <translation type="obsolete">¡El siguiente programa se está ejecutando para evitar que el sistema hiberne!</translation>
    </message>
</context>
<context>
    <name>CharsMoreWidget</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/charsmorewidget.cpp" line="183"/>
        <source>&amp;&amp;?!</source>
        <translation>&amp;&amp;?!</translation>
    </message>
</context>
<context>
    <name>CharsWidget</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/charswidget.cpp" line="115"/>
        <location filename="../src/VirtualKeyboard/src/charswidget.cpp" line="273"/>
        <source>More</source>
        <translation>Más</translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/charswidget.cpp" line="129"/>
        <source>ABC</source>
        <translation>ABECEDARIO</translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/charswidget.cpp" line="142"/>
        <source>123</source>
        <translation>123</translation>
    </message>
</context>
<context>
    <name>ConfForm</name>
    <message>
        <source>edit network</source>
        <translation type="vanished">Editar red</translation>
    </message>
    <message>
        <source>LAN name: </source>
        <translation type="vanished">Nombre de la LAN: </translation>
    </message>
    <message>
        <source>Method: </source>
        <translation type="vanished">Método: </translation>
    </message>
    <message>
        <source>Address: </source>
        <translation type="vanished">Dirección: </translation>
    </message>
    <message>
        <source>Netmask: </source>
        <translation type="vanished">Máscara de red: </translation>
    </message>
    <message>
        <source>Gateway: </source>
        <translation type="vanished">Entrada: </translation>
    </message>
    <message>
        <source>DNS 1: </source>
        <translation type="vanished">DNS 1: </translation>
    </message>
    <message>
        <source>DNS 2: </source>
        <translation type="vanished">DNS 2: </translation>
    </message>
    <message>
        <source>Edit Conn</source>
        <translation type="vanished">Editar Conn</translation>
    </message>
    <message>
        <source>Auto(DHCP)</source>
        <translation type="vanished">Automático (DHCP)</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="vanished">Manual</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Salvar</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">De acuerdo</translation>
    </message>
    <message>
        <source>Can not create new wired network for without wired card</source>
        <translation type="vanished">No se puede crear una nueva red cableada sin tarjeta cableada</translation>
    </message>
    <message>
        <source>New network already created</source>
        <translation type="vanished">Nueva red ya creada</translation>
    </message>
    <message>
        <source>New network settings already finished</source>
        <translation type="vanished">La nueva configuración de red ya ha finalizado</translation>
    </message>
    <message>
        <source>Edit Network</source>
        <translation type="vanished">Editar red</translation>
    </message>
    <message>
        <source>Add Wired Network</source>
        <translation type="vanished">Agregar red cableada</translation>
    </message>
    <message>
        <source>create wired network successfully</source>
        <translation type="obsolete">已创建新的有线网络</translation>
    </message>
    <message>
        <source>change configuration of wired network successfully</source>
        <translation type="obsolete">新的设置已经生效</translation>
    </message>
    <message>
        <source>New settings already effective</source>
        <translation type="vanished">Nuevos ajustes ya efectivos</translation>
    </message>
    <message>
        <source>There is a same named LAN exsits.</source>
        <translation type="obsolete">已有同名连接存在</translation>
    </message>
</context>
<context>
    <name>CustomAlbumViewer</name>
    <message>
        <location filename="../src/screensaver/customalbumviewer.cpp" line="18"/>
        <source>No photos detected, please re-select them</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="vanished">Huellas</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="vanished">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="vanished">Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="vanished">Cara</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="vanished">Huella de voz</translation>
    </message>
    <message>
        <source>Ukey</source>
        <translation type="vanished">Ukey</translation>
    </message>
    <message>
        <source>QRCode</source>
        <translation type="vanished">QRCode</translation>
    </message>
</context>
<context>
    <name>DigitalAuthDialog</name>
    <message>
        <source>LoginByUEdu</source>
        <translation type="vanished">LoginByUEdu</translation>
    </message>
    <message>
        <source>now is authing, wait a moment</source>
        <translation type="vanished">认证中，请稍后</translation>
    </message>
    <message>
        <source>Password Incorrect, Please try again</source>
        <translation type="obsolete">密码错误，请重试</translation>
    </message>
    <message>
        <source>ResetPWD?</source>
        <translation type="vanished">¿ReiniciarPWD?</translation>
    </message>
    <message>
        <source>SetNewUEduPWD</source>
        <translation type="vanished">SetNewUEduPWD</translation>
    </message>
    <message>
        <source>ConfirmNewUEduPWD</source>
        <translation type="vanished">ConfirmNewUEduPWD</translation>
    </message>
    <message>
        <source>The two password entries are inconsistent, please reset</source>
        <translation type="vanished">Las dos entradas de contraseña son inconsistentes, restablezca</translation>
    </message>
    <message>
        <source>Password entered incorrectly, please try again</source>
        <translation type="vanished">Contraseña introducida incorrectamente, inténtelo de nuevo</translation>
    </message>
    <message>
        <source>clear</source>
        <translation type="vanished">claro</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifi</name>
    <message>
        <source>Add Hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Wi-Fi name</source>
        <translation type="vanished">Nombre de Wi-Fi</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiLeap</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="vanished">Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecFast</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">Autenticación</translation>
    </message>
    <message>
        <source>Anonymous identity</source>
        <translation type="vanished">Identidad anónima</translation>
    </message>
    <message>
        <source>Allow automatic PAC pro_visioning</source>
        <translation type="vanished">Permitir pro_visioning PAC automáticos</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation type="vanished">Archivo PAC</translation>
    </message>
    <message>
        <source>Inner authentication</source>
        <translation type="vanished">Autenticación interna</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="vanished">Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="vanished">TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="vanished">EAP protegido (PEAP)</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation type="vanished">Anónimo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation type="vanished">Autenticado</translation>
    </message>
    <message>
        <source>Both</source>
        <translation type="vanished">Ambos</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecLeap</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">Autenticación</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="vanished">Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="vanished">TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="vanished">EAP protegido (PEAP)</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecPeap</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">Autenticación</translation>
    </message>
    <message>
        <source>Anonymous identity</source>
        <translation type="vanished">Identidad anónima</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="vanished">Dominio</translation>
    </message>
    <message>
        <source>CA certificate</source>
        <translation type="vanished">Certificado de CA</translation>
    </message>
    <message>
        <source>CA certificate password</source>
        <translation type="vanished">Contraseña del certificado de CA</translation>
    </message>
    <message>
        <source>No CA certificate is required</source>
        <translation type="vanished">No se requiere ningún certificado de CA</translation>
    </message>
    <message>
        <source>PEAP version</source>
        <translation type="vanished">Versión PEAP</translation>
    </message>
    <message>
        <source>Inner authentication</source>
        <translation type="vanished">Autenticación interna</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="vanished">Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="vanished">TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="vanished">EAP protegido (PEAP)</translation>
    </message>
    <message>
        <source>Choose from file</source>
        <translation type="vanished">Elegir del archivo</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="vanished">Automático</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation type="vanished">Versión 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation type="vanished">Versión 1</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecPwd</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">Autenticación</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="vanished">Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="vanished">TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="vanished">EAP protegido (PEAP)</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecTls</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">Autenticación</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation type="vanished">Identidad</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="vanished">Dominio</translation>
    </message>
    <message>
        <source>CA certificate</source>
        <translation type="vanished">Certificado de CA</translation>
    </message>
    <message>
        <source>CA certificate password</source>
        <translation type="vanished">Contraseña del certificado de CA</translation>
    </message>
    <message>
        <source>No CA certificate is required</source>
        <translation type="vanished">No se requiere ningún certificado de CA</translation>
    </message>
    <message>
        <source>User certificate</source>
        <translation type="vanished">Certificado de usuario</translation>
    </message>
    <message>
        <source>User certificate password</source>
        <translation type="vanished">Contraseña del certificado de usuario</translation>
    </message>
    <message>
        <source>User private key</source>
        <translation type="vanished">Clave privada de usuario</translation>
    </message>
    <message>
        <source>User key password</source>
        <translation type="vanished">Clave de usuario contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="vanished">TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="vanished">EAP protegido (PEAP)</translation>
    </message>
    <message>
        <source>Choose from file</source>
        <translation type="vanished">Elegir del archivo</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecTunnelTLS</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">Autenticación</translation>
    </message>
    <message>
        <source>Anonymous identity</source>
        <translation type="vanished">Identidad anónima</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="vanished">Dominio</translation>
    </message>
    <message>
        <source>CA certificate</source>
        <translation type="vanished">Certificado de CA</translation>
    </message>
    <message>
        <source>CA certificate password</source>
        <translation type="vanished">Contraseña del certificado de CA</translation>
    </message>
    <message>
        <source>No CA certificate is required</source>
        <translation type="vanished">No se requiere ningún certificado de CA</translation>
    </message>
    <message>
        <source>Inner authentication</source>
        <translation type="vanished">Autenticación interna</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="vanished">Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation type="vanished">TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP (PEAP)</source>
        <translation type="vanished">EAP protegido (PEAP)</translation>
    </message>
    <message>
        <source>Choose from file</source>
        <translation type="vanished">Elegir del archivo</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiWep</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Key</source>
        <translation type="vanished">Llave</translation>
    </message>
    <message>
        <source>WEP index</source>
        <translation type="vanished">Índice WEP</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="vanished">Autenticación</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">Clave WEP de 40/128 bits (hexadecimal o ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">Frase de contraseña WEP de 128 bits</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">WEP dinámico (802.1X)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA y WPA2 Enterprise</translation>
    </message>
    <message>
        <source>1(default)</source>
        <translation type="vanished">1(predeterminado)</translation>
    </message>
    <message>
        <source>Open System</source>
        <translation type="vanished">Sistema abierto</translation>
    </message>
    <message>
        <source>Shared Key</source>
        <translation type="vanished">Clave compartida</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiWpa</name>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Add Hidden Wi-Fi</source>
        <translation type="vanished">Agregar Wi-Fi oculto</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="vanished">Conexión</translation>
    </message>
    <message>
        <source>Wi-Fi name</source>
        <translation type="vanished">Nombre de Wi-Fi</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>C_reate…</source>
        <translation type="vanished">C_reate…</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
</context>
<context>
    <name>DlgHotspotCreate</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Diálogo</translation>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="vanished">Crear zona interactiva</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation type="vanished">Nombre de la red</translation>
    </message>
    <message>
        <source>Wi-Fi security</source>
        <translation type="vanished">Seguridad Wi-Fi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">De acuerdo</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="vanished">WPA y WPA2 Personal</translation>
    </message>
</context>
<context>
    <name>EngineDevice</name>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="101"/>
        <source>yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="101"/>
        <source>no</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="120"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="120"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="284"/>
        <source>%1% available, charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="290"/>
        <source>Left %1h %2m (%3%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="295"/>
        <source>%1% available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="301"/>
        <source>Left %1h %2m to full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="303"/>
        <source>charging (%1%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="309"/>
        <source>%1 waiting to discharge (%2%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="314"/>
        <source>%1 waiting to charge (%2%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="334"/>
        <source>AC adapter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="338"/>
        <source>Laptop battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="342"/>
        <source>UPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="346"/>
        <source>Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="350"/>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="354"/>
        <source>Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="358"/>
        <source>PDA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="362"/>
        <source>Cell phone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="366"/>
        <source>Media player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="370"/>
        <source>Tablet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="374"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="378"/>
        <source>unrecognised</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <location filename="../src/widgets/iconedit.cpp" line="120"/>
        <location filename="../src/widgets/iconedit.cpp" line="231"/>
        <source>OK</source>
        <translation>De acuerdo</translation>
    </message>
</context>
<context>
    <name>InputInfos</name>
    <message>
        <source>Service exception...</source>
        <translation type="vanished">Excepción de servicio...</translation>
    </message>
    <message>
        <source>Invaild parameters...</source>
        <translation type="vanished">Parámetros de Invaild...</translation>
    </message>
    <message>
        <source>Unknown fault:%1</source>
        <translation type="vanished">Fallo desconocido:%1</translation>
    </message>
    <message>
        <source>Recapture(60s)</source>
        <translation type="vanished">Recaptura (años 60)</translation>
    </message>
    <message>
        <source>Recapture(%1s)</source>
        <translation type="vanished">Recaptura(%1s)</translation>
    </message>
    <message>
        <source>Get code</source>
        <translation type="vanished">Obtener código</translation>
    </message>
</context>
<context>
    <name>KBTitle</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="46"/>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="83"/>
        <source>Suspended state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="57"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/kbtitle.cpp" line="86"/>
        <source>Welt status</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KylinDBus</name>
    <message>
        <source>kylin network applet desktop message</source>
        <translation type="obsolete">麒麟网络工具信息提示</translation>
    </message>
</context>
<context>
    <name>KylinNM</name>
    <message>
        <source>kylin-nm</source>
        <translation type="vanished">Kylin-NM</translation>
    </message>
    <message>
        <source>LAN</source>
        <translation type="vanished">LAN</translation>
    </message>
    <message>
        <source>Enabel LAN List</source>
        <translation type="obsolete">其他有线网络</translation>
    </message>
    <message>
        <source>WiFi</source>
        <translation type="obsolete">无线网络</translation>
    </message>
    <message>
        <source>Enabel WiFi List</source>
        <translation type="obsolete">其他无线网络</translation>
    </message>
    <message>
        <source>New WiFi</source>
        <translation type="obsolete">加入其他网络</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="vanished">Avanzado</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation type="vanished">有线网络</translation>
    </message>
    <message>
        <source>Connect Hide Network</source>
        <translation type="vanished">加入网络</translation>
    </message>
    <message>
        <source>Wifi</source>
        <translation type="vanished">无线网络</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation type="vanished">已开启</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="vanished">已关闭</translation>
    </message>
    <message>
        <source>HotSpot</source>
        <translation type="vanished">Punto caliente</translation>
    </message>
    <message>
        <source>FlyMode</source>
        <translation type="vanished">Modo de vuelo</translation>
    </message>
    <message>
        <source>Show MainWindow</source>
        <translation type="vanished">显示网络连接界面</translation>
    </message>
    <message>
        <source>Inactivated LAN</source>
        <translation type="vanished">LAN inactivada</translation>
    </message>
    <message>
        <source>Inactivated WLAN</source>
        <translation type="vanished">未激活</translation>
    </message>
    <message>
        <source>Other WLAN</source>
        <translation type="vanished">Otras WLAN</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation type="vanished">WLAN</translation>
    </message>
    <message>
        <source>Show KylinNM</source>
        <translation type="vanished">Mostrar KylinNM</translation>
    </message>
    <message>
        <source>No wireless card detected</source>
        <translation type="vanished">No se ha detectado ninguna tarjeta inalámbrica</translation>
    </message>
    <message>
        <source>Activated LAN</source>
        <translation type="vanished">LAN activada</translation>
    </message>
    <message>
        <source>Activated WLAN</source>
        <translation type="vanished">WLAN activada</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation type="vanished">No conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="vanished">Desconectado</translation>
    </message>
    <message>
        <source>No Other Wired Network Scheme</source>
        <translation type="vanished">Ningún otro esquema de red cableada</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="obsolete">编辑</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="obsolete">完成</translation>
    </message>
    <message>
        <source>No wifi connected.</source>
        <translation type="obsolete">未连接任何网络</translation>
    </message>
    <message>
        <source>No Other Wireless Network Scheme</source>
        <translation type="vanished">Ningún otro esquema de red inalámbrica</translation>
    </message>
    <message>
        <source>Wired net is disconnected</source>
        <translation type="vanished">La red cableada está desconectada</translation>
    </message>
    <message>
        <source>Wi-Fi is disconnected</source>
        <translation type="obsolete">断开无线网络</translation>
    </message>
    <message>
        <source>Confirm your Wi-Fi password or usable of wireless card</source>
        <translation type="vanished">Confirme su contraseña de Wi-Fi o la tarjeta inalámbrica utilizable</translation>
    </message>
    <message>
        <source>Ethernet Networks</source>
        <translation type="vanished">其他有线网络</translation>
    </message>
    <message>
        <source>New LAN</source>
        <translation type="obsolete">新建有线网络</translation>
    </message>
    <message>
        <source>Hide WiFi</source>
        <translation type="vanished">加入网络</translation>
    </message>
    <message>
        <source>No usable network in the list</source>
        <translation type="vanished">No hay red utilizable en la lista</translation>
    </message>
    <message>
        <source>NetOn,</source>
        <translation type="vanished">NetOn,</translation>
    </message>
    <message>
        <source>Wifi Networks</source>
        <translation type="vanished">其他无线网络</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">无</translation>
    </message>
    <message>
        <source>keep wired network switch is on before turning on wireless switch</source>
        <translation type="vanished">打开无线网开关前保持有线网开关打开</translation>
    </message>
    <message>
        <source>please insert the wireless network adapter</source>
        <translation type="vanished">请先插入无线网卡</translation>
    </message>
    <message>
        <source>Abnormal connection exist, program will delete it</source>
        <translation type="vanished">正在断开异常连接的网络</translation>
    </message>
    <message>
        <source>update Wi-Fi list now, click again</source>
        <translation type="vanished">正在更新 Wi-Fi列表 请再次点击</translation>
    </message>
    <message>
        <source>update Wi-Fi list now</source>
        <translation type="vanished">正在更新 Wi-Fi列表</translation>
    </message>
    <message>
        <source>Conn Ethernet Success</source>
        <translation type="vanished">Éxito de Conn Ethernet</translation>
    </message>
    <message>
        <source>Conn Ethernet Fail</source>
        <translation type="vanished">Falla de Ethernet de Conn</translation>
    </message>
    <message>
        <source>Conn Wifi Success</source>
        <translation type="vanished">Éxito de Conn Wifi</translation>
    </message>
</context>
<context>
    <name>LettersWidget</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/letterswidget.cpp" line="172"/>
        <source>&amp;&amp;?!</source>
        <translation>&amp;&amp;?!</translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/letterswidget.cpp" line="186"/>
        <source>123</source>
        <translation>123</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation type="vanished">Ctrl</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation type="vanished">Alt</translation>
    </message>
</context>
<context>
    <name>LightDMHelper</name>
    <message>
        <location filename="../src/lock-backend/lightdmhelper.cpp" line="138"/>
        <source>failed to start session.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-backend/lightdmhelper.cpp" line="232"/>
        <source>Login</source>
        <translation type="unfinished">Iniciar sesión</translation>
    </message>
    <message>
        <location filename="../src/lock-backend/lightdmhelper.cpp" line="241"/>
        <source>Guest</source>
        <translation type="unfinished">游客</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Forma</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="vanished">Fecha</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">Hora</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="vanished">游客</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="648"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1957"/>
        <source>SwitchUser</source>
        <translation>SwitchUser (Usuario)</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="584"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1946"/>
        <source>Power</source>
        <translation>Poder</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="597"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1949"/>
        <source>VirtualKeyboard</source>
        <translation>Teclado virtual</translation>
    </message>
    <message>
        <source>Multiple users are logged in at the same time.Are you sure you want to reboot this system?</source>
        <translation type="vanished">Varios usuarios han iniciado sesión al mismo tiempo. ¿Estás seguro de que quieres reiniciar este sistema?</translation>
    </message>
    <message>
        <source>LAN</source>
        <translation type="vanished">LAN</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation type="vanished">WLAN</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="743"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1966"/>
        <location filename="../src/widgets/lockwidget.cpp" line="2174"/>
        <source>system-monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1227"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1969"/>
        <source>Reset Pwd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1611"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1617"/>
        <source>%1 may cause users who have logged in to this computer to lose content that has not yet been stored,To still perform please click &quot;Confirm&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1649"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1654"/>
        <source>Multiple users are logged in at the same time.Are you sure you want to %1 this system?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1613"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1650"/>
        <source>Restart</source>
        <translation type="unfinished">Reanudar</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="705"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1963"/>
        <source>SwitchSession</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="669"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1960"/>
        <source>Power Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1953"/>
        <location filename="../src/widgets/lockwidget.cpp" line="2224"/>
        <source>Network</source>
        <translation type="unfinished">网络</translation>
    </message>
    <message>
        <location filename="../src/widgets/lockwidget.cpp" line="1619"/>
        <location filename="../src/widgets/lockwidget.cpp" line="1655"/>
        <source>Shut Down</source>
        <translation type="unfinished">Apaga</translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="81"/>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="104"/>
        <source>Login Options</source>
        <translation>Opciones de inicio de sesión</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="266"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="292"/>
        <source>Other</source>
        <translation>Otro</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1064"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1066"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1068"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1070"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1072"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1074"/>
        <source>Ukey</source>
        <translation type="unfinished">Ukey</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="1076"/>
        <source>QRCode</source>
        <translation type="unfinished">QRCode</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">微信</translation>
    </message>
    <message>
        <location filename="../src/widgets/loginoptionswidget.cpp" line="685"/>
        <source>Identify device removed!</source>
        <translation>¡Identifique el dispositivo eliminado!</translation>
    </message>
</context>
<context>
    <name>MPRISSaverWidget</name>
    <message>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="230"/>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="419"/>
        <source>No music detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="444"/>
        <location filename="../src/screensaver/mprissaverwidget.cpp" line="453"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MusicFileInformation</name>
    <message>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="199"/>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="235"/>
        <source>Unknown singer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="200"/>
        <location filename="../src/screensaver/musicfileinformation.cpp" line="238"/>
        <source>Unknown album</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MyLineEdit</name>
    <message>
        <source>Verification code</source>
        <translation type="vanished">Código de verificación</translation>
    </message>
</context>
<context>
    <name>MyNetworkWidget</name>
    <message>
        <location filename="../src/widgets/mynetworkwidget.cpp" line="52"/>
        <source>LAN</source>
        <translation type="unfinished">LAN</translation>
    </message>
    <message>
        <location filename="../src/widgets/mynetworkwidget.cpp" line="54"/>
        <source>WLAN</source>
        <translation type="unfinished">WLAN</translation>
    </message>
</context>
<context>
    <name>NumbersWidget</name>
    <message>
        <location filename="../src/VirtualKeyboard/src/numberswidget.cpp" line="161"/>
        <source>&amp;&amp;?!</source>
        <translation>&amp;&amp;?!</translation>
    </message>
    <message>
        <location filename="../src/VirtualKeyboard/src/numberswidget.cpp" line="175"/>
        <location filename="../src/VirtualKeyboard/src/numberswidget.cpp" line="310"/>
        <source>Return</source>
        <translation>Devolución</translation>
    </message>
</context>
<context>
    <name>OneConnForm</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Forma</translation>
    </message>
    <message>
        <source>Automatically join the network</source>
        <translation type="vanished">Unirse automáticamente a la red</translation>
    </message>
    <message>
        <source>Input password</source>
        <translation type="vanished">输入密码</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation type="vanished">Desconectar</translation>
    </message>
    <message>
        <source>Input Password...</source>
        <translation type="vanished">Ingrese la contraseña...</translation>
    </message>
    <message>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation type="vanished">Conéctese a una red Wi-Fi oculta</translation>
    </message>
    <message>
        <source>Signal：</source>
        <translation type="vanished">Señal:</translation>
    </message>
    <message>
        <source>Public</source>
        <translation type="vanished">开放</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="vanished">安全</translation>
    </message>
    <message>
        <source>Rate</source>
        <translation type="vanished">速率</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Ninguno</translation>
    </message>
    <message>
        <source>WiFi Security：</source>
        <translation type="vanished">Seguridad WiFi:</translation>
    </message>
    <message>
        <source>MAC：</source>
        <translation type="vanished">MAC:</translation>
    </message>
    <message>
        <source>Conn Wifi Failed</source>
        <translation type="vanished">Falló Conn Wifi</translation>
    </message>
</context>
<context>
    <name>OneLancForm</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Forma</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Conectar</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation type="vanished">Desconectar</translation>
    </message>
    <message>
        <source>No Configuration</source>
        <translation type="vanished">Sin configuración</translation>
    </message>
    <message>
        <source>IPv4：</source>
        <translation type="vanished">IPv4:</translation>
    </message>
    <message>
        <source>IPv6：</source>
        <translation type="vanished">IPv6:</translation>
    </message>
    <message>
        <source>BandWidth：</source>
        <translation type="vanished">Ancho de banda:</translation>
    </message>
    <message>
        <source>MAC：</source>
        <translation type="vanished">MAC:</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="obsolete">自动</translation>
    </message>
</context>
<context>
    <name>PasswdCheckUtil</name>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="159"/>
        <source>The password is shorter than %1 characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="162"/>
        <source>The password contains less than %1 character classes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="165"/>
        <source>The password is the same as the old one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="168"/>
        <source>The password contains the user name in some form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="171"/>
        <source>The password differs with case changes only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="174"/>
        <source>The password is too similar to the old one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/passwdcheckutil.cpp" line="177"/>
        <source>The password is a palindrome</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhoneAuthWidget</name>
    <message>
        <source>Verification by phoneNum</source>
        <translation type="vanished">Verificación por teléfonoNum</translation>
    </message>
    <message>
        <source>「 Use bound Phone number to verification 」</source>
        <translation type="vanished">「 Use el número de teléfono vinculado para la verificación 」</translation>
    </message>
    <message>
        <source>「 Use SMS to verification 」</source>
        <translation type="vanished">「Usa SMS para verificar」</translation>
    </message>
    <message>
        <source>commit</source>
        <translation type="vanished">cometer</translation>
    </message>
    <message>
        <source>Network not connected~</source>
        <translation type="vanished">Red no conectada~</translation>
    </message>
    <message>
        <source>Network unavailable~</source>
        <translation type="vanished">Red no disponible~</translation>
    </message>
    <message>
        <source>Verification Code invalid!</source>
        <translation type="vanished">¡El código de verificación no es válido!</translation>
    </message>
    <message>
        <source>Verification Code incorrect.Please retry!</source>
        <translation type="vanished">Código de verificación incorrecto. ¡Por favor, vuelva a intentarlo!</translation>
    </message>
    <message>
        <source>Failed time over limit!Retry after 1 hour!</source>
        <translation type="vanished">¡Tiempo fallido por encima del límite! ¡Vuelva a intentarlo después de 1 hora!</translation>
    </message>
    <message>
        <source>verifaction failed!</source>
        <translation type="vanished">¡La verificación falló!</translation>
    </message>
</context>
<context>
    <name>PhotoCorver</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="82"/>
        <source>Right open the file location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/photocorver.cpp" line="86"/>
        <source>Remove the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerListWidget</name>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="302"/>
        <location filename="../src/widgets/powerlistwidget.h" line="109"/>
        <source>Hibernate</source>
        <translation type="unfinished">Hibernar</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="303"/>
        <location filename="../src/widgets/powerlistwidget.h" line="110"/>
        <source>Turn off your computer, but the app stays open, When the computer is turned on, it can be restored to the state you left</source>
        <translation type="unfinished">Apague su computadora, pero la aplicación permanece abierta. Cuando se enciende la computadora, se puede restaurar al estado en el que la dejó</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="306"/>
        <location filename="../src/widgets/powerlistwidget.h" line="122"/>
        <source>Suspend</source>
        <translation type="unfinished">Suspender</translation>
    </message>
    <message>
        <source>The computer stays on, but consumes less power. The app stays open and can quickly wake up and revert to where you left off</source>
        <translation type="obsolete">El ordenador permanece encendido, pero consume menos energía. La aplicación permanece abierta y puede despertarse rápidamente y volver a donde la dejó</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="307"/>
        <location filename="../src/widgets/powerlistwidget.h" line="123"/>
        <source>The computer stays on, but consumes less power, The app stays open and can quickly wake up and revert to where you left off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="310"/>
        <location filename="../src/widgets/powerlistwidget.h" line="172"/>
        <source>Restart</source>
        <translation type="unfinished">Reanudar</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="311"/>
        <source>Close all apps, and then restart your computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="313"/>
        <location filename="../src/widgets/powerlistwidget.h" line="196"/>
        <source>Shut Down</source>
        <translation type="unfinished">Apaga</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="316"/>
        <location filename="../src/widgets/powerlistwidget.h" line="147"/>
        <source>Log Out</source>
        <translation type="unfinished">Cerrar sesión</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="318"/>
        <location filename="../src/widgets/powerlistwidget.h" line="149"/>
        <source>The current user logs out of the system, terminates the session, and returns to the login page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="320"/>
        <location filename="../src/widgets/powerlistwidget.h" line="97"/>
        <source>SwitchUser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="322"/>
        <location filename="../src/widgets/powerlistwidget.h" line="135"/>
        <source>LockScreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="324"/>
        <location filename="../src/widgets/powerlistwidget.h" line="160"/>
        <source>UpgradeThenRestart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="326"/>
        <location filename="../src/widgets/powerlistwidget.h" line="184"/>
        <source>UpgradeThenShutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="obsolete">Apagar</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.cpp" line="314"/>
        <location filename="../src/widgets/powerlistwidget.h" line="197"/>
        <source>Close all apps, and then shut down your computer</source>
        <translation type="unfinished">Cierre todas las aplicaciones y, a continuación, apague el equipo</translation>
    </message>
    <message>
        <location filename="../src/widgets/powerlistwidget.h" line="173"/>
        <source>Close all apps, turn off your computer, and then turn your computer back on</source>
        <translation type="unfinished">Cierre todas las aplicaciones, apague el equipo y, a continuación, vuelva a encenderlo</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>lock</source>
        <translation type="vanished">cerradura</translation>
    </message>
    <message>
        <source>SwitchUser</source>
        <translation type="vanished">切换用户</translation>
    </message>
    <message>
        <source>logout</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <source>reboot</source>
        <translation type="vanished">重启</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation type="vanished">锁屏</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="vanished">切换用户</translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation type="vanished">Cerrar sesión</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="vanished">Reanudar</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="vanished">Apagar</translation>
    </message>
    <message>
        <source>Close all apps, turn off your computer, and then turn your computer back on</source>
        <translation type="vanished">Cierre todas las aplicaciones, apague el equipo y, a continuación, vuelva a encenderlo</translation>
    </message>
    <message>
        <source>Close all apps, and then shut down your computer</source>
        <translation type="vanished">Cierre todas las aplicaciones y, a continuación, apague el equipo</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="vanished">Apaga</translation>
    </message>
    <message>
        <source>Turn off your computer, but the app stays open, When the computer is turned on, it can be restored to the state you left</source>
        <translation type="vanished">Apague su computadora, pero la aplicación permanece abierta. Cuando se enciende la computadora, se puede restaurar al estado en el que la dejó</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation type="vanished">Hibernar</translation>
    </message>
    <message>
        <source>The computer stays on, but consumes less power. The app stays open and can quickly wake up and revert to where you left off</source>
        <translation type="vanished">El ordenador permanece encendido, pero consume menos energía. La aplicación permanece abierta y puede despertarse rápidamente y volver a donde la dejó</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="vanished">Suspender</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation type="vanished">休眠</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/lock-command/main.cpp" line="108"/>
        <source>The screensaver is active.</source>
        <translation>El protector de pantalla está activo.</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="110"/>
        <source>The screensaver is inactive.</source>
        <translation>El protector de pantalla está inactivo.</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="28"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="30"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="32"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="34"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="36"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="38"/>
        <source>Ukey</source>
        <translation type="unfinished">Ukey</translation>
    </message>
    <message>
        <location filename="../src/common/biodefines.cpp" line="40"/>
        <source>QRCode</source>
        <translation type="unfinished">QRCode</translation>
    </message>
    <message>
        <location filename="../src/screensaver/musicdatabase.cpp" line="64"/>
        <source>Database Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResetPwdWidget</name>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="80"/>
        <source>Security Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="81"/>
        <source>Kylin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="160"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="359"/>
        <source>Enter new password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="184"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="360"/>
        <source>Confirm your password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="187"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="322"/>
        <source>Inconsistency with pwd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="215"/>
        <source>Confirm</source>
        <translation type="unfinished">Confirmar</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="225"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="291"/>
        <source>Contains illegal characters!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="385"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="456"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="480"/>
        <source>The service is abnormal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="393"/>
        <source>The SMS verification code has been sent to the mobile phone with the tail number %1 (Valid for 5 minutes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="401"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="406"/>
        <source>Failed to get the verification code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="414"/>
        <source>The account does not exist, please re-enter it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="462"/>
        <source>The account does not exist, please complete the registration first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="465"/>
        <source>The user is already locked, contact the administrator to unlock it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="468"/>
        <source>If there are too many login errors, please try again in 5 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="471"/>
        <source>The SMS verification code is incorrect or has expired</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="474"/>
        <source>Wrong username or password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="477"/>
        <source>Password decryption error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="547"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="575"/>
        <source>Verify Kylin ID Reset Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="550"/>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="569"/>
        <source>Answer the security questions and reset your password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/resetpwdwidget.cpp" line="604"/>
        <source>One or more wrong answers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="../src/dbusifs/enginedevice.cpp" line="308"/>
        <source></source>
        <comment>tablet device</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Screenlock</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="54"/>
        <source>Screenlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="291"/>
        <source>Your system does not have any browser application installed or the default browser application is not set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="292"/>
        <source>Unable to open browser application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="322"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="364"/>
        <source>select custom wallpaper file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="365"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="366"/>
        <source>Position: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="367"/>
        <source>FileName: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="368"/>
        <source>FileType: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlock.cpp" line="369"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>ScreenlockUi</name>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="50"/>
        <source>Screenlock</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screenlock/Screenlock</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="71"/>
        <source>Show picture of screenlock on screenlogin</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screenlock/Show picture of screenlock on screenlogin</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="83"/>
        <source>The date and time are displayed</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screenlock/The date and time are displayed</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="96"/>
        <source>Leave lock (System will be locked when the paired phone gone)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="106"/>
        <source>Specified device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="123"/>
        <source>No paired phone. Please turn to &apos;Bluetooth&apos; to pair.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="131"/>
        <source>Bluetooth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="180"/>
        <source>Choose Picture</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Wallpaper/Choose Picture</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="184"/>
        <source>Local Pictures</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screenlock/Local Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="188"/>
        <source>Online Pictures</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screenlock/Online Pictures</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="192"/>
        <source>Reset To Default</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screenlock/Reset To Default</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="212"/>
        <source>Related Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="215"/>
        <source>Monitor Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="216"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="218"/>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="217"/>
        <source>Screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="251"/>
        <source>No bluetooth adapter detected, can not use Leave Lock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="278"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="669"/>
        <location filename="../src/ukccplugins/screenlock/screenlockui.cpp" line="703"/>
        <source>Please select device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <source>exit(Esc)</source>
        <translation type="vanished">退出(Esc)</translation>
    </message>
    <message>
        <source>exit</source>
        <translation type="vanished">退出</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="155"/>
        <source>Picture does not exist</source>
        <translation>La imagen no existe</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1794"/>
        <location filename="../src/screensaver/screensaver.cpp" line="1796"/>
        <source>Not connected to a network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1800"/>
        <location filename="../src/screensaver/screensaver.cpp" line="1802"/>
        <source>The weather update failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1887"/>
        <source>Smart Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1961"/>
        <source>Weather</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="1989"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="2020"/>
        <source>Photo Albun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set as desktop wallpaper</source>
        <translation type="vanished">设置为桌面壁纸</translation>
    </message>
    <message>
        <source>Automatic switching</source>
        <translation type="vanished">自动切换</translation>
    </message>
    <message>
        <source>You have %1 unread message</source>
        <translation type="obsolete">您有%1条未读消息</translation>
    </message>
    <message>
        <source>You have new notification</source>
        <translation type="vanished">Tienes una nueva notificación</translation>
    </message>
    <message>
        <location filename="../src/screensaver/screensaver.cpp" line="158"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="56"/>
        <source>Screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="215"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="221"/>
        <source>5min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="215"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="221"/>
        <source>10min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <source>15min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="215"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="221"/>
        <source>30min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <source>1hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="196"/>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="202"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="215"/>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="221"/>
        <source>1min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="208"/>
        <source>UKUI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaver.cpp" line="208"/>
        <source>Customize</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreensaverUi</name>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="70"/>
        <source>Screensaver</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Screensaver</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="86"/>
        <source>Select Screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="112"/>
        <source>Weather</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="125"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="138"/>
        <source>Albun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="177"/>
        <source>Idle time</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Idle time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="196"/>
        <source>The date and time are displayed</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/The date and time are displayed</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="217"/>
        <source>Show rest time</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="228"/>
        <source>Lock screen when screensaver boot</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Lock screen when screensaver boot</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="250"/>
        <source>Go to App Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="261"/>
        <source>Current position</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Show rest time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="281"/>
        <source>Priority playlists</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Priority playlists</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="285"/>
        <source>Select the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="307"/>
        <source>Switch mode</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Switch mode</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="308"/>
        <source>In order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="309"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="407"/>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="314"/>
        <source>Switching frequency</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Switching frequency</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="331"/>
        <source>Image source</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Image source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="274"/>
        <source>Prioritize the list of songs from the Music app</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Prioritize the list of songs from the Music app</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="332"/>
        <source>Add image folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="351"/>
        <source>Screensaver program</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Screensaver program</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="380"/>
        <source>Screensaver source</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Screensaver source</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="385"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="975"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1119"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1189"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="406"/>
        <source>Ordinal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="414"/>
        <source>Random switching</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Random switching</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="434"/>
        <source>Switching time</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Switching time</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="453"/>
        <source>Text(up to 30 characters):</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Text(up to 30 characters):</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="476"/>
        <source>Text position</source>
        <translation type="unfinished"></translation>
        <extra-contents_path>/Screensaver/Text position</extra-contents_path>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="484"/>
        <source>Centered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="485"/>
        <source>Randow(Bubble text)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="867"/>
        <source>System wallpaper gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="933"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1147"/>
        <source>Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="974"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1188"/>
        <source>select custom screensaver dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="976"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1120"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1190"/>
        <source>Position: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="977"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1121"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1191"/>
        <source>FileName: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="978"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1122"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1192"/>
        <source>FileType: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="979"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1123"/>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1193"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1077"/>
        <source>Music files(*.mp3 *.wav *.ogg *.flac *.aac *.m4a *.wma *.opus *.aiff .ape)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1118"/>
        <source>select screensaver music dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukccplugins/screensaver/screensaverui.cpp" line="1143"/>
        <source>The maximum limit for the number of images in the folder has been reached; you can remove some before continuing to add more.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SleepTime</name>
    <message>
        <source>You have rested:</source>
        <translation type="vanished">您已休息:</translation>
    </message>
    <message>
        <location filename="../src/screensaver/sleeptime.cpp" line="75"/>
        <source>You have rested</source>
        <translation>Has descansado</translation>
    </message>
</context>
<context>
    <name>SureWindow</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Forma</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="vanished">Etiqueta de texto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="vanished">Confirmar</translation>
    </message>
    <message>
        <source>Multiple users are logged in at the same time.Are you sure you want to reboot this system?</source>
        <translation type="vanished">同时有多个用户登录系统，您确定要退出系统吗？</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from suspend!</source>
        <translation type="vanished">¡El siguiente programa se está ejecutando para evitar que el sistema se suspenda!</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from hibernate!</source>
        <translation type="vanished">¡El siguiente programa se está ejecutando para evitar que el sistema hiberne!</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from shutting down!</source>
        <translation type="vanished">¡El siguiente programa se está ejecutando para evitar que el sistema se apague!</translation>
    </message>
    <message>
        <source>The following program is running to prevent the system from reboot!</source>
        <translation type="vanished">¡El siguiente programa se está ejecutando para evitar que el sistema se reinicie!</translation>
    </message>
</context>
<context>
    <name>SwitchButton</name>
    <message>
        <source>login by password</source>
        <translation type="vanished">密码登录</translation>
    </message>
    <message>
        <source>login by qr code</source>
        <translation type="vanished">微信登录</translation>
    </message>
</context>
<context>
    <name>SwitchButtonGroup</name>
    <message>
        <source>uEduPWD</source>
        <translation type="vanished">uEduPWD</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">Wechat</translation>
    </message>
</context>
<context>
    <name>TabletLockWidget</name>
    <message>
        <source>You have %1 unread message</source>
        <translation type="vanished">您有%1条未读消息</translation>
    </message>
    <message>
        <source>Slide to unlock</source>
        <translation type="vanished">向上滑动解锁</translation>
    </message>
    <message>
        <source>New password is the same as old</source>
        <translation type="vanished">La nueva contraseña es la misma que la anterior</translation>
    </message>
    <message>
        <source>Reset password error:%1</source>
        <translation type="vanished">Error de restablecimiento de contraseña:%1</translation>
    </message>
    <message>
        <source>Please scan by correct WeChat</source>
        <translation type="vanished">Por favor, escanee por WeChat correcto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">Atrás</translation>
    </message>
    <message>
        <source>Skip</source>
        <translation type="vanished">Saltarse</translation>
    </message>
</context>
<context>
    <name>TalksWidget</name>
    <message>
        <location filename="../src/widgets/talkswidget.cpp" line="58"/>
        <source>Enter your answer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserListWidget</name>
    <message>
        <location filename="../src/widgets/userlistwidget.cpp" line="67"/>
        <location filename="../src/widgets/userlistwidget.cpp" line="121"/>
        <source>Login</source>
        <translation type="unfinished">Iniciar sesión</translation>
    </message>
    <message>
        <location filename="../src/widgets/userlistwidget.cpp" line="69"/>
        <location filename="../src/widgets/userlistwidget.cpp" line="123"/>
        <source>Guest</source>
        <translation type="unfinished">游客</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>kylin network applet desktop message</source>
        <translation type="vanished">Mensaje de escritorio del applet de red Kylin</translation>
    </message>
</context>
<context>
    <name>VerificationWidget</name>
    <message>
        <source>Please scan by bound WeChat</source>
        <translation type="vanished">Escanee por WeChat enlazado</translation>
    </message>
</context>
<context>
    <name>VerifyKyidWidget</name>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="45"/>
        <source>Enter your Kylin ID account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="64"/>
        <source>Input password</source>
        <translation type="unfinished">输入密码</translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="77"/>
        <source>Enter the verification code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="84"/>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="109"/>
        <source>Get verification code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/verifykyidwidget.cpp" line="112"/>
        <source>Reacquire(%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VerticalVerificationWidget</name>
    <message>
        <source>Please scan by bound WeChat</source>
        <translation type="vanished">Escanee por WeChat enlazado</translation>
    </message>
</context>
<context>
    <name>WeChatAuthDialog</name>
    <message>
        <source>Login by wechat</source>
        <translation type="vanished">Iniciar sesión por wechat</translation>
    </message>
    <message>
        <source>Verification by wechat</source>
        <translation type="vanished">Verificación por wechat</translation>
    </message>
    <message>
        <source>「 Use registered WeChat account to login 」</source>
        <translation type="vanished">「 Use una cuenta registrada de WeChat para iniciar sesión」</translation>
    </message>
    <message>
        <source>「 Use bound WeChat account to verification 」</source>
        <translation type="vanished">「Usar la cuenta de WeChat vinculada para la verificación」</translation>
    </message>
    <message>
        <source>Network not connected~</source>
        <translation type="vanished">Red no conectada~</translation>
    </message>
    <message>
        <source>Scan code successfully</source>
        <translation type="vanished">Escanear el código con éxito</translation>
    </message>
    <message>
        <source>Timeout!Try again!</source>
        <translation type="vanished">¡Interrupción! ¡Vuelve a intentarlo!</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation type="vanished">登录失败</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../examples/LoadCustomPlugin/widget.ui" line="14"/>
        <source>Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../examples/LoadCustomPlugin/widget.ui" line="26"/>
        <source>LoadPlugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>action</name>
    <message>
        <location filename="../src/lock-command/main.cpp" line="69"/>
        <source>which block type,param:Suspend/Hibernate/Restart/Shutdown/Logout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="74"/>
        <source>which block type,param:Shutdown/Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="81"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="86"/>
        <source>which block type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>delay</name>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="62"/>
        <source>how long to show lock</source>
        <translation>Cuánto tiempo mostrar el bloqueo</translation>
    </message>
</context>
<context>
    <name>has-lock</name>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="67"/>
        <source>if show lock</source>
        <translation>if show lock</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/lock-command/main.cpp" line="44"/>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation>Comando de inicio para el ukui ScreenSaver.</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="49"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="46"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="48"/>
        <source>lock the screen immediately</source>
        <translation>Bloquee la pantalla inmediatamente</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="52"/>
        <source>query the status of the screen saver</source>
        <translation>Consultar el estado del protector de pantalla</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="55"/>
        <source>unlock the screen saver</source>
        <translation>Desbloquear el protector de pantalla</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="57"/>
        <source>show the screensaver</source>
        <translation>Mostrar el protector de pantalla</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="60"/>
        <source>show blank and delay to lock,param:idle/lid/lowpower</source>
        <translation>mostrar en blanco y retardo para bloquear, param:idle/lid/lowpower</translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="63"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="70"/>
        <source>show the session tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="65"/>
        <source>show the switchuser window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="68"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="80"/>
        <source>show the app block window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-command/main.cpp" line="73"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="85"/>
        <source>show the multiUsers block window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="40"/>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation>Diálogo para el protector de pantalla ukui.</translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="50"/>
        <source>activated by session idle signal</source>
        <translation>Activado por la señal de inactividad de la sesión</translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="53"/>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="58"/>
        <source>lock the screen and show screensaver immediately</source>
        <translation>Bloquee la pantalla y muestre el protector de pantalla inmediatamente</translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="55"/>
        <source>show screensaver immediately</source>
        <translation>Mostrar protector de pantalla inmediatamente</translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="61"/>
        <source>show blank screensaver immediately and delay time to show lock</source>
        <translation>Mostrar protector de pantalla en blanco inmediatamente y retrasar el tiempo para mostrar el bloqueo</translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="66"/>
        <source>show blank screensaver immediately and if lock</source>
        <translation>Mostrar protector de pantalla en blanco inmediatamente y si se bloquea</translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="72"/>
        <source>show switch user window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="75"/>
        <source>switch to user and show window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/screensaver/main.cpp" line="66"/>
        <source>Screensaver for ukui-screensaver</source>
        <translation>Protector de pantalla para ukui-screensaver</translation>
    </message>
    <message>
        <location filename="../src/screensaver/main.cpp" line="70"/>
        <source>show on root window</source>
        <translation>Mostrar en la ventana raíz</translation>
    </message>
    <message>
        <location filename="../src/screensaver/main.cpp" line="72"/>
        <source>show on window.</source>
        <translation>mostrar en la ventana.</translation>
    </message>
    <message>
        <location filename="../src/screensaver/main.cpp" line="73"/>
        <source>window id</source>
        <translation>ID de ventana</translation>
    </message>
    <message>
        <location filename="../src/lock-backend/main.cpp" line="63"/>
        <source>Backend for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lock-backend/main.cpp" line="69"/>
        <source>lock the screen by startup</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>switchtouser</name>
    <message>
        <location filename="../src/lock-dialog/lockdialogmodel.cpp" line="76"/>
        <source>switch to someone user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
