/*
 * Copyright (C) 2023 KylinSoft Co., Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 **/
#include "circlelabel.h"

#include <QPainter>
#include <QPainterPath>

CircleLabel::CircleLabel(QWidget *parent)
    : QLabel(parent)
{
}

CircleLabel::CircleLabel(QPixmap pixmap, QWidget *parent)
    : QLabel(parent)
{
    setPixmap(pixmap);
}

CircleLabel::~CircleLabel()
{
}

void CircleLabel::setPixmap(QPixmap pixmap)
{
    mPixmap = pixmap;
    update();
}

void CircleLabel::paintEvent(QPaintEvent *event)
{
    Q_UNUSED(event);
    int radius = qMin(width(), height()) / 2;

    QPixmap pixmapa(mPixmap);
    QPainter painter(this);
    painter.setRenderHints(
       QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
    painter.setBrush(Qt::transparent);
    painter.setPen(QPen(Qt::transparent, -1, Qt::SolidLine));
    QPainterPath path;
    path.addEllipse(0, 0, radius * 2, radius * 2);
    painter.setClipPath(path);

    painter.drawPixmap(0, 0, radius * 2, radius * 2, pixmapa);
}
